@@ -11,10 +11,8 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-SYSTEMTESTTOP=..
-
 export ALGORITHM_SET="ecc_default"
-. $SYSTEMTESTTOP/conf.sh
+. ../conf.sh
 
 # Ensure the selected algorithm set is okay.
 if [ "$ALGORITHM_SET" = "error" ]; then
