@@ -13,11 +13,6 @@
 
 . ../conf.sh
 
-#
-# jnl and database files MUST be removed before we start
-#
-$SHELL clean.sh
-
 copy_setports ns1/named.conf.in ns1/named.conf
 copy_setports ns2/named.conf.in ns2/named.conf
 copy_setports ns3/named.conf.in ns3/named.conf
