@@ -97,17 +97,16 @@ def create_response(msg):
         ip6req = True
     elif endswith(lqname, "a.b.stale."):
         if lqname == "a.b.stale.":
+            r.flags |= dns.flags.AA
             if rrtype == TXT:
                 # Direct query.
                 r.answer.append(dns.rrset.from_text(lqname, 1, IN, TXT, "peekaboo"))
-                r.flags |= dns.flags.AA
             elif rrtype == NS:
                 # NS a.b.
                 r.answer.append(dns.rrset.from_text(lqname, 1, IN, NS, "ns.a.b.stale."))
                 r.additional.append(
                     dns.rrset.from_text("ns.a.b.stale.", 1, IN, A, "10.53.0.3")
                 )
-                r.flags |= dns.flags.AA
             elif rrtype == SOA:
                 # SOA a.b.
                 r.answer.append(
@@ -115,7 +114,6 @@ def create_response(msg):
                         lqname, 1, IN, SOA, "a.b.stale. hostmaster.a.b.stale. 1 2 3 4 5"
                     )
                 )
-                r.flags |= dns.flags.AA
             else:
                 # NODATA.
                 r.authority.append(
@@ -123,7 +121,20 @@ def create_response(msg):
                         lqname, 1, IN, SOA, "a.b.stale. hostmaster.a.b.stale. 1 2 3 4 5"
                     )
                 )
+        elif lqname == "ns.a.b.stale.":
+            r.flags |= dns.flags.AA
+            if rrtype == A:
+                r.answer.append(
+                    dns.rrset.from_text("ns.a.b.stale.", 1, IN, A, "10.53.0.3")
+                )
+            else:
+                r.authority.append(
+                    dns.rrset.from_text(
+                        lqname, 1, IN, SOA, "a.b.stale. hostmaster.a.b.stale. 1 2 3 4 5"
+                    )
+                )
         else:
+            r.flags |= dns.flags.AA
             r.authority.append(
                 dns.rrset.from_text(
                     lqname, 1, IN, SOA, "a.b.stale. hostmaster.a.b.stale. 1 2 3 4 5"
