@@ -45,7 +45,7 @@
 		if ((x) != ISC_R_SUCCESS) {                  \
 			fprintf(stderr, "I:%s: %s\n", (str), \
 				isc_result_totext(x));       \
-			exit(-1);                            \
+			exit(EXIT_FAILURE);                  \
 		}                                            \
 	}
 
@@ -81,7 +81,7 @@ recvquery(isc_task_t *task, isc_event_t *event) {
 	if (reqev->result != ISC_R_SUCCESS) {
 		fprintf(stderr, "I:request event result: %s\n",
 			isc_result_totext(reqev->result));
-		exit(-1);
+		exit(EXIT_FAILURE);
 	}
 
 	query = reqev->ev_arg;
@@ -96,7 +96,7 @@ recvquery(isc_task_t *task, isc_event_t *event) {
 		result = dns_result_fromrcode(response->rcode);
 		fprintf(stderr, "I:response rcode: %s\n",
 			isc_result_totext(result));
-		exit(-1);
+		exit(EXIT_FAILURE);
 	}
 
 	result = dns_tkey_processdhresponse(query, response, ourkey, &nonce,
@@ -178,9 +178,9 @@ sendquery(isc_task_t *task, isc_event_t *event) {
 				       DNS_TSIG_HMACMD5_NAME, &nonce, 3600);
 	CHECK("dns_tkey_builddhquery", result);
 
-	result = dns_request_create(requestmgr, query, &address,
-				    DNS_REQUESTOPT_TCP, initialkey, TIMEOUT,
-				    task, recvquery, query, &request);
+	result = dns_request_create(requestmgr, query, NULL, &address,
+				    DNS_REQUESTOPT_TCP, initialkey, TIMEOUT, 0,
+				    0, task, recvquery, query, &request);
 	CHECK("dns_request_create", result);
 }
 
@@ -204,7 +204,7 @@ main(int argc, char *argv[]) {
 
 	if (argc < 4) {
 		fprintf(stderr, "I:no DH key provided\n");
-		exit(-1);
+		exit(EXIT_FAILURE);
 	}
 	ip_address = argv[1];
 	port = atoi(argv[2]);
@@ -274,5 +274,5 @@ main(int argc, char *argv[]) {
 
 	isc_app_finish();
 
-	return (0);
+	return 0;
 }
