@@ -54,10 +54,10 @@ extern const dns_name_t *dns_tsig_hmacsha512_name;
 #define DNS_TSIG_FUDGE 300
 
 struct dns_tsig_keyring {
-	dns_rbt_t	  *keys;
+	dns_rbt_t   *keys;
 	unsigned int writecount;
 	isc_rwlock_t lock;
-	isc_mem_t	  *mctx;
+	isc_mem_t   *mctx;
 	/*
 	 * LRU list of generated key along with a count of the keys on the
 	 * list and a maximum size.
@@ -71,10 +71,10 @@ struct dns_tsig_keyring {
 struct dns_tsigkey {
 	/* Unlocked */
 	unsigned int	    magic; /*%< Magic number. */
-	isc_mem_t	  *mctx;
-	dst_key_t	  *key;       /*%< Key */
+	isc_mem_t	   *mctx;
+	dst_key_t	   *key;       /*%< Key */
 	dns_name_t	    name;      /*%< Key name */
-	const dns_name_t	 *algorithm; /*%< Algorithm name */
+	const dns_name_t   *algorithm; /*%< Algorithm name */
 	dns_name_t	   *creator;   /*%< name that created secret */
 	bool		    generated; /*%< was this generated? */
 	isc_stdtime_t	    inception; /*%< start of validity period */
@@ -264,7 +264,9 @@ dns_tsigkeyring_add(dns_tsig_keyring_t *ring, const dns_name_t *name,
  *      Place a TSIG key onto a key ring.
  *
  *	Requires:
- *\li		'ring', 'name' and 'tkey' are not NULL
+ *\li		'name' and 'ring' are not NULL
+ *\li		'tkey' is a valid TSIG key, which has not been
+ *		       added to any other keyrings
  *
  *	Returns:
  *\li		#ISC_R_SUCCESS
