@@ -20,6 +20,7 @@
 #include <isc/log.h>
 #include <isc/mem.h>
 #include <isc/print.h>
+#include <isc/result.h>
 #include <isc/rwlock.h>
 #include <isc/string.h>
 #include <isc/task.h>
@@ -35,7 +36,6 @@
 #include <dns/rbt.h>
 #include <dns/rdataset.h>
 #include <dns/resolver.h>
-#include <dns/result.h>
 #include <dns/time.h>
 
 struct dns_nta {
@@ -137,7 +137,7 @@ dns_ntatable_create(dns_view_t *view, isc_taskmgr_t *taskmgr,
 	ntatable->magic = NTATABLE_MAGIC;
 	*ntatablep = ntatable;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup_task:
 	isc_task_detach(&ntatable->task);
@@ -145,7 +145,7 @@ cleanup_task:
 cleanup_ntatable:
 	isc_mem_put(view->mctx, ntatable, sizeof(*ntatable));
 
-	return (result);
+	return result;
 }
 
 void
@@ -263,8 +263,8 @@ checkbogus(isc_task_t *task, isc_event_t *event) {
 	dns_view_weakattach(ntatable->view, &view);
 	result = dns_resolver_createfetch(
 		view->resolver, nta->name, dns_rdatatype_nsec, NULL, NULL, NULL,
-		NULL, 0, DNS_FETCHOPT_NONTA, 0, NULL, task, fetch_done, nta,
-		&nta->rdataset, &nta->sigrdataset, &nta->fetch);
+		NULL, 0, DNS_FETCHOPT_NONTA, 0, NULL, NULL, task, fetch_done,
+		nta, &nta->rdataset, &nta->sigrdataset, &nta->fetch);
 	if (result != ISC_R_SUCCESS) {
 		nta_detach(view->mctx, &nta);
 		dns_view_weakdetach(&view);
@@ -281,12 +281,12 @@ settimer(dns_ntatable_t *ntatable, dns_nta_t *nta, uint32_t lifetime) {
 	REQUIRE(VALID_NTA(nta));
 
 	if (ntatable->timermgr == NULL) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	view = ntatable->view;
 	if (view->nta_recheck == 0 || lifetime <= view->nta_recheck) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	isc_interval_set(&interval, view->nta_recheck, 0);
@@ -296,7 +296,7 @@ settimer(dns_ntatable_t *ntatable, dns_nta_t *nta, uint32_t lifetime) {
 	if (result != ISC_R_SUCCESS) {
 		isc_timer_destroy(&nta->timer);
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -322,12 +322,12 @@ nta_create(dns_ntatable_t *ntatable, const dns_name_t *name,
 	isc_refcount_init(&nta->refcount, 1);
 
 	nta->name = dns_fixedname_initname(&nta->fn);
-	dns_name_copynf(name, nta->name);
+	dns_name_copy(name, nta->name);
 
 	nta->magic = NTA_MAGIC;
 
 	*target = nta;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -386,7 +386,7 @@ unlock:
 		nta_detach(view->mctx, &nta);
 	}
 
-	return (result);
+	return result;
 }
 
 /*
@@ -413,7 +413,7 @@ deletenode(dns_ntatable_t *ntatable, const dns_name_t *name) {
 		result = ISC_R_NOTFOUND;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -424,7 +424,7 @@ dns_ntatable_delete(dns_ntatable_t *ntatable, const dns_name_t *name) {
 	result = deletenode(ntatable, name);
 	RWUNLOCK(&ntatable->rwlock, isc_rwlocktype_write);
 
-	return (result);
+	return result;
 }
 
 bool
@@ -442,7 +442,7 @@ dns_ntatable_covered(dns_ntatable_t *ntatable, isc_stdtime_t now,
 	REQUIRE(dns_name_isabsolute(name));
 
 	if (ntatable == NULL) {
-		return (false);
+		return false;
 	}
 
 	foundname = dns_fixedname_initname(&fn);
@@ -496,7 +496,7 @@ again:
 	}
 	RWUNLOCK(&ntatable->rwlock, locktype);
 
-	return (answer);
+	return answer;
 }
 
 static isc_result_t
@@ -505,11 +505,11 @@ putstr(isc_buffer_t **b, const char *str) {
 
 	result = isc_buffer_reserve(b, strlen(str));
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	isc_buffer_putstr(*b, str);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -547,13 +547,12 @@ dns_ntatable_totext(dns_ntatable_t *ntatable, const char *view,
 			dns_name_t *name;
 			isc_time_t t;
 
-			/*
-			 * Skip "validate-except" entries.
-			 */
+			name = dns_fixedname_initname(&fn);
+			dns_rbt_fullnamefromnode(node, name);
+			dns_name_format(name, nbuf, sizeof(nbuf));
+
 			if (n->expiry != 0xffffffffU) {
-				name = dns_fixedname_initname(&fn);
-				dns_rbt_fullnamefromnode(node, name);
-				dns_name_format(name, nbuf, sizeof(nbuf));
+				/* Normal NTA entries */
 				isc_time_set(&t, n->expiry, 0);
 				isc_time_formattimestamp(&t, tbuf,
 							 sizeof(tbuf));
@@ -565,11 +564,18 @@ dns_ntatable_totext(dns_ntatable_t *ntatable, const char *view,
 					 n->expiry <= now ? "expired"
 							  : "expiry",
 					 tbuf);
-				first = false;
-				result = putstr(buf, obuf);
-				if (result != ISC_R_SUCCESS) {
-					goto cleanup;
-				}
+			} else {
+				/* "validate-except" entries */
+				snprintf(obuf, sizeof(obuf), "%s%s%s%s: %s",
+					 first ? "" : "\n", nbuf,
+					 view != NULL ? "/" : "",
+					 view != NULL ? view : "", "permanent");
+			}
+
+			first = false;
+			result = putstr(buf, obuf);
+			if (result != ISC_R_SUCCESS) {
+				goto cleanup;
 			}
 		}
 		result = dns_rbtnodechain_next(&chain, NULL, NULL);
@@ -584,32 +590,7 @@ dns_ntatable_totext(dns_ntatable_t *ntatable, const char *view,
 cleanup:
 	dns_rbtnodechain_invalidate(&chain);
 	RWUNLOCK(&ntatable->rwlock, isc_rwlocktype_read);
-	return (result);
-}
-
-isc_result_t
-dns_ntatable_dump(dns_ntatable_t *ntatable, FILE *fp) {
-	isc_result_t result;
-	isc_buffer_t *text = NULL;
-	int len = 4096;
-
-	isc_buffer_allocate(ntatable->view->mctx, &text, len);
-
-	result = dns_ntatable_totext(ntatable, NULL, &text);
-
-	if (isc_buffer_usedlength(text) != 0) {
-		(void)putstr(&text, "\n");
-	} else if (result == ISC_R_SUCCESS) {
-		(void)putstr(&text, "none");
-	} else {
-		(void)putstr(&text, "could not dump NTA table: ");
-		(void)putstr(&text, isc_result_totext(result));
-	}
-
-	fprintf(fp, "%.*s", (int)isc_buffer_usedlength(text),
-		(char *)isc_buffer_base(text));
-	isc_buffer_free(&text);
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -685,9 +666,9 @@ cleanup:
 	RWUNLOCK(&ntatable->rwlock, isc_rwlocktype_read);
 
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	} else {
-		return (written ? ISC_R_SUCCESS : ISC_R_NOTFOUND);
+		return written ? ISC_R_SUCCESS : ISC_R_NOTFOUND;
 	}
 }
 
