@@ -75,7 +75,7 @@ static uint32_t
 hash_32(uint32_t val, unsigned int bits) {
 	REQUIRE(bits <= RBT_HASH_MAX_BITS);
 	/* High bits are more random. */
-	return (val * GOLDEN_RATIO_32 >> (32 - bits));
+	return val * GOLDEN_RATIO_32 >> (32 - bits);
 }
 
 struct dns_rbt {
@@ -197,7 +197,7 @@ Name(dns_rbtnode_t *node) {
 		NODENAME(node, &name);
 	}
 
-	return (name);
+	return name;
 }
 #endif /* DEBUG */
 
@@ -207,7 +207,7 @@ Name(dns_rbtnode_t *node) {
  */
 static dns_rbtnode_t *
 get_upper_node(dns_rbtnode_t *node) {
-	return (UPPERNODE(node));
+	return UPPERNODE(node);
 }
 
 size_t
@@ -222,7 +222,7 @@ dns__rbtnode_getdistance(dns_rbtnode_t *node) {
 		node = PARENT(node);
 	}
 
-	return (nodes);
+	return nodes;
 }
 
 /*
@@ -299,14 +299,14 @@ dns__rbtnode_namelen(dns_rbtnode_t *node) {
 		node = get_upper_node(node);
 	} while (!dns_name_isabsolute(&current));
 
-	return (len);
+	return len;
 }
 
 unsigned int
 dns__rbtnode_getsize(dns_rbtnode_t *node) {
 	REQUIRE(DNS_RBTNODE_VALID(node));
 
-	return (NODE_SIZE(node));
+	return NODE_SIZE(node);
 }
 
 /*
@@ -335,7 +335,7 @@ dns_rbt_create(isc_mem_t *mctx, dns_rbtdeleter_t deleter, void *deleter_arg,
 
 	*rbtp = rbt;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -356,7 +356,7 @@ dns_rbt_destroy2(dns_rbt_t **rbtp, unsigned int quantum) {
 
 	deletetreeflat(rbt, quantum, false, &rbt->root);
 	if (rbt->root != NULL) {
-		return (ISC_R_QUOTA);
+		return ISC_R_QUOTA;
 	}
 
 	*rbtp = NULL;
@@ -373,14 +373,14 @@ dns_rbt_destroy2(dns_rbt_t **rbtp, unsigned int quantum) {
 	rbt->magic = 0;
 
 	isc_mem_putanddetach(&rbt->mctx, rbt, sizeof(*rbt));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 unsigned int
 dns_rbt_nodecount(dns_rbt_t *rbt) {
 	REQUIRE(VALID_RBT(rbt));
 
-	return (rbt->nodecount);
+	return rbt->nodecount;
 }
 
 size_t
@@ -391,7 +391,7 @@ dns_rbt_hashsize(dns_rbt_t *rbt) {
 				   ? rbt->hashbits[0]
 				   : rbt->hashbits[1];
 
-	return (1 << hashbits);
+	return 1 << hashbits;
 }
 
 static isc_result_t
@@ -415,10 +415,10 @@ chain_name(dns_rbtnodechain_t *chain, dns_name_t *name,
 		result = dns_name_concatenate(name, &nodename, name, NULL);
 
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -442,7 +442,7 @@ move_chain_to_last(dns_rbtnodechain_t *chain, dns_rbtnode_t *node) {
 
 	chain->end = node;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -520,7 +520,7 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 			*nodep = new_current;
 			hash_node(rbt, new_current, name);
 		}
-		return (result);
+		return result;
 	}
 
 	level_count = 0;
@@ -716,7 +716,7 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 					 * a new level.
 					 */
 					*nodep = new_current;
-					return (ISC_R_SUCCESS);
+					return ISC_R_SUCCESS;
 				} else {
 					/*
 					 * The current node has no data,
@@ -759,7 +759,7 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 		hash_node(rbt, new_current, name);
 	}
 
-	return (result);
+	return result;
 }
 
 /*
@@ -790,7 +790,7 @@ dns_rbt_addname(dns_rbt_t *rbt, const dns_name_t *name, void *data) {
 		result = ISC_R_SUCCESS;
 	}
 
-	return (result);
+	return result;
 }
 
 /*
@@ -832,7 +832,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 	}
 
 	if (rbt->root == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	/*
@@ -1058,7 +1058,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 						chain, callback_name, false);
 					if (result != ISC_R_SUCCESS) {
 						dns_rbtnodechain_reset(chain);
-						return (result);
+						return result;
 					}
 
 					result = (callback)(current,
@@ -1320,7 +1320,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 
 	ENSURE(*node == NULL || DNS_RBTNODE_VALID(*node));
 
-	return (result);
+	return result;
 }
 
 /*
@@ -1343,7 +1343,7 @@ dns_rbt_findname(dns_rbt_t *rbt, const dns_name_t *name, unsigned int options,
 		result = ISC_R_NOTFOUND;
 	}
 
-	return (result);
+	return result;
 }
 
 /*
@@ -1384,7 +1384,7 @@ dns_rbt_deletename(dns_rbt_t *rbt, const dns_name_t *name, bool recurse) {
 		result = ISC_R_NOTFOUND;
 	}
 
-	return (result);
+	return result;
 }
 
 /*
@@ -1450,7 +1450,7 @@ dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, bool recurse) {
 			 * of the comment at the start of this function).
 			 * But join_nodes() function has now been removed.
 			 */
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 	}
 
@@ -1482,7 +1482,7 @@ dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, bool recurse) {
 	/*
 	 * This function never fails.
 	 */
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -1519,7 +1519,7 @@ dns_rbt_fullnamefromnode(dns_rbtnode_t *node, dns_name_t *name) {
 		node = get_upper_node(node);
 	} while (!dns_name_isabsolute(name));
 
-	return (result);
+	return result;
 }
 
 char *
@@ -1541,7 +1541,7 @@ dns_rbt_formatnodename(dns_rbtnode_t *node, char *printname,
 			 isc_result_totext(result));
 	}
 
-	return (printname);
+	return printname;
 }
 
 static isc_result_t
@@ -1576,7 +1576,6 @@ create_node(isc_mem_t *mctx, const dns_name_t *name, dns_rbtnode_t **nodep) {
 	HASHVAL(node) = 0;
 
 	ISC_LINK_INIT(node, deadlink);
-	ISC_LINK_INIT(node, prunelink);
 
 	LOCKNUM(node) = 0;
 	WILD(node) = 0;
@@ -1613,7 +1612,7 @@ create_node(isc_mem_t *mctx, const dns_name_t *name, dns_rbtnode_t **nodep) {
 #endif /* if DNS_RBT_USEMAGIC */
 	*nodep = node;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -1669,7 +1668,7 @@ rehash_bits(dns_rbt_t *rbt, size_t newcount) {
 		newbits += 1;
 	}
 
-	return (newbits);
+	return newbits;
 }
 
 /*
@@ -1747,13 +1746,13 @@ maybe_rehash(dns_rbt_t *rbt, size_t newcount) {
 
 static bool
 rehashing_in_progress(dns_rbt_t *rbt) {
-	return (rbt->hashtable[RBT_HASH_NEXTTABLE(rbt->hindex)] != NULL);
+	return rbt->hashtable[RBT_HASH_NEXTTABLE(rbt->hindex)] != NULL;
 }
 
 static bool
 hashtable_is_overcommited(dns_rbt_t *rbt) {
-	return (rbt->nodecount >=
-		(HASHSIZE(rbt->hashbits[rbt->hindex]) * RBT_HASH_OVERCOMMIT));
+	return rbt->nodecount >=
+	       (HASHSIZE(rbt->hashbits[rbt->hindex]) * RBT_HASH_OVERCOMMIT);
 }
 
 /*
@@ -2301,7 +2300,7 @@ getheight_helper(dns_rbtnode_t *node) {
 	size_t this_height, down_height;
 
 	if (node == NULL) {
-		return (0);
+		return 0;
 	}
 
 	dl = getheight_helper(LEFT(node));
@@ -2310,43 +2309,43 @@ getheight_helper(dns_rbtnode_t *node) {
 	this_height = ISC_MAX(dl + 1, dr + 1);
 	down_height = getheight_helper(DOWN(node));
 
-	return (ISC_MAX(this_height, down_height));
+	return ISC_MAX(this_height, down_height);
 }
 
 size_t
 dns__rbt_getheight(dns_rbt_t *rbt) {
-	return (getheight_helper(rbt->root));
+	return getheight_helper(rbt->root);
 }
 
 static bool
 check_properties_helper(dns_rbtnode_t *node) {
 	if (node == NULL) {
-		return (true);
+		return true;
 	}
 
 	if (IS_RED(node)) {
 		/* Root nodes must be BLACK. */
 		if (IS_ROOT(node)) {
-			return (false);
+			return false;
 		}
 
 		/* Both children of RED nodes must be BLACK. */
 		if (IS_RED(LEFT(node)) || IS_RED(RIGHT(node))) {
-			return (false);
+			return false;
 		}
 	}
 
 	if ((DOWN(node) != NULL) && (!IS_ROOT(DOWN(node)))) {
-		return (false);
+		return false;
 	}
 
 	if (IS_ROOT(node)) {
 		if ((PARENT(node) != NULL) && (DOWN(PARENT(node)) != node)) {
-			return (false);
+			return false;
 		}
 
 		if (get_upper_node(node) != PARENT(node)) {
-			return (false);
+			return false;
 		}
 	}
 
@@ -2356,13 +2355,13 @@ check_properties_helper(dns_rbtnode_t *node) {
 	if (((!PARENT(node)) || (DOWN(PARENT(node)) == node)) &&
 	    (!IS_ROOT(node)))
 	{
-		return (false);
+		return false;
 	}
 
 	/* Repeat tests with this node's children. */
-	return (check_properties_helper(LEFT(node)) &&
-		check_properties_helper(RIGHT(node)) &&
-		check_properties_helper(DOWN(node)));
+	return check_properties_helper(LEFT(node)) &&
+	       check_properties_helper(RIGHT(node)) &&
+	       check_properties_helper(DOWN(node));
 }
 
 static bool
@@ -2371,24 +2370,24 @@ check_black_distance_helper(dns_rbtnode_t *node, size_t *distance) {
 
 	if (node == NULL) {
 		*distance = 1;
-		return (true);
+		return true;
 	}
 
 	if (!check_black_distance_helper(LEFT(node), &dl)) {
-		return (false);
+		return false;
 	}
 
 	if (!check_black_distance_helper(RIGHT(node), &dr)) {
-		return (false);
+		return false;
 	}
 
 	if (!check_black_distance_helper(DOWN(node), &dd)) {
-		return (false);
+		return false;
 	}
 
 	/* Left and right side black node counts must match. */
 	if (dl != dr) {
-		return (false);
+		return false;
 	}
 
 	if (IS_BLACK(node)) {
@@ -2397,7 +2396,7 @@ check_black_distance_helper(dns_rbtnode_t *node, size_t *distance) {
 
 	*distance = dl;
 
-	return (true);
+	return true;
 }
 
 bool
@@ -2405,7 +2404,7 @@ dns__rbt_checkproperties(dns_rbt_t *rbt) {
 	size_t dd;
 
 	if (!check_properties_helper(rbt->root)) {
-		return (false);
+		return false;
 	}
 
 	/* Path from a given node to all its leaves must contain the
@@ -2413,7 +2412,7 @@ dns__rbt_checkproperties(dns_rbt_t *rbt) {
 	 * here instead of inside check_properties_helper() as
 	 * it would take (n log n) complexity otherwise.
 	 */
-	return (check_black_distance_helper(rbt->root, &dd));
+	return check_black_distance_helper(rbt->root, &dd);
 }
 
 static void
@@ -2537,7 +2536,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 	unsigned int l, r, d;
 
 	if (node == NULL) {
-		return (0);
+		return 0;
 	}
 
 	l = print_dot_helper(LEFT(node), nodecount, show_pointers, f);
@@ -2587,7 +2586,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 		fprintf(f, "\"node%u\":f2 -> \"node%u\":f1;\n", *nodecount, r);
 	}
 
-	return (*nodecount);
+	return *nodecount;
 }
 
 void
@@ -2633,7 +2632,7 @@ dns_rbtnodechain_current(dns_rbtnodechain_t *chain, dns_name_t *name,
 	}
 
 	if (chain->end == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
 	if (name != NULL) {
@@ -2664,7 +2663,7 @@ dns_rbtnodechain_current(dns_rbtnodechain_t *chain, dns_name_t *name,
 		}
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -2786,7 +2785,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 		result = ISC_R_NOMORE;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -2853,7 +2852,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 		result = ISC_R_NOMORE;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -2899,7 +2898,7 @@ dns_rbtnodechain_nextflat(dns_rbtnodechain_t *chain, dns_name_t *name) {
 		result = ISC_R_NOMORE;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -3044,7 +3043,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 		result = ISC_R_NOMORE;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -3067,7 +3066,7 @@ dns_rbtnodechain_first(dns_rbtnodechain_t *chain, dns_rbt_t *rbt,
 		result = DNS_R_NEWORIGIN;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -3084,7 +3083,7 @@ dns_rbtnodechain_last(dns_rbtnodechain_t *chain, dns_rbt_t *rbt,
 
 	result = move_chain_to_last(chain, rbt->root);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	result = dns_rbtnodechain_current(chain, name, origin, NULL);
@@ -3093,7 +3092,7 @@ dns_rbtnodechain_last(dns_rbtnodechain_t *chain, dns_rbt_t *rbt,
 		result = DNS_R_NEWORIGIN;
 	}
 
-	return (result);
+	return result;
 }
 
 void
