@@ -25,6 +25,7 @@
 #include <isc/print.h>
 #include <isc/result.h>
 #include <isc/string.h>
+#include <isc/utf8.h>
 #include <isc/util.h>
 
 #include <dns/callbacks.h>
@@ -368,24 +369,24 @@ locator_pton(const char *src, unsigned char *dst) {
 	while ((ch = *src++) != '\0') {
 		const char *pch;
 
-		pch = strchr((xdigits = xdigits_l), ch);
+		pch = strchr(xdigits = xdigits_l, ch);
 		if (pch == NULL) {
-			pch = strchr((xdigits = xdigits_u), ch);
+			pch = strchr(xdigits = xdigits_u, ch);
 		}
 		if (pch != NULL) {
 			val <<= 4;
 			val |= (pch - xdigits);
 			if (++seen_xdigits > 4) {
-				return (0);
+				return 0;
 			}
 			continue;
 		}
 		if (ch == ':') {
 			if (!seen_xdigits) {
-				return (0);
+				return 0;
 			}
 			if (tp + NS_INT16SZ > endp) {
-				return (0);
+				return 0;
 			}
 			*tp++ = (unsigned char)(val >> 8) & 0xff;
 			*tp++ = (unsigned char)val & 0xff;
@@ -393,20 +394,20 @@ locator_pton(const char *src, unsigned char *dst) {
 			val = 0;
 			continue;
 		}
-		return (0);
+		return 0;
 	}
 	if (seen_xdigits) {
 		if (tp + NS_INT16SZ > endp) {
-			return (0);
+			return 0;
 		}
 		*tp++ = (unsigned char)(val >> 8) & 0xff;
 		*tp++ = (unsigned char)val & 0xff;
 	}
 	if (tp != endp) {
-		return (0);
+		return 0;
 	}
 	memmove(dst, tmp, NS_LOCATORSZ);
-	return (1);
+	return 1;
 }
 
 static void
@@ -423,12 +424,12 @@ mem_maybedup(isc_mem_t *mctx, void *source, size_t length) {
 	void *copy;
 
 	if (mctx == NULL) {
-		return (source);
+		return source;
 	}
 	copy = isc_mem_allocate(mctx, length);
 	memmove(copy, source, length);
 
-	return (copy);
+	return copy;
 }
 
 static isc_result_t
@@ -466,7 +467,7 @@ typemap_fromtext(isc_lex_t *lexer, isc_buffer_t *target, bool allow_empty) {
 	} while (1);
 	isc_lex_ungettoken(lexer, &token);
 	if (!allow_empty && first) {
-		return (DNS_R_FORMERR);
+		return DNS_R_FORMERR;
 	}
 
 	for (window = 0; window < 256; window++) {
@@ -496,7 +497,7 @@ typemap_fromtext(isc_lex_t *lexer, isc_buffer_t *target, bool allow_empty) {
 		RETERR(uint8_tobuffer(octet + 1, target));
 		RETERR(mem_tobuffer(target, &bm[window * 32], octet + 1));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -543,7 +544,7 @@ typemap_totext(isc_region_t *sr, dns_rdata_textctx_t *tctx,
 			}
 		}
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -591,17 +592,187 @@ typemap_test(isc_region_t *sr, bool allow_empty) {
 		first = false;
 	}
 	if (i != sr->length) {
-		return (DNS_R_EXTRADATA);
+		return DNS_R_EXTRADATA;
 	}
 	if (!allow_empty && first) {
 		RETERR(DNS_R_FORMERR);
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static const char hexdigits[] = "0123456789abcdef";
 static const char decdigits[] = "0123456789";
 
+/*
+ * A relative URI template that has a "dns" variable.
+ */
+static bool
+validate_dohpath(isc_region_t *region) {
+	const unsigned char *p;
+	const unsigned char *v = NULL;
+	const unsigned char *n = NULL;
+	unsigned char c;
+	bool dns = false;
+	bool wasop = false;
+	enum {
+		path,
+		variable,
+		percent1,
+		percent2,
+		variable_percent1,
+		variable_percent2,
+		prefix,
+		explode
+	} state = path;
+
+	if (region->length == 0 || *region->base != '/' ||
+	    !isc_utf8_valid(region->base, region->length))
+	{
+		return false;
+	}
+
+	/*
+	 * RFC 6570 URI Template check + "dns" variable.
+	 */
+	p = region->base;
+	while (p < region->base + region->length) {
+		switch (state) {
+		case path:
+			switch (*p++) {
+			case '{': /*}*/
+				state = variable;
+				wasop = false;
+				v = p;
+				break;
+			case '%':
+				state = percent1;
+				break;
+			default:
+				break;
+			}
+			break;
+		case variable:
+			c = *p++;
+			switch (c) {
+			case '+':
+			case '#':
+			case '.':
+			case '/':
+			case ';':
+			case '?':
+			case '&':
+				/* Operators. */
+				if (p != v + 1 || wasop) {
+					return false;
+				}
+				wasop = true;
+				v = p;
+				break;
+			case '=':
+			case '!':
+			case '@':
+			case '|':
+				/* Reserved operators. */
+				return false;
+			case '*':
+			case ':':
+			case '}':
+			case ',':
+				/* Found the end of the variable name. */
+				if (p == (v + 1)) {
+					return false;
+				}
+				/* 'p' has been incremented so 4 not 3 */
+				if ((p - v) == 4 && memcmp(v, "dns", 3) == 0) {
+					dns = true;
+				}
+				switch (c) {
+				case ':':
+					state = prefix;
+					n = p;
+					break;
+				case /*{*/ '}':
+					state = path;
+					break;
+				case '*':
+					state = explode;
+					break;
+				case ',':
+					wasop = false;
+					v = p;
+					break;
+				}
+				break;
+			case '%':
+				/* Percent encoded variable name. */
+				state = variable_percent1;
+				break;
+			default:
+				/* Valid variable name character? */
+				if (c != '_' && !isalnum(c)) {
+					return false;
+				}
+				break;
+			}
+			break;
+		case explode:
+			switch (*p++) {
+			case ',':
+				state = variable;
+				wasop = false;
+				v = p;
+				break;
+			case /*}*/ '}':
+				state = path;
+				break;
+			default:
+				return false;
+			}
+			break;
+		/* Check % encoding */
+		case percent1:
+		case percent2:
+		case variable_percent1:
+		case variable_percent2:
+			/* bad percent encoding? */
+			if (!isxdigit(*p++)) {
+				return false;
+			}
+			if (state == percent1) {
+				state = percent2;
+			} else if (state == percent2) {
+				state = path;
+			} else if (state == variable_percent1) {
+				state = variable_percent2;
+			} else {
+				state = variable;
+			}
+			break;
+		case prefix:
+			c = *p++;
+			if (!isdigit(c)) {
+				/* valid number range [1..9999] */
+				if ((p == n + 1) || (p - n) > 5 || *n == '0') {
+					return false;
+				}
+				switch (c) {
+				case ',':
+					state = variable;
+					wasop = false;
+					break;
+				case /*{*/ '}':
+					state = path;
+					break;
+				default:
+					return false;
+				}
+			}
+			break;
+		}
+	}
+	return state == path && dns;
+}
+
 #include "code.h"
 
 #define META	 0x0001
@@ -676,11 +847,11 @@ dns_rdata_compare(const dns_rdata_t *rdata1, const dns_rdata_t *rdata2) {
 	REQUIRE(DNS_RDATA_VALIDFLAGS(rdata2));
 
 	if (rdata1->rdclass != rdata2->rdclass) {
-		return (rdata1->rdclass < rdata2->rdclass ? -1 : 1);
+		return rdata1->rdclass < rdata2->rdclass ? -1 : 1;
 	}
 
 	if (rdata1->type != rdata2->type) {
-		return (rdata1->type < rdata2->type ? -1 : 1);
+		return rdata1->type < rdata2->type ? -1 : 1;
 	}
 
 	COMPARESWITCH
@@ -693,7 +864,7 @@ dns_rdata_compare(const dns_rdata_t *rdata1, const dns_rdata_t *rdata2) {
 		dns_rdata_toregion(rdata2, &r2);
 		result = isc_region_compare(&r1, &r2);
 	}
-	return (result);
+	return result;
 }
 
 int
@@ -709,11 +880,11 @@ dns_rdata_casecompare(const dns_rdata_t *rdata1, const dns_rdata_t *rdata2) {
 	REQUIRE(DNS_RDATA_VALIDFLAGS(rdata2));
 
 	if (rdata1->rdclass != rdata2->rdclass) {
-		return (rdata1->rdclass < rdata2->rdclass ? -1 : 1);
+		return rdata1->rdclass < rdata2->rdclass ? -1 : 1;
 	}
 
 	if (rdata1->type != rdata2->type) {
-		return (rdata1->type < rdata2->type ? -1 : 1);
+		return rdata1->type < rdata2->type ? -1 : 1;
 	}
 
 	CASECOMPARESWITCH
@@ -726,7 +897,7 @@ dns_rdata_casecompare(const dns_rdata_t *rdata1, const dns_rdata_t *rdata2) {
 		dns_rdata_toregion(rdata2, &r2);
 		result = isc_region_compare(&r1, &r2);
 	}
-	return (result);
+	return result;
 }
 
 /***
@@ -781,7 +952,7 @@ dns_rdata_fromwire(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 	REQUIRE(target != NULL);
 
 	if (type == 0) {
-		return (DNS_R_FORMERR);
+		return DNS_R_FORMERR;
 	}
 
 	ss = *source;
@@ -829,7 +1000,7 @@ dns_rdata_fromwire(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 		*source = ss;
 		*target = st;
 	}
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -848,7 +1019,7 @@ dns_rdata_towire(dns_rdata_t *rdata, dns_compress_t *cctx,
 	 */
 	if ((rdata->flags & DNS_RDATA_UPDATE) != 0) {
 		INSIST(rdata->length == 0);
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	st = *target;
@@ -858,18 +1029,18 @@ dns_rdata_towire(dns_rdata_t *rdata, dns_compress_t *cctx,
 	if (use_default) {
 		isc_buffer_availableregion(target, &tr);
 		if (tr.length < rdata->length) {
-			return (ISC_R_NOSPACE);
+			return ISC_R_NOSPACE;
 		}
 		memmove(tr.base, rdata->data, rdata->length);
 		isc_buffer_add(target, rdata->length);
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	if (result != ISC_R_SUCCESS) {
 		*target = st;
 		INSIST(target->used < 65536);
 		dns_compress_rollback(cctx, (uint16_t)target->used);
 	}
-	return (result);
+	return result;
 }
 
 /*
@@ -888,7 +1059,7 @@ rdata_validate(isc_buffer_t *src, isc_buffer_t *dest, dns_rdataclass_t rdclass,
 	result = dns_rdata_fromwire(NULL, rdclass, type, src, &dctx, 0, dest);
 	dns_decompress_invalidate(&dctx);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -899,13 +1070,13 @@ unknown_fromtext(dns_rdataclass_t rdclass, dns_rdatatype_t type,
 	isc_token_t token;
 
 	if (type == 0 || dns_rdatatype_ismeta(type)) {
-		return (DNS_R_METATYPE);
+		return DNS_R_METATYPE;
 	}
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
 				      false));
 	if (token.value.as_ulong > 65535U) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	isc_buffer_allocate(mctx, &buf, token.value.as_ulong);
 
@@ -933,11 +1104,11 @@ unknown_fromtext(dns_rdataclass_t rdclass, dns_rdatatype_t type,
 	}
 
 	isc_buffer_free(&buf);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	isc_buffer_free(&buf);
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -983,7 +1154,7 @@ dns_rdata_fromtext(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 		name = isc_lex_getsourcename(lexer);
 		line = isc_lex_getsourceline(lexer);
 		fromtext_error(callback, callbacks, name, line, NULL, result);
-		return (result);
+		return result;
 	}
 
 	unknown = false;
@@ -1072,7 +1243,7 @@ dns_rdata_fromtext(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 	if (result != ISC_R_SUCCESS) {
 		*target = st;
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1085,7 +1256,7 @@ unknown_totext(dns_rdata_t *rdata, dns_rdata_textctx_t *tctx,
 	strlcpy(buf, "\\# ", sizeof(buf));
 	result = str_totext(buf, target);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	dns_rdata_toregion(rdata, &sr);
@@ -1093,7 +1264,7 @@ unknown_totext(dns_rdata_t *rdata, dns_rdata_textctx_t *tctx,
 	snprintf(buf, sizeof(buf), "%u", sr.length);
 	result = str_totext(buf, target);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	if (sr.length != 0U) {
@@ -1104,7 +1275,7 @@ unknown_totext(dns_rdata_t *rdata, dns_rdata_textctx_t *tctx,
 		}
 
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 
 		if (tctx->width == 0) { /* No splitting */
@@ -1119,7 +1290,7 @@ unknown_totext(dns_rdata_t *rdata, dns_rdata_textctx_t *tctx,
 			result = str_totext(" )", target);
 		}
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1137,11 +1308,11 @@ rdata_totext(dns_rdata_t *rdata, dns_rdata_textctx_t *tctx,
 	 */
 	if ((rdata->flags & DNS_RDATA_UPDATE) != 0) {
 		INSIST(rdata->length == 0);
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	if ((tctx->flags & DNS_STYLEFLAG_UNKNOWNFORMAT) != 0) {
-		return (unknown_totext(rdata, tctx, target));
+		return unknown_totext(rdata, tctx, target);
 	}
 
 	cur = isc_buffer_usedlength(target);
@@ -1156,7 +1327,7 @@ rdata_totext(dns_rdata_t *rdata, dns_rdata_textctx_t *tctx,
 		result = unknown_totext(rdata, tctx, target);
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1173,7 +1344,7 @@ dns_rdata_totext(dns_rdata_t *rdata, const dns_name_t *origin,
 	tctx.flags = 0;
 	tctx.width = 60;
 	tctx.linebreak = " ";
-	return (rdata_totext(rdata, &tctx, target));
+	return rdata_totext(rdata, &tctx, target);
 }
 
 isc_result_t
@@ -1204,7 +1375,7 @@ dns_rdata_tofmttext(dns_rdata_t *rdata, const dns_name_t *origin,
 		}
 		tctx.linebreak = " ";
 	}
-	return (rdata_totext(rdata, &tctx, target));
+	return rdata_totext(rdata, &tctx, target);
 }
 
 isc_result_t
@@ -1243,7 +1414,7 @@ dns_rdata_fromstruct(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 	if (result != ISC_R_SUCCESS) {
 		*target = st;
 	}
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1261,7 +1432,7 @@ dns_rdata_tostruct(const dns_rdata_t *rdata, void *target, isc_mem_t *mctx) {
 		(void)NULL;
 	}
 
-	return (result);
+	return result;
 }
 
 void
@@ -1294,7 +1465,7 @@ dns_rdata_additionaldata(dns_rdata_t *rdata, const dns_name_t *owner,
 		result = ISC_R_SUCCESS;
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1318,7 +1489,7 @@ dns_rdata_digest(dns_rdata_t *rdata, dns_digestfunc_t digest, void *arg) {
 		result = (digest)(arg, &r);
 	}
 
-	return (result);
+	return result;
 }
 
 bool
@@ -1327,7 +1498,7 @@ dns_rdata_checkowner(const dns_name_t *name, dns_rdataclass_t rdclass,
 	bool result;
 
 	CHECKOWNERSWITCH
-	return (result);
+	return result;
 }
 
 bool
@@ -1336,16 +1507,16 @@ dns_rdata_checknames(dns_rdata_t *rdata, const dns_name_t *owner,
 	bool result;
 
 	CHECKNAMESSWITCH
-	return (result);
+	return result;
 }
 
 unsigned int
 dns_rdatatype_attributes(dns_rdatatype_t type) {
 	RDATATYPE_ATTRIBUTE_SW
 	if (type >= (dns_rdatatype_t)128 && type <= (dns_rdatatype_t)255) {
-		return (DNS_RDATATYPEATTR_UNKNOWN | DNS_RDATATYPEATTR_META);
+		return DNS_RDATATYPEATTR_UNKNOWN | DNS_RDATATYPEATTR_META;
 	}
-	return (DNS_RDATATYPEATTR_UNKNOWN);
+	return DNS_RDATATYPEATTR_UNKNOWN;
 }
 
 isc_result_t
@@ -1357,7 +1528,7 @@ dns_rdatatype_fromtext(dns_rdatatype_t *typep, isc_textregion_t *source) {
 	n = source->length;
 
 	if (n == 0) {
-		return (DNS_R_UNKNOWN);
+		return DNS_R_UNKNOWN;
 	}
 
 	a = tolower((unsigned char)source->base[0]);
@@ -1388,18 +1559,18 @@ dns_rdatatype_fromtext(dns_rdatatype_t *typep, isc_textregion_t *source) {
 		val = strtoul(buf, &endp, 10);
 		if (*endp == '\0' && val <= 0xffff) {
 			*typep = (dns_rdatatype_t)val;
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		}
 	}
 
-	return (DNS_R_UNKNOWN);
+	return DNS_R_UNKNOWN;
 }
 
 isc_result_t
 dns_rdatatype_totext(dns_rdatatype_t type, isc_buffer_t *target) {
 	RDATATYPE_TOTEXT_SW
 
-	return (dns_rdatatype_tounknowntext(type, target));
+	return dns_rdatatype_tounknowntext(type, target);
 }
 
 isc_result_t
@@ -1407,7 +1578,7 @@ dns_rdatatype_tounknowntext(dns_rdatatype_t type, isc_buffer_t *target) {
 	char buf[sizeof("TYPE65535")];
 
 	snprintf(buf, sizeof(buf), "TYPE%u", type);
-	return (str_totext(buf, target));
+	return str_totext(buf, target);
 }
 
 void
@@ -1442,7 +1613,7 @@ dns_rdatatype_format(dns_rdatatype_t rdtype, char *array, unsigned int size) {
 
 static unsigned int
 name_length(const dns_name_t *name) {
-	return (name->length);
+	return name->length;
 }
 
 static isc_result_t
@@ -1468,7 +1639,7 @@ commatxt_totext(isc_region_t *source, bool quote, bool comma,
 
 	if (quote) {
 		if (tl < 1) {
-			return (ISC_R_NOSPACE);
+			return ISC_R_NOSPACE;
 		}
 		*tp++ = '"';
 		tl--;
@@ -1479,7 +1650,7 @@ commatxt_totext(isc_region_t *source, bool quote, bool comma,
 		 */
 		if (*sp < (quote ? ' ' : '!') || *sp >= 0x7f) {
 			if (tl < 4) {
-				return (ISC_R_NOSPACE);
+				return ISC_R_NOSPACE;
 			}
 			*tp++ = '\\';
 			*tp++ = '0' + ((*sp / 100) % 10);
@@ -1499,7 +1670,7 @@ commatxt_totext(isc_region_t *source, bool quote, bool comma,
 		    (!comma && !quote && (*sp == '@' || *sp == ';')))
 		{
 			if (tl < 2) {
-				return (ISC_R_NOSPACE);
+				return ISC_R_NOSPACE;
 			}
 			*tp++ = '\\';
 			tl--;
@@ -1510,7 +1681,7 @@ commatxt_totext(isc_region_t *source, bool quote, bool comma,
 			 */
 			if (comma && (*sp == ',' || *sp == '\\')) {
 				if (tl < ((*sp == '\\') ? 3 : 2)) {
-					return (ISC_R_NOSPACE);
+					return ISC_R_NOSPACE;
 				}
 				*tp++ = '\\';
 				tl--;
@@ -1521,14 +1692,14 @@ commatxt_totext(isc_region_t *source, bool quote, bool comma,
 			}
 		}
 		if (tl < 1) {
-			return (ISC_R_NOSPACE);
+			return ISC_R_NOSPACE;
 		}
 		*tp++ = *sp++;
 		tl--;
 	}
 	if (quote) {
 		if (tl < 1) {
-			return (ISC_R_NOSPACE);
+			return ISC_R_NOSPACE;
 		}
 		*tp++ = '"';
 		tl--;
@@ -1536,12 +1707,12 @@ commatxt_totext(isc_region_t *source, bool quote, bool comma,
 	}
 	isc_buffer_add(target, (unsigned int)(tp - (char *)region.base));
 	isc_region_consume(source, *source->base + 1);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 txt_totext(isc_region_t *source, bool quote, isc_buffer_t *target) {
-	return (commatxt_totext(source, quote, false, target));
+	return commatxt_totext(source, quote, false, target);
 }
 
 static isc_result_t
@@ -1560,7 +1731,7 @@ commatxt_fromtext(isc_textregion_t *source, bool comma, isc_buffer_t *target) {
 	t = tregion.base;
 	nrem = tregion.length;
 	if (nrem < 1) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	/*
 	 * Length byte.
@@ -1578,25 +1749,25 @@ commatxt_fromtext(isc_textregion_t *source, bool comma, isc_buffer_t *target) {
 		if (escape && (d = decvalue((char)c)) != -1) {
 			c = d;
 			if (n == 0) {
-				return (DNS_R_SYNTAX);
+				return DNS_R_SYNTAX;
 			}
 			n--;
 			if ((d = decvalue(*s++)) != -1) {
 				c = c * 10 + d;
 			} else {
-				return (DNS_R_SYNTAX);
+				return DNS_R_SYNTAX;
 			}
 			if (n == 0) {
-				return (DNS_R_SYNTAX);
+				return DNS_R_SYNTAX;
 			}
 			n--;
 			if ((d = decvalue(*s++)) != -1) {
 				c = c * 10 + d;
 			} else {
-				return (DNS_R_SYNTAX);
+				return DNS_R_SYNTAX;
 			}
 			if (c > 255) {
-				return (DNS_R_SYNTAX);
+				return DNS_R_SYNTAX;
 			}
 		} else if (!escape && c == '\\') {
 			escape = true;
@@ -1623,8 +1794,8 @@ commatxt_fromtext(isc_textregion_t *source, bool comma, isc_buffer_t *target) {
 		}
 		comma_escape = false;
 		if (nrem == 0) {
-			return ((tregion.length <= 256U) ? ISC_R_NOSPACE
-							 : DNS_R_SYNTAX);
+			return (tregion.length <= 256U) ? ISC_R_NOSPACE
+							: DNS_R_SYNTAX;
 		}
 		*t++ = c;
 		nrem--;
@@ -1634,7 +1805,7 @@ commatxt_fromtext(isc_textregion_t *source, bool comma, isc_buffer_t *target) {
 	 * Incomplete escape processing?
 	 */
 	if (escape || (comma && comma_escape)) {
-		return (DNS_R_SYNTAX);
+		return DNS_R_SYNTAX;
 	}
 
 	if (comma) {
@@ -1643,7 +1814,7 @@ commatxt_fromtext(isc_textregion_t *source, bool comma, isc_buffer_t *target) {
 		 * in the middle ("h1,,h2" or "h1\,\,h2").
 		 */
 		if ((t - tregion.base - 1) == 0) {
-			return (DNS_R_SYNTAX);
+			return DNS_R_SYNTAX;
 		}
 
 		/*
@@ -1655,18 +1826,18 @@ commatxt_fromtext(isc_textregion_t *source, bool comma, isc_buffer_t *target) {
 		 * Disallow empty ALPN at end ("h1," or "h1\,").
 		 */
 		if (seen_comma && source->length == 0) {
-			return (DNS_R_SYNTAX);
+			return DNS_R_SYNTAX;
 		}
 	}
 
 	*tregion.base = (unsigned char)(t - tregion.base - 1);
 	isc_buffer_add(target, *tregion.base + 1);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 txt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
-	return (commatxt_fromtext(source, false, target));
+	return commatxt_fromtext(source, false, target);
 }
 
 static isc_result_t
@@ -1677,16 +1848,16 @@ txt_fromwire(isc_buffer_t *source, isc_buffer_t *target) {
 
 	isc_buffer_activeregion(source, &sregion);
 	if (sregion.length == 0) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	n = *sregion.base + 1;
 	if (n > sregion.length) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	isc_buffer_availableregion(target, &tregion);
 	if (n > tregion.length) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	if (tregion.base != sregion.base) {
@@ -1694,7 +1865,7 @@ txt_fromwire(isc_buffer_t *source, isc_buffer_t *target) {
 	}
 	isc_buffer_forward(source, n);
 	isc_buffer_add(target, n);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -1714,7 +1885,7 @@ multitxt_totext(isc_region_t *source, isc_buffer_t *target) {
 	tl = region.length;
 
 	if (tl < 1) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	*tp++ = '"';
 	tl--;
@@ -1725,7 +1896,7 @@ multitxt_totext(isc_region_t *source, isc_buffer_t *target) {
 		while (n--) {
 			if (*sp < ' ' || *sp >= 0x7f) {
 				if (tl < 4) {
-					return (ISC_R_NOSPACE);
+					return ISC_R_NOSPACE;
 				}
 				*tp++ = '\\';
 				*tp++ = '0' + ((*sp / 100) % 10);
@@ -1738,13 +1909,13 @@ multitxt_totext(isc_region_t *source, isc_buffer_t *target) {
 			/* double quote, backslash */
 			if (*sp == '"' || *sp == '\\') {
 				if (tl < 2) {
-					return (ISC_R_NOSPACE);
+					return ISC_R_NOSPACE;
 				}
 				*tp++ = '\\';
 				tl--;
 			}
 			if (tl < 1) {
-				return (ISC_R_NOSPACE);
+				return ISC_R_NOSPACE;
 			}
 			*tp++ = *sp++;
 			tl--;
@@ -1752,13 +1923,13 @@ multitxt_totext(isc_region_t *source, isc_buffer_t *target) {
 		isc_region_consume(source, n0 + 1);
 	} while (source->length != 0);
 	if (tl < 1) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	*tp++ = '"';
 	tl--;
 	POST(tl);
 	isc_buffer_add(target, (unsigned int)(tp - (char *)region.base));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1780,7 +1951,7 @@ multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 		t0 = t = tregion.base;
 		nrem = tregion.length;
 		if (nrem < 1) {
-			return (ISC_R_NOSPACE);
+			return ISC_R_NOSPACE;
 		}
 
 		while (n != 0) {
@@ -1789,25 +1960,25 @@ multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 			if (escape && (d = decvalue((char)c)) != -1) {
 				c = d;
 				if (n == 0) {
-					return (DNS_R_SYNTAX);
+					return DNS_R_SYNTAX;
 				}
 				n--;
 				if ((d = decvalue(*s++)) != -1) {
 					c = c * 10 + d;
 				} else {
-					return (DNS_R_SYNTAX);
+					return DNS_R_SYNTAX;
 				}
 				if (n == 0) {
-					return (DNS_R_SYNTAX);
+					return DNS_R_SYNTAX;
 				}
 				n--;
 				if ((d = decvalue(*s++)) != -1) {
 					c = c * 10 + d;
 				} else {
-					return (DNS_R_SYNTAX);
+					return DNS_R_SYNTAX;
 				}
 				if (c > 255) {
-					return (DNS_R_SYNTAX);
+					return DNS_R_SYNTAX;
 				}
 			} else if (!escape && c == '\\') {
 				escape = true;
@@ -1821,12 +1992,12 @@ multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 			}
 		}
 		if (escape) {
-			return (DNS_R_SYNTAX);
+			return DNS_R_SYNTAX;
 		}
 
 		isc_buffer_add(target, (unsigned int)(t - t0));
 	} while (n != 0);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static bool
@@ -1859,11 +2030,11 @@ name_prefix(dns_name_t *name, const dns_name_t *origin, dns_name_t *target) {
 	}
 
 	dns_name_getlabelsequence(name, 0, l1 - l2, target);
-	return (true);
+	return true;
 
 return_false:
 	*target = *name;
-	return (false);
+	return false;
 }
 
 static isc_result_t
@@ -1875,12 +2046,12 @@ str_totext(const char *source, isc_buffer_t *target) {
 	l = strlen(source);
 
 	if (l > region.length) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(region.base, source, l);
 	isc_buffer_add(target, l);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1889,10 +2060,10 @@ inet_totext(int af, uint32_t flags, isc_region_t *src, isc_buffer_t *target) {
 
 	/* Note - inet_ntop doesn't do size checking on its input. */
 	if (inet_ntop(af, src->base, tmpbuf, sizeof(tmpbuf)) == NULL) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	if (strlen(tmpbuf) > isc_buffer_availablelength(target)) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	isc_buffer_putstr(target, tmpbuf);
 
@@ -1905,19 +2076,19 @@ inet_totext(int af, uint32_t flags, isc_region_t *src, isc_buffer_t *target) {
 		isc_buffer_usedregion(target, &r);
 		if (r.length > 0 && r.base[r.length - 1] == ':') {
 			if (isc_buffer_availablelength(target) == 0) {
-				return (ISC_R_NOSPACE);
+				return ISC_R_NOSPACE;
 			}
 			isc_buffer_putmem(target, (const unsigned char *)"0",
 					  1);
 		}
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static bool
 buffer_empty(isc_buffer_t *source) {
-	return ((source->current == source->active) ? true : false);
+	return (source->current == source->active) ? true : false;
 }
 
 static void
@@ -1933,10 +2104,10 @@ uint32_tobuffer(uint32_t value, isc_buffer_t *target) {
 
 	isc_buffer_availableregion(target, &region);
 	if (region.length < 4) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	isc_buffer_putuint32(target, value);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1944,14 +2115,14 @@ uint16_tobuffer(uint32_t value, isc_buffer_t *target) {
 	isc_region_t region;
 
 	if (value > 0xffff) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	isc_buffer_availableregion(target, &region);
 	if (region.length < 2) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	isc_buffer_putuint16(target, (uint16_t)value);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1959,21 +2130,21 @@ uint8_tobuffer(uint32_t value, isc_buffer_t *target) {
 	isc_region_t region;
 
 	if (value > 0xff) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	isc_buffer_availableregion(target, &region);
 	if (region.length < 1) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	isc_buffer_putuint8(target, (uint8_t)value);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 name_tobuffer(const dns_name_t *name, isc_buffer_t *target) {
 	isc_region_t r;
 	dns_name_toregion(name, &r);
-	return (isc_buffer_copyregion(target, &r));
+	return isc_buffer_copyregion(target, &r);
 }
 
 static uint32_t
@@ -1985,7 +2156,7 @@ uint32_fromregion(isc_region_t *region) {
 	value |= (uint32_t)region->base[1] << 16;
 	value |= (uint32_t)region->base[2] << 8;
 	value |= (uint32_t)region->base[3];
-	return (value);
+	return value;
 }
 
 static uint16_t
@@ -1993,21 +2164,21 @@ uint16_consume_fromregion(isc_region_t *region) {
 	uint16_t r = uint16_fromregion(region);
 
 	isc_region_consume(region, 2);
-	return (r);
+	return r;
 }
 
 static uint16_t
 uint16_fromregion(isc_region_t *region) {
 	REQUIRE(region->length >= 2);
 
-	return ((region->base[0] << 8) | region->base[1]);
+	return (region->base[0] << 8) | region->base[1];
 }
 
 static uint8_t
 uint8_fromregion(isc_region_t *region) {
 	REQUIRE(region->length >= 1);
 
-	return (region->base[0]);
+	return region->base[0];
 }
 
 static uint8_t
@@ -2015,7 +2186,7 @@ uint8_consume_fromregion(isc_region_t *region) {
 	uint8_t r = uint8_fromregion(region);
 
 	isc_region_consume(region, 1);
-	return (r);
+	return r;
 }
 
 static isc_result_t
@@ -2023,18 +2194,18 @@ mem_tobuffer(isc_buffer_t *target, void *base, unsigned int length) {
 	isc_region_t tr;
 
 	if (length == 0U) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	isc_buffer_availableregion(target, &tr);
 	if (length > tr.length) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	if (tr.base != base) {
 		memmove(tr.base, base, length);
 	}
 	isc_buffer_add(target, length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static int
@@ -2045,15 +2216,15 @@ hexvalue(char value) {
 	c = (unsigned char)value;
 
 	if (!isascii(c)) {
-		return (-1);
+		return -1;
 	}
 	if (isupper(c)) {
 		c = tolower(c);
 	}
 	if ((s = strchr(hexdigits, c)) == NULL) {
-		return (-1);
+		return -1;
 	}
-	return ((int)(s - hexdigits));
+	return (int)(s - hexdigits);
 }
 
 static int
@@ -2065,12 +2236,12 @@ decvalue(char value) {
 	 * mask or cast.
 	 */
 	if (!isascii((unsigned char)value)) {
-		return (-1);
+		return -1;
 	}
 	if ((s = strchr(decdigits, value)) == NULL) {
-		return (-1);
+		return -1;
 	}
-	return ((int)(s - decdigits));
+	return (int)(s - decdigits);
 }
 
 static void
@@ -2179,26 +2350,26 @@ fromtext_error(void (*callback)(dns_rdatacallbacks_t *, const char *, ...),
 dns_rdatatype_t
 dns_rdata_covers(dns_rdata_t *rdata) {
 	if (rdata->type == dns_rdatatype_rrsig) {
-		return (covers_rrsig(rdata));
+		return covers_rrsig(rdata);
 	}
-	return (covers_sig(rdata));
+	return covers_sig(rdata);
 }
 
 bool
 dns_rdatatype_ismeta(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_META) != 0) {
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
 dns_rdatatype_issingleton(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_SINGLETON) != 0)
 	{
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
@@ -2206,9 +2377,9 @@ dns_rdatatype_notquestion(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_NOTQUESTION) !=
 	    0)
 	{
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
@@ -2216,26 +2387,26 @@ dns_rdatatype_questiononly(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_QUESTIONONLY) !=
 	    0)
 	{
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
 dns_rdatatype_atcname(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_ATCNAME) != 0) {
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
 dns_rdatatype_atparent(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_ATPARENT) != 0)
 	{
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
@@ -2243,9 +2414,9 @@ dns_rdatatype_followadditional(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) &
 	     DNS_RDATATYPEATTR_FOLLOWADDITIONAL) != 0)
 	{
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
@@ -2253,24 +2424,24 @@ dns_rdataclass_ismeta(dns_rdataclass_t rdclass) {
 	if (rdclass == dns_rdataclass_reserved0 ||
 	    rdclass == dns_rdataclass_none || rdclass == dns_rdataclass_any)
 	{
-		return (true);
+		return true;
 	}
 
-	return (false); /* Assume it is not a meta class. */
+	return false; /* Assume it is not a meta class. */
 }
 
 bool
 dns_rdatatype_isdnssec(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_DNSSEC) != 0) {
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
 dns_rdatatype_iskeymaterial(dns_rdatatype_t type) {
-	return (type == dns_rdatatype_dnskey || type == dns_rdatatype_cdnskey ||
-		type == dns_rdatatype_cds);
+	return type == dns_rdatatype_dnskey || type == dns_rdatatype_cdnskey ||
+	       type == dns_rdatatype_cds;
 }
 
 bool
@@ -2278,17 +2449,17 @@ dns_rdatatype_iszonecutauth(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_ZONECUTAUTH) !=
 	    0)
 	{
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 bool
 dns_rdatatype_isknown(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_UNKNOWN) == 0) {
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 void
@@ -2345,34 +2516,34 @@ dns_rdata_updateop(dns_rdata_t *rdata, dns_section_t section) {
 		case dns_rdataclass_none:
 			switch (rdata->type) {
 			case dns_rdatatype_any:
-				return ("domain doesn't exist");
+				return "domain doesn't exist";
 			default:
-				return ("rrset doesn't exist");
+				return "rrset doesn't exist";
 			}
 		case dns_rdataclass_any:
 			switch (rdata->type) {
 			case dns_rdatatype_any:
-				return ("domain exists");
+				return "domain exists";
 			default:
-				return ("rrset exists (value independent)");
+				return "rrset exists (value independent)";
 			}
 		default:
-			return ("rrset exists (value dependent)");
+			return "rrset exists (value dependent)";
 		}
 	case DNS_SECTION_UPDATE:
 		switch (rdata->rdclass) {
 		case dns_rdataclass_none:
-			return ("delete");
+			return "delete";
 		case dns_rdataclass_any:
 			switch (rdata->type) {
 			case dns_rdatatype_any:
-				return ("delete all rrsets");
+				return "delete all rrsets";
 			default:
-				return ("delete rrset");
+				return "delete rrset";
 			}
 		default:
-			return ("add");
+			return "add";
 		}
 	}
-	return ("invalid");
+	return "invalid";
 }
