@@ -24,7 +24,7 @@ static isc_result_t
 fromtext_cds(ARGS_FROMTEXT) {
 	REQUIRE(type == dns_rdatatype_cds);
 
-	return (generic_fromtext_ds(CALL_FROMTEXT));
+	return generic_fromtext_ds(CALL_FROMTEXT);
 }
 
 static isc_result_t
@@ -32,14 +32,14 @@ totext_cds(ARGS_TOTEXT) {
 	REQUIRE(rdata != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_cds);
 
-	return (generic_totext_ds(CALL_TOTEXT));
+	return generic_totext_ds(CALL_TOTEXT);
 }
 
 static isc_result_t
 fromwire_cds(ARGS_FROMWIRE) {
 	REQUIRE(type == dns_rdatatype_cds);
 
-	return (generic_fromwire_ds(CALL_FROMWIRE));
+	return generic_fromwire_ds(CALL_FROMWIRE);
 }
 
 static isc_result_t
@@ -52,7 +52,7 @@ towire_cds(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static int
@@ -68,14 +68,14 @@ compare_cds(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
 fromstruct_cds(ARGS_FROMSTRUCT) {
 	REQUIRE(type == dns_rdatatype_cds);
 
-	return (generic_fromstruct_ds(CALL_FROMSTRUCT));
+	return generic_fromstruct_ds(CALL_FROMSTRUCT);
 }
 
 static isc_result_t
@@ -93,7 +93,7 @@ tostruct_cds(ARGS_TOSTRUCT) {
 	cds->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&cds->common, link);
 
-	return (generic_tostruct_ds(CALL_TOSTRUCT));
+	return generic_tostruct_ds(CALL_TOSTRUCT);
 }
 
 static void
@@ -122,7 +122,7 @@ additionaldata_cds(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -133,7 +133,7 @@ digest_cds(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -145,7 +145,7 @@ checkowner_cds(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -156,12 +156,12 @@ checknames_cds(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_cds(ARGS_COMPARE) {
-	return (compare_cds(rdata1, rdata2));
+	return compare_cds(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_CDS_59_C */
