@@ -58,7 +58,7 @@ fromtext_cert(ARGS_FROMTEXT) {
 	RETTOK(dns_secalg_fromtext(&secalg, &token.value.as_textregion));
 	RETERR(mem_tobuffer(target, &secalg, 1));
 
-	return (isc_base64_tobuffer(lexer, target, -2));
+	return isc_base64_tobuffer(lexer, target, -2);
 }
 
 static isc_result_t
@@ -112,7 +112,7 @@ totext_cert(ARGS_TOTEXT) {
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
 		RETERR(str_totext(" )", target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -128,11 +128,11 @@ fromwire_cert(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &sr);
 	if (sr.length < 6) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	isc_buffer_forward(source, sr.length);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static isc_result_t
@@ -145,7 +145,7 @@ towire_cert(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static int
@@ -161,7 +161,7 @@ compare_cert(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
@@ -180,7 +180,7 @@ fromstruct_cert(ARGS_FROMSTRUCT) {
 	RETERR(uint16_tobuffer(cert->key_tag, target));
 	RETERR(uint8_tobuffer(cert->algorithm, target));
 
-	return (mem_tobuffer(target, cert->certificate, cert->length));
+	return mem_tobuffer(target, cert->certificate, cert->length);
 }
 
 static isc_result_t
@@ -208,11 +208,11 @@ tostruct_cert(ARGS_TOSTRUCT) {
 
 	cert->certificate = mem_maybedup(mctx, region.base, region.length);
 	if (cert->certificate == NULL) {
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	}
 
 	cert->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -241,7 +241,7 @@ additionaldata_cert(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -252,7 +252,7 @@ digest_cert(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -264,7 +264,7 @@ checkowner_cert(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -275,11 +275,11 @@ checknames_cert(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_cert(ARGS_COMPARE) {
-	return (compare_cert(rdata1, rdata2));
+	return compare_cert(rdata1, rdata2);
 }
 #endif /* RDATA_GENERIC_CERT_37_C */
