@@ -11,13 +11,10 @@
  * information regarding copyright ownership.
  */
 
-#ifndef GENERIC_CNAME_5_H
-#define GENERIC_CNAME_5_H 1
+#pragma once
 
 typedef struct dns_rdata_cname {
 	dns_rdatacommon_t common;
 	isc_mem_t *mctx;
 	dns_name_t cname;
 } dns_rdata_cname_t;
-
-#endif /* GENERIC_CNAME_5_H */
