@@ -40,7 +40,7 @@ fromtext_eui48(ARGS_FROMTEXT) {
 	if (n != 6 || l0 > 255U || l1 > 255U || l2 > 255U || l3 > 255U ||
 	    l4 > 255U || l5 > 255U)
 	{
-		return (DNS_R_BADEUI);
+		return DNS_R_BADEUI;
 	}
 
 	eui48[0] = l0;
@@ -49,7 +49,7 @@ fromtext_eui48(ARGS_FROMTEXT) {
 	eui48[3] = l3;
 	eui48[4] = l4;
 	eui48[5] = l5;
-	return (mem_tobuffer(target, eui48, sizeof(eui48)));
+	return mem_tobuffer(target, eui48, sizeof(eui48));
 }
 
 static isc_result_t
@@ -64,7 +64,7 @@ totext_eui48(ARGS_TOTEXT) {
 	(void)snprintf(buf, sizeof(buf), "%02x-%02x-%02x-%02x-%02x-%02x",
 		       rdata->data[0], rdata->data[1], rdata->data[2],
 		       rdata->data[3], rdata->data[4], rdata->data[5]);
-	return (str_totext(buf, target));
+	return str_totext(buf, target);
 }
 
 static isc_result_t
@@ -80,10 +80,10 @@ fromwire_eui48(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &sregion);
 	if (sregion.length != 6) {
-		return (DNS_R_FORMERR);
+		return DNS_R_FORMERR;
 	}
 	isc_buffer_forward(source, sregion.length);
-	return (mem_tobuffer(target, sregion.base, sregion.length));
+	return mem_tobuffer(target, sregion.base, sregion.length);
 }
 
 static isc_result_t
@@ -93,7 +93,7 @@ towire_eui48(ARGS_TOWIRE) {
 
 	UNUSED(cctx);
 
-	return (mem_tobuffer(target, rdata->data, rdata->length));
+	return mem_tobuffer(target, rdata->data, rdata->length);
 }
 
 static int
@@ -109,7 +109,7 @@ compare_eui48(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &region1);
 	dns_rdata_toregion(rdata2, &region2);
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 
 static isc_result_t
@@ -124,7 +124,7 @@ fromstruct_eui48(ARGS_FROMSTRUCT) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	return (mem_tobuffer(target, eui48->eui48, sizeof(eui48->eui48)));
+	return mem_tobuffer(target, eui48->eui48, sizeof(eui48->eui48));
 }
 
 static isc_result_t
@@ -142,7 +142,7 @@ tostruct_eui48(ARGS_TOSTRUCT) {
 	ISC_LINK_INIT(&eui48->common, link);
 
 	memmove(eui48->eui48, rdata->data, rdata->length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -165,7 +165,7 @@ additionaldata_eui48(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -177,7 +177,7 @@ digest_eui48(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -189,7 +189,7 @@ checkowner_eui48(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -201,12 +201,12 @@ checknames_eui48(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_eui48(ARGS_COMPARE) {
-	return (compare_eui48(rdata1, rdata2));
+	return compare_eui48(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_EUI48_108_C */
