@@ -29,10 +29,10 @@ loc_getdecimal(const char *str, unsigned long max, size_t precision, char units,
 
 	value = strtoul(str, &e, 10);
 	if (*e != 0 && *e != '.' && *e != units) {
-		return (DNS_R_SYNTAX);
+		return DNS_R_SYNTAX;
 	}
 	if (value > max) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	ok = e != str;
 	if (*e == '.') {
@@ -42,7 +42,7 @@ loc_getdecimal(const char *str, unsigned long max, size_t precision, char units,
 				break;
 			}
 			if ((tmp = decvalue(*e++)) < 0) {
-				return (DNS_R_SYNTAX);
+				return DNS_R_SYNTAX;
 			}
 			ok = true;
 			value *= 10;
@@ -60,10 +60,10 @@ loc_getdecimal(const char *str, unsigned long max, size_t precision, char units,
 		e++;
 	}
 	if (!ok || *e != 0) {
-		return (DNS_R_SYNTAX);
+		return DNS_R_SYNTAX;
 	}
 	*valuep = value;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -80,10 +80,10 @@ loc_getprecision(const char *str, unsigned char *valuep) {
 
 	m = strtoul(str, &e, 10);
 	if (*e != 0 && *e != '.' && *e != 'm') {
-		return (DNS_R_SYNTAX);
+		return DNS_R_SYNTAX;
 	}
 	if (m > 90000000) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	cm = 0;
 	ok = e != str;
@@ -94,7 +94,7 @@ loc_getprecision(const char *str, unsigned char *valuep) {
 				break;
 			}
 			if ((tmp = decvalue(*e++)) < 0) {
-				return (DNS_R_SYNTAX);
+				return DNS_R_SYNTAX;
 			}
 			ok = true;
 			cm *= 10;
@@ -108,7 +108,7 @@ loc_getprecision(const char *str, unsigned char *valuep) {
 		e++;
 	}
 	if (!ok || *e != 0) {
-		return (DNS_R_SYNTAX);
+		return DNS_R_SYNTAX;
 	}
 
 	/*
@@ -130,7 +130,7 @@ loc_getprecision(const char *str, unsigned char *valuep) {
 		exp = 0;
 	}
 	*valuep = (man << 4) + exp;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -139,20 +139,20 @@ get_degrees(isc_lex_t *lexer, isc_token_t *token, unsigned long *d) {
 				      false));
 	*d = token->value.as_ulong;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 check_coordinate(unsigned long d, unsigned long m, unsigned long s,
 		 unsigned long maxd) {
 	if (d > maxd || m > 59U) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	if (d == maxd && (m != 0 || s != 0)) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -162,7 +162,7 @@ get_minutes(isc_lex_t *lexer, isc_token_t *token, unsigned long *m) {
 
 	*m = token->value.as_ulong;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -171,7 +171,7 @@ get_seconds(isc_lex_t *lexer, isc_token_t *token, unsigned long *s) {
 				      false));
 	RETERR(loc_getdecimal(DNS_AS_STR(*token), 59, 3, '\0', s));
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -180,20 +180,22 @@ get_direction(isc_lex_t *lexer, isc_token_t *token, const char *directions,
 	RETERR(isc_lex_getmastertoken(lexer, token, isc_tokentype_string,
 				      false));
 	if (DNS_AS_STR(*token)[0] == directions[1] &&
-	    DNS_AS_STR(*token)[1] == 0) {
+	    DNS_AS_STR(*token)[1] == 0)
+	{
 		*direction = DNS_AS_STR(*token)[0];
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	if (DNS_AS_STR(*token)[0] == directions[0] &&
-	    DNS_AS_STR(*token)[1] == 0) {
+	    DNS_AS_STR(*token)[1] == 0)
+	{
 		*direction = DNS_AS_STR(*token)[0];
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	*direction = 0;
 	isc_lex_ungettoken(lexer, token);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -254,10 +256,10 @@ done:
 	*mp = m;
 	*sp = s;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 loc_getlatitude(isc_lex_t *lexer, unsigned long *latitude) {
 	unsigned long d1 = 0, m1 = 0, s1 = 0;
 	int direction = 0;
@@ -272,14 +274,13 @@ loc_getlatitude(isc_lex_t *lexer, unsigned long *latitude) {
 		*latitude = 0x80000000 - (d1 * 3600 + m1 * 60) * 1000 - s1;
 		break;
 	default:
-		INSIST(0);
-		ISC_UNREACHABLE();
+		UNREACHABLE();
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 loc_getlongitude(isc_lex_t *lexer, unsigned long *longitude) {
 	unsigned long d2 = 0, m2 = 0, s2 = 0;
 	int direction = 0;
@@ -294,14 +295,13 @@ loc_getlongitude(isc_lex_t *lexer, unsigned long *longitude) {
 		*longitude = 0x80000000 - (d2 * 3600 + m2 * 60) * 1000 - s2;
 		break;
 	default:
-		INSIST(0);
-		ISC_UNREACHABLE();
+		UNREACHABLE();
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 loc_getaltitude(isc_lex_t *lexer, unsigned long *altitude) {
 	isc_token_t token;
 	unsigned long cm;
@@ -324,10 +324,10 @@ loc_getaltitude(isc_lex_t *lexer, unsigned long *altitude) {
 		*altitude = 10000000 + cm;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 loc_getoptionalprecision(isc_lex_t *lexer, unsigned char *valuep) {
 	isc_token_t token;
 
@@ -336,26 +336,26 @@ loc_getoptionalprecision(isc_lex_t *lexer, unsigned char *valuep) {
 	if (token.type == isc_tokentype_eol || token.type == isc_tokentype_eof)
 	{
 		isc_lex_ungettoken(lexer, &token);
-		return (ISC_R_NOMORE);
+		return ISC_R_NOMORE;
 	}
 	RETTOK(loc_getprecision(DNS_AS_STR(token), valuep));
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 loc_getsize(isc_lex_t *lexer, unsigned char *sizep) {
-	return (loc_getoptionalprecision(lexer, sizep));
+	return loc_getoptionalprecision(lexer, sizep);
 }
 
-static inline isc_result_t
+static isc_result_t
 loc_gethorizontalprecision(isc_lex_t *lexer, unsigned char *hpp) {
-	return (loc_getoptionalprecision(lexer, hpp));
+	return loc_getoptionalprecision(lexer, hpp);
 }
 
-static inline isc_result_t
+static isc_result_t
 loc_getverticalprecision(isc_lex_t *lexer, unsigned char *vpp) {
-	return (loc_getoptionalprecision(lexer, vpp));
+	return loc_getoptionalprecision(lexer, vpp);
 }
 
 /* The LOC record is expressed in a master file in the following format:
@@ -382,7 +382,7 @@ loc_getverticalprecision(isc_lex_t *lexer, unsigned char *vpp) {
  * ZIP/postal code area sizes, since it is often easy to find
  * approximate geographical location by ZIP/postal code.
  */
-static inline isc_result_t
+static isc_result_t
 fromtext_loc(ARGS_FROMTEXT) {
 	isc_result_t result = ISC_R_SUCCESS;
 	unsigned long latitude = 0;
@@ -432,10 +432,10 @@ encode:
 	RETERR(uint32_tobuffer(longitude, target));
 	RETERR(uint32_tobuffer(altitude, target));
 
-	return (result);
+	return result;
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_loc(ARGS_TOTEXT) {
 	int d1, m1, s1, fs1;
 	int d2, m2, s2, fs2;
@@ -465,7 +465,7 @@ totext_loc(ARGS_TOTEXT) {
 	dns_rdata_toregion(rdata, &sr);
 
 	if (sr.base[0] != 0) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	REQUIRE(rdata->length == 16);
@@ -551,10 +551,10 @@ totext_loc(ARGS_TOTEXT) {
 		 east ? "E" : "W", below ? "-" : "", altitude / 100,
 		 altitude % 100, sbuf, hbuf, vbuf);
 
-	return (str_totext(buf, target));
+	return str_totext(buf, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_loc(ARGS_FROMWIRE) {
 	isc_region_t sr;
 	unsigned char c;
@@ -570,15 +570,15 @@ fromwire_loc(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &sr);
 	if (sr.length < 1) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	if (sr.base[0] != 0) {
 		/* Treat as unknown. */
 		isc_buffer_forward(source, sr.length);
-		return (mem_tobuffer(target, sr.base, sr.length));
+		return mem_tobuffer(target, sr.base, sr.length);
 	}
 	if (sr.length < 16) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	/*
@@ -587,8 +587,9 @@ fromwire_loc(ARGS_FROMWIRE) {
 	c = sr.base[1];
 	if (c != 0) {
 		if ((c & 0xf) > 9 || ((c >> 4) & 0xf) > 9 ||
-		    ((c >> 4) & 0xf) == 0) {
-			return (ISC_R_RANGE);
+		    ((c >> 4) & 0xf) == 0)
+		{
+			return ISC_R_RANGE;
 
 			/*
 			 * Horizontal precision.
@@ -602,8 +603,9 @@ fromwire_loc(ARGS_FROMWIRE) {
 	c = sr.base[2];
 	if (c != 0) {
 		if ((c & 0xf) > 9 || ((c >> 4) & 0xf) > 9 ||
-		    ((c >> 4) & 0xf) == 0) {
-			return (ISC_R_RANGE);
+		    ((c >> 4) & 0xf) == 0)
+		{
+			return ISC_R_RANGE;
 
 			/*
 			 * Vertical precision.
@@ -617,8 +619,9 @@ fromwire_loc(ARGS_FROMWIRE) {
 	c = sr.base[3];
 	if (c != 0) {
 		if ((c & 0xf) > 9 || ((c >> 4) & 0xf) > 9 ||
-		    ((c >> 4) & 0xf) == 0) {
-			return (ISC_R_RANGE);
+		    ((c >> 4) & 0xf) == 0)
+		{
+			return ISC_R_RANGE;
 		}
 	}
 	isc_region_consume(&sr, 4);
@@ -630,7 +633,7 @@ fromwire_loc(ARGS_FROMWIRE) {
 	if (latitude < (0x80000000UL - 90 * 3600000) ||
 	    latitude > (0x80000000UL + 90 * 3600000))
 	{
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	isc_region_consume(&sr, 4);
 
@@ -641,7 +644,7 @@ fromwire_loc(ARGS_FROMWIRE) {
 	if (longitude < (0x80000000UL - 180 * 3600000) ||
 	    longitude > (0x80000000UL + 180 * 3600000))
 	{
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	/*
@@ -651,20 +654,20 @@ fromwire_loc(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &sr);
 	isc_buffer_forward(source, 16);
-	return (mem_tobuffer(target, sr.base, 16));
+	return mem_tobuffer(target, sr.base, 16);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_loc(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	REQUIRE(rdata->type == dns_rdatatype_loc);
 	REQUIRE(rdata->length != 0);
 
-	return (mem_tobuffer(target, rdata->data, rdata->length));
+	return mem_tobuffer(target, rdata->data, rdata->length);
 }
 
-static inline int
+static int
 compare_loc(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -677,10 +680,10 @@ compare_loc(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_loc(ARGS_FROMSTRUCT) {
 	dns_rdata_loc_t *loc = source;
 	uint8_t c;
@@ -694,45 +697,45 @@ fromstruct_loc(ARGS_FROMSTRUCT) {
 	UNUSED(rdclass);
 
 	if (loc->v.v0.version != 0) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 	RETERR(uint8_tobuffer(loc->v.v0.version, target));
 
 	c = loc->v.v0.size;
 	if ((c & 0xf) > 9 || ((c >> 4) & 0xf) > 9 || ((c >> 4) & 0xf) == 0) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	RETERR(uint8_tobuffer(loc->v.v0.size, target));
 
 	c = loc->v.v0.horizontal;
 	if ((c & 0xf) > 9 || ((c >> 4) & 0xf) > 9 || ((c >> 4) & 0xf) == 0) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	RETERR(uint8_tobuffer(loc->v.v0.horizontal, target));
 
 	c = loc->v.v0.vertical;
 	if ((c & 0xf) > 9 || ((c >> 4) & 0xf) > 9 || ((c >> 4) & 0xf) == 0) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	RETERR(uint8_tobuffer(loc->v.v0.vertical, target));
 
 	if (loc->v.v0.latitude < (0x80000000UL - 90 * 3600000) ||
 	    loc->v.v0.latitude > (0x80000000UL + 90 * 3600000))
 	{
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	RETERR(uint32_tobuffer(loc->v.v0.latitude, target));
 
 	if (loc->v.v0.longitude < (0x80000000UL - 180 * 3600000) ||
 	    loc->v.v0.longitude > (0x80000000UL + 180 * 3600000))
 	{
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	RETERR(uint32_tobuffer(loc->v.v0.longitude, target));
-	return (uint32_tobuffer(loc->v.v0.altitude, target));
+	return uint32_tobuffer(loc->v.v0.altitude, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_loc(ARGS_TOSTRUCT) {
 	dns_rdata_loc_t *loc = target;
 	isc_region_t r;
@@ -747,7 +750,7 @@ tostruct_loc(ARGS_TOSTRUCT) {
 	dns_rdata_toregion(rdata, &r);
 	version = uint8_fromregion(&r);
 	if (version != 0) {
-		return (ISC_R_NOTIMPLEMENTED);
+		return ISC_R_NOTIMPLEMENTED;
 	}
 
 	loc->common.rdclass = rdata->rdclass;
@@ -768,10 +771,10 @@ tostruct_loc(ARGS_TOSTRUCT) {
 	isc_region_consume(&r, 4);
 	loc->v.v0.altitude = uint32_fromregion(&r);
 	isc_region_consume(&r, 4);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_loc(ARGS_FREESTRUCT) {
 	dns_rdata_loc_t *loc = source;
 
@@ -782,7 +785,7 @@ freestruct_loc(ARGS_FREESTRUCT) {
 	UNUSED(loc);
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_loc(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_loc);
 
@@ -791,10 +794,10 @@ additionaldata_loc(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_loc(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -802,10 +805,10 @@ digest_loc(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_loc(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_loc);
 
@@ -814,10 +817,10 @@ checkowner_loc(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_loc(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_loc);
 
@@ -825,12 +828,12 @@ checknames_loc(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_loc(ARGS_COMPARE) {
-	return (compare_loc(rdata1, rdata2));
+	return compare_loc(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_LOC_29_C */
