@@ -20,7 +20,7 @@
 
 #define RRTYPE_NID_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_nid(ARGS_FROMTEXT) {
 	isc_token_t token;
 	unsigned char locator[NS_LOCATORSZ];
@@ -46,10 +46,10 @@ fromtext_nid(ARGS_FROMTEXT) {
 	if (locator_pton(DNS_AS_STR(token), locator) != 1) {
 		RETTOK(DNS_R_SYNTAX);
 	}
-	return (mem_tobuffer(target, locator, NS_LOCATORSZ));
+	return mem_tobuffer(target, locator, NS_LOCATORSZ);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_nid(ARGS_TOTEXT) {
 	isc_region_t region;
 	char buf[sizeof("xxxx:xxxx:xxxx:xxxx")];
@@ -73,10 +73,10 @@ totext_nid(ARGS_TOTEXT) {
 		 region.base[2] << 8 | region.base[3],
 		 region.base[4] << 8 | region.base[5],
 		 region.base[6] << 8 | region.base[7]);
-	return (str_totext(buf, target));
+	return str_totext(buf, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_nid(ARGS_FROMWIRE) {
 	isc_region_t sregion;
 
@@ -89,23 +89,23 @@ fromwire_nid(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &sregion);
 	if (sregion.length != 10) {
-		return (DNS_R_FORMERR);
+		return DNS_R_FORMERR;
 	}
 	isc_buffer_forward(source, sregion.length);
-	return (mem_tobuffer(target, sregion.base, sregion.length));
+	return mem_tobuffer(target, sregion.base, sregion.length);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_nid(ARGS_TOWIRE) {
 	REQUIRE(rdata->type == dns_rdatatype_nid);
 	REQUIRE(rdata->length == 10);
 
 	UNUSED(cctx);
 
-	return (mem_tobuffer(target, rdata->data, rdata->length));
+	return mem_tobuffer(target, rdata->data, rdata->length);
 }
 
-static inline int
+static int
 compare_nid(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
@@ -118,10 +118,10 @@ compare_nid(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &region1);
 	dns_rdata_toregion(rdata2, &region2);
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_nid(ARGS_FROMSTRUCT) {
 	dns_rdata_nid_t *nid = source;
 
@@ -134,10 +134,10 @@ fromstruct_nid(ARGS_FROMSTRUCT) {
 	UNUSED(rdclass);
 
 	RETERR(uint16_tobuffer(nid->pref, target));
-	return (mem_tobuffer(target, nid->nid, sizeof(nid->nid)));
+	return mem_tobuffer(target, nid->nid, sizeof(nid->nid));
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_nid(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_nid_t *nid = target;
@@ -155,10 +155,10 @@ tostruct_nid(ARGS_TOSTRUCT) {
 	dns_rdata_toregion(rdata, &region);
 	nid->pref = uint16_fromregion(&region);
 	memmove(nid->nid, region.base, region.length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_nid(ARGS_FREESTRUCT) {
 	dns_rdata_nid_t *nid = source;
 
@@ -168,7 +168,7 @@ freestruct_nid(ARGS_FREESTRUCT) {
 	return;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_nid(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_nid);
 	REQUIRE(rdata->length == 10);
@@ -178,10 +178,10 @@ additionaldata_nid(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_nid(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -190,10 +190,10 @@ digest_nid(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_nid(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_nid);
 
@@ -202,10 +202,10 @@ checkowner_nid(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_nid(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_nid);
 	REQUIRE(rdata->length == 10);
@@ -214,12 +214,12 @@ checknames_nid(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_nid(ARGS_COMPARE) {
-	return (compare_nid(rdata1, rdata2));
+	return compare_nid(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_NID_104_C */
