@@ -24,7 +24,7 @@
 	(DNS_RDATATYPEATTR_DNSSEC | DNS_RDATATYPEATTR_ZONECUTAUTH | \
 	 DNS_RDATATYPEATTR_ATCNAME)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_nsec(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -48,10 +48,10 @@ fromtext_nsec(ARGS_FROMTEXT) {
 	}
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
 
-	return (typemap_fromtext(lexer, target, false));
+	return typemap_fromtext(lexer, target, false);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_nsec(ARGS_TOTEXT) {
 	isc_region_t sr;
 	dns_name_t name;
@@ -72,10 +72,10 @@ totext_nsec(ARGS_TOTEXT) {
 	if (sr.length > 0) {
 		RETERR(str_totext(" ", target));
 	}
-	return (typemap_totext(&sr, NULL, target));
+	return typemap_totext(&sr, NULL, target);
 }
 
-static /* inline */ isc_result_t
+static isc_result_t
 fromwire_nsec(ARGS_FROMWIRE) {
 	isc_region_t sr;
 	dns_name_t name;
@@ -94,10 +94,10 @@ fromwire_nsec(ARGS_FROMWIRE) {
 	RETERR(typemap_test(&sr, false));
 	RETERR(mem_tobuffer(target, sr.base, sr.length));
 	isc_buffer_forward(source, sr.length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_nsec(ARGS_TOWIRE) {
 	isc_region_t sr;
 	dns_name_t name;
@@ -113,10 +113,10 @@ towire_nsec(ARGS_TOWIRE) {
 	isc_region_consume(&sr, name_length(&name));
 	RETERR(dns_name_towire(&name, cctx, target));
 
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
-static inline int
+static int
 compare_nsec(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -129,10 +129,10 @@ compare_nsec(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_nsec(ARGS_FROMSTRUCT) {
 	dns_rdata_nsec_t *nsec = source;
 	isc_region_t region;
@@ -152,10 +152,10 @@ fromstruct_nsec(ARGS_FROMSTRUCT) {
 	region.base = nsec->typebits;
 	region.length = nsec->len;
 	RETERR(typemap_test(&region, false));
-	return (mem_tobuffer(target, nsec->typebits, nsec->len));
+	return mem_tobuffer(target, nsec->typebits, nsec->len);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_nsec(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_nsec_t *nsec = target;
@@ -183,16 +183,16 @@ tostruct_nsec(ARGS_TOSTRUCT) {
 	}
 
 	nsec->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (mctx != NULL) {
 		dns_name_free(&nsec->next, mctx);
 	}
-	return (ISC_R_NOMEMORY);
+	return ISC_R_NOMEMORY;
 }
 
-static inline void
+static void
 freestruct_nsec(ARGS_FREESTRUCT) {
 	dns_rdata_nsec_t *nsec = source;
 
@@ -210,7 +210,7 @@ freestruct_nsec(ARGS_FREESTRUCT) {
 	nsec->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_nsec(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_nsec);
 
@@ -219,20 +219,20 @@ additionaldata_nsec(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_nsec(ARGS_DIGEST) {
 	isc_region_t r;
 
 	REQUIRE(rdata->type == dns_rdatatype_nsec);
 
 	dns_rdata_toregion(rdata, &r);
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_nsec(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_nsec);
 
@@ -241,10 +241,10 @@ checkowner_nsec(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_nsec(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_nsec);
 
@@ -252,10 +252,10 @@ checknames_nsec(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_nsec(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
@@ -280,12 +280,12 @@ casecompare_nsec(ARGS_COMPARE) {
 
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&region1, name_length(&name1));
 	isc_region_consume(&region2, name_length(&name2));
 
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 #endif /* RDATA_GENERIC_NSEC_47_C */
