@@ -16,7 +16,7 @@
 
 #define RRTYPE_NULL_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_null(ARGS_FROMTEXT) {
 	REQUIRE(type == dns_rdatatype_null);
 
@@ -28,17 +28,17 @@ fromtext_null(ARGS_FROMTEXT) {
 	UNUSED(target);
 	UNUSED(callbacks);
 
-	return (DNS_R_SYNTAX);
+	return DNS_R_SYNTAX;
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_null(ARGS_TOTEXT) {
 	REQUIRE(rdata->type == dns_rdatatype_null);
 
-	return (unknown_totext(rdata, tctx, target));
+	return unknown_totext(rdata, tctx, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_null(ARGS_FROMWIRE) {
 	isc_region_t sr;
 
@@ -51,19 +51,19 @@ fromwire_null(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &sr);
 	isc_buffer_forward(source, sr.length);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_null(ARGS_TOWIRE) {
 	REQUIRE(rdata->type == dns_rdatatype_null);
 
 	UNUSED(cctx);
 
-	return (mem_tobuffer(target, rdata->data, rdata->length));
+	return mem_tobuffer(target, rdata->data, rdata->length);
 }
 
-static inline int
+static int
 compare_null(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -74,10 +74,10 @@ compare_null(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_null(ARGS_FROMSTRUCT) {
 	dns_rdata_null_t *null = source;
 
@@ -90,10 +90,10 @@ fromstruct_null(ARGS_FROMSTRUCT) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	return (mem_tobuffer(target, null->data, null->length));
+	return mem_tobuffer(target, null->data, null->length);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_null(ARGS_TOSTRUCT) {
 	dns_rdata_null_t *null = target;
 	isc_region_t r;
@@ -109,14 +109,14 @@ tostruct_null(ARGS_TOSTRUCT) {
 	null->length = r.length;
 	null->data = mem_maybedup(mctx, r.base, r.length);
 	if (null->data == NULL) {
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	}
 
 	null->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_null(ARGS_FREESTRUCT) {
 	dns_rdata_null_t *null = source;
 
@@ -133,7 +133,7 @@ freestruct_null(ARGS_FREESTRUCT) {
 	null->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_null(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_null);
 
@@ -142,10 +142,10 @@ additionaldata_null(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_null(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -153,10 +153,10 @@ digest_null(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_null(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_null);
 
@@ -165,10 +165,10 @@ checkowner_null(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_null(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_null);
 
@@ -176,12 +176,12 @@ checknames_null(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_null(ARGS_COMPARE) {
-	return (compare_null(rdata1, rdata2));
+	return compare_null(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_NULL_10_C */
