@@ -50,7 +50,7 @@ fromtext_ptr(ARGS_FROMTEXT) {
 			warn_badname(&name, lexer, callbacks);
 		}
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -71,7 +71,7 @@ totext_ptr(ARGS_TOTEXT) {
 
 	sub = name_prefix(&name, tctx->origin, &prefix);
 
-	return (dns_name_totext(&prefix, sub, target));
+	return dns_name_totext(&prefix, sub, target);
 }
 
 static isc_result_t
@@ -86,7 +86,7 @@ fromwire_ptr(ARGS_FROMWIRE) {
 	dns_decompress_setmethods(dctx, DNS_COMPRESS_GLOBAL14);
 
 	dns_name_init(&name, NULL);
-	return (dns_name_fromwire(&name, source, dctx, options, target));
+	return dns_name_fromwire(&name, source, dctx, options, target);
 }
 
 static isc_result_t
@@ -104,7 +104,7 @@ towire_ptr(ARGS_TOWIRE) {
 	dns_rdata_toregion(rdata, &region);
 	dns_name_fromregion(&name, &region);
 
-	return (dns_name_towire(&name, cctx, target));
+	return dns_name_towire(&name, cctx, target);
 }
 
 static int
@@ -129,7 +129,7 @@ compare_ptr(ARGS_COMPARE) {
 	dns_name_fromregion(&name1, &region1);
 	dns_name_fromregion(&name2, &region2);
 
-	return (dns_name_rdatacompare(&name1, &name2));
+	return dns_name_rdatacompare(&name1, &name2);
 }
 
 static isc_result_t
@@ -146,7 +146,7 @@ fromstruct_ptr(ARGS_FROMSTRUCT) {
 	UNUSED(rdclass);
 
 	dns_name_toregion(&ptr->ptr, &region);
-	return (isc_buffer_copyregion(target, &region));
+	return isc_buffer_copyregion(target, &region);
 }
 
 static isc_result_t
@@ -169,7 +169,7 @@ tostruct_ptr(ARGS_TOSTRUCT) {
 	dns_name_init(&ptr->ptr, NULL);
 	name_duporclone(&name, mctx, &ptr->ptr);
 	ptr->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -196,7 +196,7 @@ additionaldata_ptr(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -210,7 +210,7 @@ digest_ptr(ARGS_DIGEST) {
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &r);
 
-	return (dns_name_digest(&name, digest, arg));
+	return dns_name_digest(&name, digest, arg);
 }
 
 static bool
@@ -222,7 +222,7 @@ checkowner_ptr(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static unsigned char ip6_arpa_data[] = "\003IP6\004ARPA";
@@ -248,11 +248,11 @@ checknames_ptr(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_ptr);
 
 	if (rdata->rdclass != dns_rdataclass_in) {
-		return (true);
+		return true;
 	}
 
 	if (dns_name_isdnssd(owner)) {
-		return (true);
+		return true;
 	}
 
 	if (dns_name_issubdomain(owner, &in_addr_arpa) ||
@@ -266,14 +266,14 @@ checknames_ptr(ARGS_CHECKNAMES) {
 			if (bad != NULL) {
 				dns_name_clone(&name, bad);
 			}
-			return (false);
+			return false;
 		}
 	}
-	return (true);
+	return true;
 }
 
 static int
 casecompare_ptr(ARGS_COMPARE) {
-	return (compare_ptr(rdata1, rdata2));
+	return compare_ptr(rdata1, rdata2);
 }
 #endif /* RDATA_GENERIC_PTR_12_C */
