@@ -20,7 +20,7 @@ static isc_result_t
 fromtext_smimea(ARGS_FROMTEXT) {
 	REQUIRE(type == dns_rdatatype_smimea);
 
-	return (generic_fromtext_tlsa(CALL_FROMTEXT));
+	return generic_fromtext_tlsa(CALL_FROMTEXT);
 }
 
 static isc_result_t
@@ -28,14 +28,14 @@ totext_smimea(ARGS_TOTEXT) {
 	REQUIRE(rdata != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_smimea);
 
-	return (generic_totext_tlsa(CALL_TOTEXT));
+	return generic_totext_tlsa(CALL_TOTEXT);
 }
 
 static isc_result_t
 fromwire_smimea(ARGS_FROMWIRE) {
 	REQUIRE(type == dns_rdatatype_smimea);
 
-	return (generic_fromwire_tlsa(CALL_FROMWIRE));
+	return generic_fromwire_tlsa(CALL_FROMWIRE);
 }
 
 static isc_result_t
@@ -48,7 +48,7 @@ towire_smimea(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static int
@@ -64,14 +64,14 @@ compare_smimea(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
 fromstruct_smimea(ARGS_FROMSTRUCT) {
 	REQUIRE(type == dns_rdatatype_smimea);
 
-	return (generic_fromstruct_tlsa(CALL_FROMSTRUCT));
+	return generic_fromstruct_tlsa(CALL_FROMSTRUCT);
 }
 
 static isc_result_t
@@ -86,7 +86,7 @@ tostruct_smimea(ARGS_TOSTRUCT) {
 	smimea->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&smimea->common, link);
 
-	return (generic_tostruct_tlsa(CALL_TOSTRUCT));
+	return generic_tostruct_tlsa(CALL_TOSTRUCT);
 }
 
 static void
@@ -104,10 +104,11 @@ additionaldata_smimea(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_smimea);
 
 	UNUSED(rdata);
+	UNUSED(owner);
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -118,7 +119,7 @@ digest_smimea(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -130,7 +131,7 @@ checkowner_smimea(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -141,12 +142,12 @@ checknames_smimea(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_smimea(ARGS_COMPARE) {
-	return (compare_smimea(rdata1, rdata2));
+	return compare_smimea(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_SMIMEA_53_C */
