@@ -73,7 +73,7 @@ fromtext_soa(ARGS_FROMTEXT) {
 		RETERR(uint32_tobuffer(n, target));
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static const char *soa_fieldnames[5] = { "serial", "refresh", "retry", "expire",
@@ -150,7 +150,7 @@ totext_soa(ARGS_TOTEXT) {
 		RETERR(str_totext(")", target));
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -177,17 +177,17 @@ fromwire_soa(ARGS_FROMWIRE) {
 	isc_buffer_availableregion(target, &tregion);
 
 	if (sregion.length < 20) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	if (tregion.length < 20) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(tregion.base, sregion.base, 20);
 	isc_buffer_forward(source, 20);
 	isc_buffer_add(target, 20);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -219,12 +219,12 @@ towire_soa(ARGS_TOWIRE) {
 
 	isc_buffer_availableregion(target, &tregion);
 	if (tregion.length < 20) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(tregion.base, sregion.base, 20);
 	isc_buffer_add(target, 20);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static int
@@ -252,7 +252,7 @@ compare_soa(ARGS_COMPARE) {
 
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&region1, name_length(&name1));
@@ -266,13 +266,13 @@ compare_soa(ARGS_COMPARE) {
 
 	order = dns_name_rdatacompare(&name1, &name2);
 	if (order != 0) {
-		return (order);
+		return order;
 	}
 
 	isc_region_consume(&region1, name_length(&name1));
 	isc_region_consume(&region2, name_length(&name2));
 
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 
 static isc_result_t
@@ -296,7 +296,7 @@ fromstruct_soa(ARGS_FROMSTRUCT) {
 	RETERR(uint32_tobuffer(soa->refresh, target));
 	RETERR(uint32_tobuffer(soa->retry, target));
 	RETERR(uint32_tobuffer(soa->expire, target));
-	return (uint32_tobuffer(soa->minimum, target));
+	return uint32_tobuffer(soa->minimum, target);
 }
 
 static isc_result_t
@@ -341,7 +341,7 @@ tostruct_soa(ARGS_TOSTRUCT) {
 	soa->minimum = uint32_fromregion(&region);
 
 	soa->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -369,7 +369,7 @@ additionaldata_soa(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -391,7 +391,7 @@ digest_soa(ARGS_DIGEST) {
 	RETERR(dns_name_digest(&name, digest, arg));
 	isc_region_consume(&r, name_length(&name));
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -403,7 +403,7 @@ checkowner_soa(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -422,7 +422,7 @@ checknames_soa(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
 	isc_region_consume(&region, name_length(&name));
 	dns_name_fromregion(&name, &region);
@@ -430,14 +430,14 @@ checknames_soa(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
-	return (true);
+	return true;
 }
 
 static int
 casecompare_soa(ARGS_COMPARE) {
-	return (compare_soa(rdata1, rdata2));
+	return compare_soa(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_SOA_6_C */
