@@ -18,7 +18,7 @@
 
 #define RRTYPE_SSHFP_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_sshfp(ARGS_FROMTEXT) {
 	isc_token_t token;
 	int len = -1;
@@ -68,10 +68,10 @@ fromtext_sshfp(ARGS_FROMTEXT) {
 	/*
 	 * Digest.
 	 */
-	return (isc_hex_tobuffer(lexer, target, len));
+	return isc_hex_tobuffer(lexer, target, len);
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_sshfp(ARGS_TOTEXT) {
 	isc_region_t sr;
 	char buf[sizeof("64000 ")];
@@ -101,7 +101,7 @@ totext_sshfp(ARGS_TOTEXT) {
 	RETERR(str_totext(buf, target));
 
 	if (sr.length == 0U) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	/*
@@ -120,10 +120,10 @@ totext_sshfp(ARGS_TOTEXT) {
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
 		RETERR(str_totext(" )", target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_sshfp(ARGS_FROMWIRE) {
 	isc_region_t sr;
 
@@ -136,20 +136,20 @@ fromwire_sshfp(ARGS_FROMWIRE) {
 
 	isc_buffer_activeregion(source, &sr);
 	if (sr.length < 2) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	if ((sr.base[1] == 1 && sr.length != ISC_SHA1_DIGESTLENGTH + 2) ||
 	    (sr.base[1] == 2 && sr.length != ISC_SHA256_DIGESTLENGTH + 2))
 	{
-		return (DNS_R_FORMERR);
+		return DNS_R_FORMERR;
 	}
 
 	isc_buffer_forward(source, sr.length);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_sshfp(ARGS_TOWIRE) {
 	isc_region_t sr;
 
@@ -159,10 +159,10 @@ towire_sshfp(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
-static inline int
+static int
 compare_sshfp(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -175,10 +175,10 @@ compare_sshfp(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_sshfp(ARGS_FROMSTRUCT) {
 	dns_rdata_sshfp_t *sshfp = source;
 
@@ -193,10 +193,10 @@ fromstruct_sshfp(ARGS_FROMSTRUCT) {
 	RETERR(uint8_tobuffer(sshfp->algorithm, target));
 	RETERR(uint8_tobuffer(sshfp->digest_type, target));
 
-	return (mem_tobuffer(target, sshfp->digest, sshfp->length));
+	return mem_tobuffer(target, sshfp->digest, sshfp->length);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_sshfp(ARGS_TOSTRUCT) {
 	dns_rdata_sshfp_t *sshfp = target;
 	isc_region_t region;
@@ -219,14 +219,14 @@ tostruct_sshfp(ARGS_TOSTRUCT) {
 
 	sshfp->digest = mem_maybedup(mctx, region.base, region.length);
 	if (sshfp->digest == NULL) {
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	}
 
 	sshfp->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_sshfp(ARGS_FREESTRUCT) {
 	dns_rdata_sshfp_t *sshfp = source;
 
@@ -243,7 +243,7 @@ freestruct_sshfp(ARGS_FREESTRUCT) {
 	sshfp->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_sshfp(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_sshfp);
 
@@ -252,10 +252,10 @@ additionaldata_sshfp(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_sshfp(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -263,10 +263,10 @@ digest_sshfp(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_sshfp(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_sshfp);
 
@@ -275,10 +275,10 @@ checkowner_sshfp(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_sshfp(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_sshfp);
 
@@ -286,12 +286,12 @@ checknames_sshfp(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_sshfp(ARGS_COMPARE) {
-	return (compare_sshfp(rdata1, rdata2));
+	return compare_sshfp(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_SSHFP_44_C */
