@@ -16,7 +16,7 @@
 
 #define RRTYPE_TALINK_ATTRIBUTES 0
 
-static inline isc_result_t
+static isc_result_t
 fromtext_talink(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
@@ -43,10 +43,10 @@ fromtext_talink(ARGS_FROMTEXT) {
 					 target));
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_talink(ARGS_TOTEXT) {
 	isc_region_t dregion;
 	dns_name_t prev;
@@ -75,10 +75,10 @@ totext_talink(ARGS_TOTEXT) {
 	RETERR(str_totext(" ", target));
 
 	sub = name_prefix(&next, tctx->origin, &prefix);
-	return (dns_name_totext(&prefix, sub, target));
+	return dns_name_totext(&prefix, sub, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_talink(ARGS_FROMWIRE) {
 	dns_name_t prev;
 	dns_name_t next;
@@ -94,10 +94,10 @@ fromwire_talink(ARGS_FROMWIRE) {
 	dns_name_init(&next, NULL);
 
 	RETERR(dns_name_fromwire(&prev, source, dctx, options, target));
-	return (dns_name_fromwire(&next, source, dctx, options, target));
+	return dns_name_fromwire(&next, source, dctx, options, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_talink(ARGS_TOWIRE) {
 	isc_region_t sregion;
 	dns_name_t prev;
@@ -121,10 +121,10 @@ towire_talink(ARGS_TOWIRE) {
 
 	dns_name_fromregion(&next, &sregion);
 	isc_region_consume(&sregion, name_length(&next));
-	return (dns_name_towire(&next, cctx, target));
+	return dns_name_towire(&next, cctx, target);
 }
 
-static inline int
+static int
 compare_talink(ARGS_COMPARE) {
 	isc_region_t region1;
 	isc_region_t region2;
@@ -137,10 +137,10 @@ compare_talink(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &region1);
 	dns_rdata_toregion(rdata2, &region2);
-	return (isc_region_compare(&region1, &region2));
+	return isc_region_compare(&region1, &region2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_talink(ARGS_FROMSTRUCT) {
 	dns_rdata_talink_t *talink = source;
 	isc_region_t region;
@@ -156,10 +156,10 @@ fromstruct_talink(ARGS_FROMSTRUCT) {
 	dns_name_toregion(&talink->prev, &region);
 	RETERR(isc_buffer_copyregion(target, &region));
 	dns_name_toregion(&talink->next, &region);
-	return (isc_buffer_copyregion(target, &region));
+	return isc_buffer_copyregion(target, &region);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_talink(ARGS_TOSTRUCT) {
 	isc_region_t region;
 	dns_rdata_talink_t *talink = target;
@@ -187,10 +187,10 @@ tostruct_talink(ARGS_TOSTRUCT) {
 	name_duporclone(&name, mctx, &talink->next);
 
 	talink->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_talink(ARGS_FREESTRUCT) {
 	dns_rdata_talink_t *talink = source;
 
@@ -206,7 +206,7 @@ freestruct_talink(ARGS_FREESTRUCT) {
 	talink->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_talink(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_talink);
 
@@ -215,20 +215,20 @@ additionaldata_talink(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_talink(ARGS_DIGEST) {
 	isc_region_t r;
 
 	REQUIRE(rdata->type == dns_rdatatype_talink);
 
 	dns_rdata_toregion(rdata, &r);
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_talink(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_talink);
 
@@ -237,22 +237,22 @@ checkowner_talink(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
-static inline bool
+static bool
 checknames_talink(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_talink);
 
 	UNUSED(bad);
 	UNUSED(owner);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_talink(ARGS_COMPARE) {
-	return (compare_talink(rdata1, rdata2));
+	return compare_talink(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_TALINK_58_C */
