@@ -72,9 +72,9 @@ fromtext_zonemd(ARGS_FROMTEXT) {
 	result = isc_hex_tobuffer(lexer, target, length);
 	/* Minimum length of digest is 12 octets. */
 	if (isc_buffer_usedlength(target) - isc_buffer_usedlength(&save) < 12) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -137,7 +137,7 @@ totext_zonemd(ARGS_TOTEXT) {
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
 		RETERR(str_totext(" )", target));
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -160,7 +160,7 @@ fromwire_zonemd(ARGS_FROMWIRE) {
 	 * correct length.
 	 */
 	if (sr.length < 18) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	switch (sr.base[5]) {
@@ -175,7 +175,7 @@ fromwire_zonemd(ARGS_FROMWIRE) {
 	}
 
 	if (digestlen != 0 && sr.length < 6 + digestlen) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 
 	/*
@@ -189,7 +189,7 @@ fromwire_zonemd(ARGS_FROMWIRE) {
 	}
 
 	isc_buffer_forward(source, sr.length);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static isc_result_t
@@ -202,7 +202,7 @@ towire_zonemd(ARGS_TOWIRE) {
 	UNUSED(cctx);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
 static int
@@ -218,7 +218,7 @@ compare_zonemd(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
 static isc_result_t
@@ -245,7 +245,7 @@ fromstruct_zonemd(ARGS_FROMSTRUCT) {
 	RETERR(uint8_tobuffer(zonemd->scheme, target));
 	RETERR(uint8_tobuffer(zonemd->digest_type, target));
 
-	return (mem_tobuffer(target, zonemd->digest, zonemd->length));
+	return mem_tobuffer(target, zonemd->digest, zonemd->length);
 }
 
 static isc_result_t
@@ -273,11 +273,11 @@ tostruct_zonemd(ARGS_TOSTRUCT) {
 
 	zonemd->digest = mem_maybedup(mctx, region.base, region.length);
 	if (zonemd->digest == NULL) {
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	}
 
 	zonemd->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -306,7 +306,7 @@ additionaldata_zonemd(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -317,7 +317,7 @@ digest_zonemd(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
 static bool
@@ -329,7 +329,7 @@ checkowner_zonemd(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -340,12 +340,12 @@ checknames_zonemd(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
 static int
 casecompare_zonemd(ARGS_COMPARE) {
-	return (compare_zonemd(rdata1, rdata2));
+	return compare_zonemd(rdata1, rdata2);
 }
 
 #endif /* RDATA_GENERIC_ZONEMD_63_C */
