@@ -20,7 +20,7 @@
 
 #define RRTYPE_A6_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_in_a6(ARGS_FROMTEXT) {
 	isc_token_t token;
 	unsigned char addr[16];
@@ -72,7 +72,7 @@ fromtext_in_a6(ARGS_FROMTEXT) {
 	}
 
 	if (prefixlen == 0) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
@@ -93,10 +93,10 @@ fromtext_in_a6(ARGS_FROMTEXT) {
 	if (!ok && callbacks != NULL) {
 		warn_badname(&name, lexer, callbacks);
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_in_a6(ARGS_TOTEXT) {
 	isc_region_t sr, ar;
 	unsigned char addr[16];
@@ -133,7 +133,7 @@ totext_in_a6(ARGS_TOTEXT) {
 	}
 
 	if (prefixlen == 0) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	RETERR(str_totext(" ", target));
@@ -141,10 +141,10 @@ totext_in_a6(ARGS_TOTEXT) {
 	dns_name_init(&prefix, NULL);
 	dns_name_fromregion(&name, &sr);
 	sub = name_prefix(&name, tctx->origin, &prefix);
-	return (dns_name_totext(&prefix, sub, target));
+	return dns_name_totext(&prefix, sub, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_in_a6(ARGS_FROMWIRE) {
 	isc_region_t sr;
 	unsigned char prefixlen;
@@ -165,11 +165,11 @@ fromwire_in_a6(ARGS_FROMWIRE) {
 	 * Prefix length.
 	 */
 	if (sr.length < 1) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	prefixlen = sr.base[0];
 	if (prefixlen > 128) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 	isc_region_consume(&sr, 1);
 	RETERR(mem_tobuffer(target, &prefixlen, 1));
@@ -181,25 +181,25 @@ fromwire_in_a6(ARGS_FROMWIRE) {
 	if (prefixlen != 128) {
 		octets = 16 - prefixlen / 8;
 		if (sr.length < octets) {
-			return (ISC_R_UNEXPECTEDEND);
+			return ISC_R_UNEXPECTEDEND;
 		}
 		mask = 0xff >> (prefixlen % 8);
 		if ((sr.base[0] & ~mask) != 0) {
-			return (DNS_R_FORMERR);
+			return DNS_R_FORMERR;
 		}
 		RETERR(mem_tobuffer(target, sr.base, octets));
 		isc_buffer_forward(source, octets);
 	}
 
 	if (prefixlen == 0) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	dns_name_init(&name, NULL);
-	return (dns_name_fromwire(&name, source, dctx, options, target));
+	return dns_name_fromwire(&name, source, dctx, options, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_in_a6(ARGS_TOWIRE) {
 	isc_region_t sr;
 	dns_name_t name;
@@ -221,15 +221,15 @@ towire_in_a6(ARGS_TOWIRE) {
 	isc_region_consume(&sr, octets);
 
 	if (prefixlen == 0) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	dns_name_init(&name, offsets);
 	dns_name_fromregion(&name, &sr);
-	return (dns_name_towire(&name, cctx, target));
+	return dns_name_towire(&name, cctx, target);
 }
 
-static inline int
+static int
 compare_in_a6(ARGS_COMPARE) {
 	int order;
 	unsigned char prefixlen1, prefixlen2;
@@ -253,9 +253,9 @@ compare_in_a6(ARGS_COMPARE) {
 	isc_region_consume(&region1, 1);
 	isc_region_consume(&region2, 1);
 	if (prefixlen1 < prefixlen2) {
-		return (-1);
+		return -1;
 	} else if (prefixlen1 > prefixlen2) {
-		return (1);
+		return 1;
 	}
 	/*
 	 * Prefix lengths are equal.
@@ -265,15 +265,15 @@ compare_in_a6(ARGS_COMPARE) {
 	if (octets > 0) {
 		order = memcmp(region1.base, region2.base, octets);
 		if (order < 0) {
-			return (-1);
+			return -1;
 		} else if (order > 0) {
-			return (1);
+			return 1;
 		}
 		/*
 		 * Address suffixes are equal.
 		 */
 		if (prefixlen1 == 0) {
-			return (order);
+			return order;
 		}
 		isc_region_consume(&region1, octets);
 		isc_region_consume(&region2, octets);
@@ -283,10 +283,10 @@ compare_in_a6(ARGS_COMPARE) {
 	dns_name_init(&name2, NULL);
 	dns_name_fromregion(&name1, &region1);
 	dns_name_fromregion(&name2, &region2);
-	return (dns_name_rdatacompare(&name1, &name2));
+	return dns_name_rdatacompare(&name1, &name2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_in_a6(ARGS_FROMSTRUCT) {
 	dns_rdata_in_a6_t *a6 = source;
 	isc_region_t region;
@@ -305,7 +305,7 @@ fromstruct_in_a6(ARGS_FROMSTRUCT) {
 	UNUSED(rdclass);
 
 	if (a6->prefixlen > 128) {
-		return (ISC_R_RANGE);
+		return ISC_R_RANGE;
 	}
 
 	RETERR(uint8_tobuffer(a6->prefixlen, target));
@@ -328,13 +328,13 @@ fromstruct_in_a6(ARGS_FROMSTRUCT) {
 	}
 
 	if (a6->prefixlen == 0) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	dns_name_toregion(&a6->prefix, &region);
-	return (isc_buffer_copyregion(target, &region));
+	return isc_buffer_copyregion(target, &region);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_in_a6(ARGS_TOSTRUCT) {
 	dns_rdata_in_a6_t *a6 = target;
 	unsigned char octets;
@@ -376,10 +376,10 @@ tostruct_in_a6(ARGS_TOSTRUCT) {
 		name_duporclone(&name, mctx, &a6->prefix);
 	}
 	a6->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_in_a6(ARGS_FREESTRUCT) {
 	dns_rdata_in_a6_t *a6 = source;
 
@@ -397,7 +397,7 @@ freestruct_in_a6(ARGS_FREESTRUCT) {
 	a6->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_in_a6(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_a6);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
@@ -407,10 +407,10 @@ additionaldata_in_a6(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_in_a6(ARGS_DIGEST) {
 	isc_region_t r1, r2;
 	unsigned char prefixlen, octets;
@@ -428,19 +428,19 @@ digest_in_a6(ARGS_DIGEST) {
 	r1.length = octets;
 	result = (digest)(arg, &r1);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	if (prefixlen == 0) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	isc_region_consume(&r2, octets);
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &r2);
-	return (dns_name_digest(&name, digest, arg));
+	return dns_name_digest(&name, digest, arg);
 }
 
-static inline bool
+static bool
 checkowner_in_a6(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_a6);
 	REQUIRE(rdclass == dns_rdataclass_in);
@@ -448,10 +448,10 @@ checkowner_in_a6(ARGS_CHECKOWNER) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	return (dns_name_ishostname(name, wildcard));
+	return dns_name_ishostname(name, wildcard);
 }
 
-static inline bool
+static bool
 checknames_in_a6(ARGS_CHECKNAMES) {
 	isc_region_t region;
 	dns_name_t name;
@@ -465,7 +465,7 @@ checknames_in_a6(ARGS_CHECKNAMES) {
 	dns_rdata_toregion(rdata, &region);
 	prefixlen = uint8_fromregion(&region);
 	if (prefixlen == 0) {
-		return (true);
+		return true;
 	}
 	isc_region_consume(&region, 1 + 16 - prefixlen / 8);
 	dns_name_init(&name, NULL);
@@ -474,14 +474,14 @@ checknames_in_a6(ARGS_CHECKNAMES) {
 		if (bad != NULL) {
 			dns_name_clone(&name, bad);
 		}
-		return (false);
+		return false;
 	}
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_in_a6(ARGS_COMPARE) {
-	return (compare_in_a6(rdata1, rdata2));
+	return compare_in_a6(rdata1, rdata2);
 }
 
 #endif /* RDATA_IN_1_A6_38_C */
