@@ -20,7 +20,7 @@
 
 #define RRTYPE_A_ATTRIBUTES (0)
 
-static inline isc_result_t
+static isc_result_t
 fromtext_in_a(ARGS_FROMTEXT) {
 	isc_token_t token;
 	struct in_addr addr;
@@ -43,14 +43,14 @@ fromtext_in_a(ARGS_FROMTEXT) {
 	}
 	isc_buffer_availableregion(target, &region);
 	if (region.length < 4) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	memmove(region.base, &addr, 4);
 	isc_buffer_add(target, 4);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_in_a(ARGS_TOTEXT) {
 	isc_region_t region;
 
@@ -61,10 +61,10 @@ totext_in_a(ARGS_TOTEXT) {
 	UNUSED(tctx);
 
 	dns_rdata_toregion(rdata, &region);
-	return (inet_totext(AF_INET, tctx->flags, &region, target));
+	return inet_totext(AF_INET, tctx->flags, &region, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_in_a(ARGS_FROMWIRE) {
 	isc_region_t sregion;
 	isc_region_t tregion;
@@ -80,19 +80,19 @@ fromwire_in_a(ARGS_FROMWIRE) {
 	isc_buffer_activeregion(source, &sregion);
 	isc_buffer_availableregion(target, &tregion);
 	if (sregion.length < 4) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	if (tregion.length < 4) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(tregion.base, sregion.base, 4);
 	isc_buffer_forward(source, 4);
 	isc_buffer_add(target, 4);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_in_a(ARGS_TOWIRE) {
 	isc_region_t region;
 
@@ -104,14 +104,14 @@ towire_in_a(ARGS_TOWIRE) {
 
 	isc_buffer_availableregion(target, &region);
 	if (region.length < rdata->length) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	memmove(region.base, rdata->data, rdata->length);
 	isc_buffer_add(target, 4);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline int
+static int
 compare_in_a(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -125,10 +125,10 @@ compare_in_a(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_in_a(ARGS_FROMSTRUCT) {
 	dns_rdata_in_a_t *a = source;
 	uint32_t n;
@@ -144,10 +144,10 @@ fromstruct_in_a(ARGS_FROMSTRUCT) {
 
 	n = ntohl(a->in_addr.s_addr);
 
-	return (uint32_tobuffer(n, target));
+	return uint32_tobuffer(n, target);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_in_a(ARGS_TOSTRUCT) {
 	dns_rdata_in_a_t *a = target;
 	uint32_t n;
@@ -168,10 +168,10 @@ tostruct_in_a(ARGS_TOSTRUCT) {
 	n = uint32_fromregion(&region);
 	a->in_addr.s_addr = htonl(n);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_in_a(ARGS_FREESTRUCT) {
 	dns_rdata_in_a_t *a = source;
 
@@ -182,7 +182,7 @@ freestruct_in_a(ARGS_FREESTRUCT) {
 	UNUSED(a);
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_in_a(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_a);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
@@ -192,10 +192,10 @@ additionaldata_in_a(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_in_a(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -204,10 +204,10 @@ digest_in_a(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_in_a(ARGS_CHECKOWNER) {
 	dns_name_t prefix, suffix;
 	unsigned int labels, i;
@@ -227,8 +227,9 @@ checkowner_in_a(ARGS_CHECKOWNER) {
 		dns_name_init(&suffix, NULL);
 		dns_name_split(name, labels - 2, &prefix, &suffix);
 		if (dns_name_equal(&gc_msdcs, &prefix) &&
-		    dns_name_ishostname(&suffix, false)) {
-			return (true);
+		    dns_name_ishostname(&suffix, false))
+		{
+			return true;
 		}
 
 		/*
@@ -250,15 +251,15 @@ checkowner_in_a(ARGS_CHECKOWNER) {
 			     strncasecmp((char *)label.base, "\x09_spf_rate",
 					 10) == 0))
 			{
-				return (true);
+				return true;
 			}
 		}
 	}
 
-	return (dns_name_ishostname(name, wildcard));
+	return dns_name_ishostname(name, wildcard);
 }
 
-static inline bool
+static bool
 checknames_in_a(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_a);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
@@ -267,12 +268,12 @@ checknames_in_a(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_in_a(ARGS_COMPARE) {
-	return (compare_in_a(rdata1, rdata2));
+	return compare_in_a(rdata1, rdata2);
 }
 
 #endif /* RDATA_IN_1_A_1_C */
