@@ -40,7 +40,7 @@ mygetprotobyname(const char *name, long *proto) {
 		*proto = pe->p_proto;
 	}
 	UNLOCK(&wks_lock);
-	return (pe != NULL);
+	return pe != NULL;
 }
 
 static bool
@@ -53,10 +53,10 @@ mygetservbyname(const char *name, const char *proto, long *port) {
 		*port = ntohs(se->s_port);
 	}
 	UNLOCK(&wks_lock);
-	return (se != NULL);
+	return se != NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 fromtext_in_wks(ARGS_FROMTEXT) {
 	static isc_once_t once = ISC_ONCE_INIT;
 	isc_token_t token;
@@ -95,7 +95,7 @@ fromtext_in_wks(ARGS_FROMTEXT) {
 		CHECKTOK(DNS_R_BADDOTTEDQUAD);
 	}
 	if (region.length < 4) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	memmove(region.base, &addr, 4);
 	isc_buffer_add(target, 4);
@@ -166,10 +166,10 @@ fromtext_in_wks(ARGS_FROMTEXT) {
 	result = mem_tobuffer(target, bm, n);
 
 cleanup:
-	return (result);
+	return result;
 }
 
-static inline isc_result_t
+static isc_result_t
 totext_in_wks(ARGS_TOTEXT) {
 	isc_region_t sr;
 	unsigned short proto;
@@ -208,10 +208,10 @@ totext_in_wks(ARGS_TOTEXT) {
 		}
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 fromwire_in_wks(ARGS_FROMWIRE) {
 	isc_region_t sr;
 	isc_region_t tr;
@@ -228,26 +228,26 @@ fromwire_in_wks(ARGS_FROMWIRE) {
 	isc_buffer_availableregion(target, &tr);
 
 	if (sr.length < 5) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	if (sr.length > 8 * 1024 + 5) {
-		return (DNS_R_EXTRADATA);
+		return DNS_R_EXTRADATA;
 	}
 	if (sr.length > 5 && sr.base[sr.length - 1] == 0) {
-		return (DNS_R_FORMERR);
+		return DNS_R_FORMERR;
 	}
 	if (tr.length < sr.length) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(tr.base, sr.base, sr.length);
 	isc_buffer_add(target, sr.length);
 	isc_buffer_forward(source, sr.length);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 towire_in_wks(ARGS_TOWIRE) {
 	isc_region_t sr;
 
@@ -258,10 +258,10 @@ towire_in_wks(ARGS_TOWIRE) {
 	REQUIRE(rdata->length != 0);
 
 	dns_rdata_toregion(rdata, &sr);
-	return (mem_tobuffer(target, sr.base, sr.length));
+	return mem_tobuffer(target, sr.base, sr.length);
 }
 
-static inline int
+static int
 compare_in_wks(ARGS_COMPARE) {
 	isc_region_t r1;
 	isc_region_t r2;
@@ -275,10 +275,10 @@ compare_in_wks(ARGS_COMPARE) {
 
 	dns_rdata_toregion(rdata1, &r1);
 	dns_rdata_toregion(rdata2, &r2);
-	return (isc_region_compare(&r1, &r2));
+	return isc_region_compare(&r1, &r2);
 }
 
-static inline isc_result_t
+static isc_result_t
 fromstruct_in_wks(ARGS_FROMSTRUCT) {
 	dns_rdata_in_wks_t *wks = source;
 	uint32_t a;
@@ -297,10 +297,10 @@ fromstruct_in_wks(ARGS_FROMSTRUCT) {
 	a = ntohl(wks->in_addr.s_addr);
 	RETERR(uint32_tobuffer(a, target));
 	RETERR(uint8_tobuffer(wks->protocol, target));
-	return (mem_tobuffer(target, wks->map, wks->map_len));
+	return mem_tobuffer(target, wks->map, wks->map_len);
 }
 
-static inline isc_result_t
+static isc_result_t
 tostruct_in_wks(ARGS_TOSTRUCT) {
 	dns_rdata_in_wks_t *wks = target;
 	uint32_t n;
@@ -324,13 +324,13 @@ tostruct_in_wks(ARGS_TOSTRUCT) {
 	wks->map_len = region.length;
 	wks->map = mem_maybedup(mctx, region.base, region.length);
 	if (wks->map == NULL) {
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	}
 	wks->mctx = mctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline void
+static void
 freestruct_in_wks(ARGS_FREESTRUCT) {
 	dns_rdata_in_wks_t *wks = source;
 
@@ -348,7 +348,7 @@ freestruct_in_wks(ARGS_FREESTRUCT) {
 	wks->mctx = NULL;
 }
 
-static inline isc_result_t
+static isc_result_t
 additionaldata_in_wks(ARGS_ADDLDATA) {
 	REQUIRE(rdata->type == dns_rdatatype_wks);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
@@ -358,10 +358,10 @@ additionaldata_in_wks(ARGS_ADDLDATA) {
 	UNUSED(add);
 	UNUSED(arg);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
-static inline isc_result_t
+static isc_result_t
 digest_in_wks(ARGS_DIGEST) {
 	isc_region_t r;
 
@@ -370,10 +370,10 @@ digest_in_wks(ARGS_DIGEST) {
 
 	dns_rdata_toregion(rdata, &r);
 
-	return ((digest)(arg, &r));
+	return (digest)(arg, &r);
 }
 
-static inline bool
+static bool
 checkowner_in_wks(ARGS_CHECKOWNER) {
 	REQUIRE(type == dns_rdatatype_wks);
 	REQUIRE(rdclass == dns_rdataclass_in);
@@ -381,10 +381,10 @@ checkowner_in_wks(ARGS_CHECKOWNER) {
 	UNUSED(type);
 	UNUSED(rdclass);
 
-	return (dns_name_ishostname(name, wildcard));
+	return dns_name_ishostname(name, wildcard);
 }
 
-static inline bool
+static bool
 checknames_in_wks(ARGS_CHECKNAMES) {
 	REQUIRE(rdata->type == dns_rdatatype_wks);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
@@ -393,12 +393,12 @@ checknames_in_wks(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return true;
 }
 
-static inline int
+static int
 casecompare_in_wks(ARGS_COMPARE) {
-	return (compare_in_wks(rdata1, rdata2));
+	return compare_in_wks(rdata1, rdata2);
 }
 
 #endif /* RDATA_IN_1_WKS_11_C */
