@@ -247,7 +247,7 @@ add_server(isc_mem_t *mctx, const char *address_str,
 		goto cleanup;
 	}
 	address->length = (unsigned int)res->ai_addrlen;
-	memmove(&address->type.ss, res->ai_addr, res->ai_addrlen);
+	memmove(&address->type.sa, res->ai_addr, res->ai_addrlen);
 	ISC_LINK_INIT(address, link);
 	ISC_LIST_APPEND(*nameservers, address, link);
 
