@@ -110,28 +110,28 @@ base32_totext(isc_region_t *source, int wordlength, const char *wordbreak,
 	if (source->length > 0) {
 		isc_region_consume(source, source->length);
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
 isc_base32_totext(isc_region_t *source, int wordlength, const char *wordbreak,
 		  isc_buffer_t *target) {
-	return (base32_totext(source, wordlength, wordbreak, target, base32,
-			      '='));
+	return base32_totext(source, wordlength, wordbreak, target, base32,
+			     '=');
 }
 
 isc_result_t
 isc_base32hex_totext(isc_region_t *source, int wordlength,
 		     const char *wordbreak, isc_buffer_t *target) {
-	return (base32_totext(source, wordlength, wordbreak, target, base32hex,
-			      '='));
+	return base32_totext(source, wordlength, wordbreak, target, base32hex,
+			     '=');
 }
 
 isc_result_t
 isc_base32hexnp_totext(isc_region_t *source, int wordlength,
 		       const char *wordbreak, isc_buffer_t *target) {
-	return (base32_totext(source, wordlength, wordbreak, target, base32hex,
-			      0));
+	return base32_totext(source, wordlength, wordbreak, target, base32hex,
+			     0);
 }
 
 /*%
@@ -167,10 +167,10 @@ base32_decode_char(base32_decode_ctx_t *ctx, int c) {
 	unsigned int last;
 
 	if (ctx->seen_end) {
-		return (ISC_R_BADBASE32);
+		return ISC_R_BADBASE32;
 	}
 	if ((s = strchr(ctx->base, c)) == NULL) {
-		return (ISC_R_BADBASE32);
+		return ISC_R_BADBASE32;
 	}
 	last = (unsigned int)(s - ctx->base);
 
@@ -185,14 +185,14 @@ base32_decode_char(base32_decode_ctx_t *ctx, int c) {
 	 * Check that padding is contiguous.
 	 */
 	if (last != 32 && ctx->seen_32 != 0) {
-		return (ISC_R_BADBASE32);
+		return ISC_R_BADBASE32;
 	}
 
 	/*
 	 * If padding is not permitted flag padding as a error.
 	 */
 	if (last == 32 && !ctx->pad) {
-		return (ISC_R_BADBASE32);
+		return ISC_R_BADBASE32;
 	}
 
 	/*
@@ -204,32 +204,32 @@ base32_decode_char(base32_decode_ctx_t *ctx, int c) {
 		switch (ctx->digits) {
 		case 0:
 		case 1:
-			return (ISC_R_BADBASE32);
+			return ISC_R_BADBASE32;
 		case 2:
 			if ((ctx->val[1] & 0x03) != 0) {
-				return (ISC_R_BADBASE32);
+				return ISC_R_BADBASE32;
 			}
 			ctx->seen_32 = 1;
 			break;
 		case 3:
-			return (ISC_R_BADBASE32);
+			return ISC_R_BADBASE32;
 		case 4:
 			if ((ctx->val[3] & 0x0f) != 0) {
-				return (ISC_R_BADBASE32);
+				return ISC_R_BADBASE32;
 			}
 			ctx->seen_32 = 2;
 			break;
 		case 5:
 			if ((ctx->val[4] & 0x01) != 0) {
-				return (ISC_R_BADBASE32);
+				return ISC_R_BADBASE32;
 			}
 			ctx->seen_32 = 3;
 			break;
 		case 6:
-			return (ISC_R_BADBASE32);
+			return ISC_R_BADBASE32;
 		case 7:
 			if ((ctx->val[6] & 0x07) != 0) {
-				return (ISC_R_BADBASE32);
+				return ISC_R_BADBASE32;
 			}
 			ctx->seen_32 = 4;
 			break;
@@ -259,20 +259,20 @@ base32_decode_char(base32_decode_ctx_t *ctx, int c) {
 		RETERR(mem_tobuffer(ctx->target, buf, n));
 		if (ctx->length >= 0) {
 			if (n > ctx->length) {
-				return (ISC_R_BADBASE32);
+				return ISC_R_BADBASE32;
 			} else {
 				ctx->length -= n;
 			}
 		}
 		ctx->digits = 0;
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 base32_decode_finish(base32_decode_ctx_t *ctx) {
 	if (ctx->length > 0) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
 	/*
 	 * Add missing padding if required.
@@ -284,9 +284,9 @@ base32_decode_finish(base32_decode_ctx_t *ctx) {
 		} while (ctx->digits != 0);
 	}
 	if (ctx->digits != 0) {
-		return (ISC_R_BADBASE32);
+		return ISC_R_BADBASE32;
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -327,24 +327,24 @@ base32_tobuffer(isc_lex_t *lexer, const char base[], bool pad,
 	}
 	RETERR(base32_decode_finish(&ctx));
 	if (length == -2 && before == after) {
-		return (ISC_R_UNEXPECTEDEND);
+		return ISC_R_UNEXPECTEDEND;
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
 isc_base32_tobuffer(isc_lex_t *lexer, isc_buffer_t *target, int length) {
-	return (base32_tobuffer(lexer, base32, true, target, length));
+	return base32_tobuffer(lexer, base32, true, target, length);
 }
 
 isc_result_t
 isc_base32hex_tobuffer(isc_lex_t *lexer, isc_buffer_t *target, int length) {
-	return (base32_tobuffer(lexer, base32hex, true, target, length));
+	return base32_tobuffer(lexer, base32hex, true, target, length);
 }
 
 isc_result_t
 isc_base32hexnp_tobuffer(isc_lex_t *lexer, isc_buffer_t *target, int length) {
-	return (base32_tobuffer(lexer, base32hex, false, target, length));
+	return base32_tobuffer(lexer, base32hex, false, target, length);
 }
 
 static isc_result_t
@@ -364,22 +364,22 @@ base32_decodestring(const char *cstr, const char base[], bool pad,
 		RETERR(base32_decode_char(&ctx, c));
 	}
 	RETERR(base32_decode_finish(&ctx));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
 isc_base32_decodestring(const char *cstr, isc_buffer_t *target) {
-	return (base32_decodestring(cstr, base32, true, target));
+	return base32_decodestring(cstr, base32, true, target);
 }
 
 isc_result_t
 isc_base32hex_decodestring(const char *cstr, isc_buffer_t *target) {
-	return (base32_decodestring(cstr, base32hex, true, target));
+	return base32_decodestring(cstr, base32hex, true, target);
 }
 
 isc_result_t
 isc_base32hexnp_decodestring(const char *cstr, isc_buffer_t *target) {
-	return (base32_decodestring(cstr, base32hex, false, target));
+	return base32_decodestring(cstr, base32hex, false, target);
 }
 
 static isc_result_t
@@ -394,22 +394,22 @@ base32_decoderegion(isc_region_t *source, const char base[], bool pad,
 		isc_region_consume(source, 1);
 	}
 	RETERR(base32_decode_finish(&ctx));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
 isc_base32_decoderegion(isc_region_t *source, isc_buffer_t *target) {
-	return (base32_decoderegion(source, base32, true, target));
+	return base32_decoderegion(source, base32, true, target);
 }
 
 isc_result_t
 isc_base32hex_decoderegion(isc_region_t *source, isc_buffer_t *target) {
-	return (base32_decoderegion(source, base32hex, true, target));
+	return base32_decoderegion(source, base32hex, true, target);
 }
 
 isc_result_t
 isc_base32hexnp_decoderegion(isc_region_t *source, isc_buffer_t *target) {
-	return (base32_decoderegion(source, base32hex, false, target));
+	return base32_decoderegion(source, base32hex, false, target);
 }
 
 static isc_result_t
@@ -421,12 +421,12 @@ str_totext(const char *source, isc_buffer_t *target) {
 	l = strlen(source);
 
 	if (l > region.length) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 
 	memmove(region.base, source, l);
 	isc_buffer_add(target, l);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -435,9 +435,9 @@ mem_tobuffer(isc_buffer_t *target, void *base, unsigned int length) {
 
 	isc_buffer_availableregion(target, &tr);
 	if (length > tr.length) {
-		return (ISC_R_NOSPACE);
+		return ISC_R_NOSPACE;
 	}
 	memmove(tr.base, base, length);
 	isc_buffer_add(target, length);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
