@@ -16,9 +16,7 @@
 #include <string.h>
 
 #include <openssl/crypto.h>
-#include <openssl/engine.h>
 #include <openssl/evp.h>
-#include <openssl/hmac.h>
 #include <openssl/opensslv.h>
 #include <openssl/ssl.h>
 
@@ -31,7 +29,7 @@ CRYPTO_zalloc(size_t num, const char *file, int line) {
 	if (ret != NULL) {
 		memset(ret, 0, num);
 	}
-	return (ret);
+	return ret;
 }
 #endif /* if !HAVE_CRYPTO_ZALLOC */
 
@@ -39,7 +37,7 @@ CRYPTO_zalloc(size_t num, const char *file, int line) {
 EVP_CIPHER_CTX *
 EVP_CIPHER_CTX_new(void) {
 	EVP_CIPHER_CTX *ctx = OPENSSL_zalloc(sizeof(*ctx));
-	return (ctx);
+	return ctx;
 }
 #endif /* if !HAVE_EVP_CIPHER_CTX_NEW */
 
@@ -56,7 +54,7 @@ EVP_CIPHER_CTX_free(EVP_CIPHER_CTX *ctx) {
 #if !HAVE_EVP_MD_CTX_RESET
 int
 EVP_MD_CTX_reset(EVP_MD_CTX *ctx) {
-	return (EVP_MD_CTX_cleanup(ctx));
+	return EVP_MD_CTX_cleanup(ctx);
 }
 #endif /* if !HAVE_EVP_MD_CTX_RESET */
 
@@ -69,7 +67,7 @@ SSL_read_ex(SSL *ssl, void *buf, size_t num, size_t *readbytes) {
 		rv = 1;
 	}
 
-	return (rv);
+	return rv;
 }
 #endif
 
@@ -82,7 +80,7 @@ SSL_peek_ex(SSL *ssl, void *buf, size_t num, size_t *readbytes) {
 		rv = 1;
 	}
 
-	return (rv);
+	return rv;
 }
 #endif
 
@@ -95,7 +93,7 @@ SSL_write_ex(SSL *ssl, const void *buf, size_t num, size_t *written) {
 		rv = 1;
 	}
 
-	return (rv);
+	return rv;
 }
 #endif
 
@@ -108,7 +106,7 @@ BIO_read_ex(BIO *b, void *data, size_t dlen, size_t *readbytes) {
 		rv = 1;
 	}
 
-	return (rv);
+	return rv;
 }
 #endif
 
@@ -121,7 +119,7 @@ BIO_write_ex(BIO *b, const void *data, size_t dlen, size_t *written) {
 		rv = 1;
 	}
 
-	return (rv);
+	return rv;
 }
 #endif
 
@@ -144,7 +142,7 @@ OPENSSL_init_crypto(uint64_t opts, const void *settings) {
 		OpenSSL_add_all_ciphers();
 	}
 
-	return (1);
+	return 1;
 }
 #endif
 
@@ -159,7 +157,7 @@ OPENSSL_init_ssl(uint64_t opts, const void *settings) {
 		SSL_load_error_strings();
 	}
 
-	return (1);
+	return 1;
 }
 #endif
 
@@ -173,7 +171,7 @@ OPENSSL_cleanup(void) {
 #if !HAVE_SSL_CTX_UP_REF
 int
 SSL_CTX_up_ref(SSL_CTX *ctx) {
-	return (CRYPTO_add(&ctx->references, 1, CRYPTO_LOCK_SSL_CTX) > 0);
+	return CRYPTO_add(&ctx->references, 1, CRYPTO_LOCK_SSL_CTX) > 0;
 }
 #endif /* !HAVE_SSL_CTX_UP_REF */
 
@@ -181,7 +179,7 @@ SSL_CTX_up_ref(SSL_CTX *ctx) {
 
 int
 X509_STORE_up_ref(X509_STORE *store) {
-	return (CRYPTO_add(&store->references, 1, CRYPTO_LOCK_X509_STORE) > 0);
+	return CRYPTO_add(&store->references, 1, CRYPTO_LOCK_X509_STORE) > 0;
 }
 
 #endif /* !HAVE_OPENSSL_CLEANUP */
