@@ -12,9 +12,15 @@
  */
 
 /*
+ * SPDX-License-Identifier: BSD-3-Clause
+ *
+ * Copyright (c) 2001 Mike Barcroft <mike@FreeBSD.org>
  * Copyright (c) 1990, 1993
  *	The Regents of the University of California.  All rights reserved.
  *
+ * This code is derived from software contributed to Berkeley by
+ * Chris Torek.
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -74,7 +80,7 @@ strlcpy(char *dst, const char *src, size_t size) {
 		}
 	}
 
-	return (s - src - 1); /* count does not include NUL */
+	return s - src - 1; /* count does not include NUL */
 }
 #endif /* !defined(HAVE_STRLCPY) */
 
@@ -94,7 +100,7 @@ strlcat(char *dst, const char *src, size_t size) {
 	n = size - dlen;
 
 	if (n == 0U) {
-		return (dlen + strlen(s));
+		return dlen + strlen(s);
 	}
 	while (*s != '\0') {
 		if (n != 1U) {
@@ -105,11 +111,33 @@ strlcat(char *dst, const char *src, size_t size) {
 	}
 	*d = '\0';
 
-	return (dlen + (s - src)); /* count does not include NUL */
+	return dlen + (s - src); /* count does not include NUL */
 }
 #endif /* !defined(HAVE_STRLCAT) */
 
+#if !defined(HAVE_STRNSTR)
+char *
+strnstr(const char *s, const char *find, size_t slen) {
+	char c, sc;
+	size_t len;
+
+	if ((c = *find++) != '\0') {
+		len = strlen(find);
+		do {
+			do {
+				if (slen-- < 1 || (sc = *s++) == '\0')
+					return NULL;
+			} while (sc != c);
+			if (len > slen)
+				return NULL;
+		} while (strncmp(s, find, len) != 0);
+		s--;
+	}
+	return (char *)s;
+}
+#endif
+
 int
 isc_string_strerror_r(int errnum, char *buf, size_t buflen) {
-	return (strerror_r(errnum, buf, buflen));
+	return strerror_r(errnum, buf, buflen);
 }
