@@ -1,6 +1,8 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
+ * SPDX-License-Identifier: MPL-2.0 AND BSD-2-Clause
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -89,8 +91,8 @@ conv_num(const char **buf, int *dest, int llim, int ulim) {
 	/* The limit also determines the number of valid digits. */
 	int rulim = ulim;
 
-	if (**buf < '0' || **buf > '9') {
-		return (0);
+	if (!isdigit((unsigned char)**buf)) {
+		return 0;
 	}
 
 	do {
@@ -101,11 +103,11 @@ conv_num(const char **buf, int *dest, int llim, int ulim) {
 		 **buf <= '9');
 
 	if (result < llim || result > ulim) {
-		return (0);
+		return 0;
 	}
 
 	*dest = result;
-	return (1);
+	return 1;
 }
 
 time_t
@@ -129,7 +131,7 @@ isc_tm_timegm(struct tm *tm) {
 	      (86400 *
 	       (yday + ((tm->tm_year - 70) * 365) + ((tm->tm_year - 69) / 4) -
 		((tm->tm_year - 1) / 100) + ((tm->tm_year + 299) / 400)));
-	return (ret);
+	return ret;
 }
 
 char *
@@ -170,7 +172,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 		case '%': /* "%%" is converted to "%". */
 		literal:
 			if (c != *bp++) {
-				return (0);
+				return 0;
 			}
 			break;
 
@@ -194,49 +196,49 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 		case 'c': /* Date and time, using the locale's format. */
 			LEGAL_ALT(ALT_E);
 			if (!(bp = isc_tm_strptime(bp, "%x %X", tm))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'D': /* The date as "%m/%d/%y". */
 			LEGAL_ALT(0);
 			if (!(bp = isc_tm_strptime(bp, "%m/%d/%y", tm))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'R': /* The time as "%H:%M". */
 			LEGAL_ALT(0);
 			if (!(bp = isc_tm_strptime(bp, "%H:%M", tm))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'r': /* The time in 12-hour clock representation. */
 			LEGAL_ALT(0);
 			if (!(bp = isc_tm_strptime(bp, "%I:%M:%S %p", tm))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'T': /* The time as "%H:%M:%S". */
 			LEGAL_ALT(0);
 			if (!(bp = isc_tm_strptime(bp, "%H:%M:%S", tm))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'X': /* The time, using the locale's format. */
 			LEGAL_ALT(ALT_E);
 			if (!(bp = isc_tm_strptime(bp, "%H:%M:%S", tm))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'x': /* The date, using the locale's format. */
 			LEGAL_ALT(ALT_E);
 			if (!(bp = isc_tm_strptime(bp, "%m/%d/%y", tm))) {
-				return (0);
+				return 0;
 			}
 			break;
 
@@ -262,7 +264,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 
 			/* Nothing matched. */
 			if (i == 7) {
-				return (0);
+				return 0;
 			}
 
 			tm->tm_wday = i;
@@ -289,7 +291,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 
 			/* Nothing matched. */
 			if (i == 12) {
-				return (0);
+				return 0;
 			}
 
 			tm->tm_mon = i;
@@ -299,7 +301,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 		case 'C': /* The century number. */
 			LEGAL_ALT(ALT_E);
 			if (!(conv_num(&bp, &i, 0, 99))) {
-				return (0);
+				return 0;
 			}
 
 			if (split_year) {
@@ -314,27 +316,27 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 		case 'e':
 			LEGAL_ALT(ALT_O);
 			if (!(conv_num(&bp, &tm->tm_mday, 1, 31))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'k': /* The hour (24-hour clock representation). */
 			LEGAL_ALT(0);
-		/* FALLTHROUGH */
+			FALLTHROUGH;
 		case 'H':
 			LEGAL_ALT(ALT_O);
 			if (!(conv_num(&bp, &tm->tm_hour, 0, 23))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'l': /* The hour (12-hour clock representation). */
 			LEGAL_ALT(0);
-		/* FALLTHROUGH */
+			FALLTHROUGH;
 		case 'I':
 			LEGAL_ALT(ALT_O);
 			if (!(conv_num(&bp, &tm->tm_hour, 1, 12))) {
-				return (0);
+				return 0;
 			}
 			if (tm->tm_hour == 12) {
 				tm->tm_hour = 0;
@@ -344,7 +346,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 		case 'j': /* The day of year. */
 			LEGAL_ALT(0);
 			if (!(conv_num(&bp, &i, 1, 366))) {
-				return (0);
+				return 0;
 			}
 			tm->tm_yday = i - 1;
 			break;
@@ -352,14 +354,14 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 		case 'M': /* The minute. */
 			LEGAL_ALT(ALT_O);
 			if (!(conv_num(&bp, &tm->tm_min, 0, 59))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'm': /* The month. */
 			LEGAL_ALT(ALT_O);
 			if (!(conv_num(&bp, &i, 1, 12))) {
-				return (0);
+				return 0;
 			}
 			tm->tm_mon = i - 1;
 			break;
@@ -369,7 +371,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 			/* AM? */
 			if (strcasecmp(am_pm[0], bp) == 0) {
 				if (tm->tm_hour > 11) {
-					return (0);
+					return 0;
 				}
 
 				bp += strlen(am_pm[0]);
@@ -379,7 +381,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 			else if (strcasecmp(am_pm[1], bp) == 0)
 			{
 				if (tm->tm_hour > 11) {
-					return (0);
+					return 0;
 				}
 
 				tm->tm_hour += 12;
@@ -388,12 +390,12 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 			}
 
 			/* Nothing matched. */
-			return (0);
+			return 0;
 
 		case 'S': /* The seconds. */
 			LEGAL_ALT(ALT_O);
 			if (!(conv_num(&bp, &tm->tm_sec, 0, 61))) {
-				return (0);
+				return 0;
 			}
 			break;
 
@@ -407,21 +409,21 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 			 * range for now.
 			 */
 			if (!(conv_num(&bp, &i, 0, 53))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'w': /* The day of week, beginning on sunday. */
 			LEGAL_ALT(ALT_O);
 			if (!(conv_num(&bp, &tm->tm_wday, 0, 6))) {
-				return (0);
+				return 0;
 			}
 			break;
 
 		case 'Y': /* The year. */
 			LEGAL_ALT(ALT_E);
 			if (!(conv_num(&bp, &i, 0, 9999))) {
-				return (0);
+				return 0;
 			}
 
 			tm->tm_year = i - TM_YEAR_BASE;
@@ -430,7 +432,7 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 		case 'y': /* The year within 100 years of the epoch. */
 			LEGAL_ALT(ALT_E | ALT_O);
 			if (!(conv_num(&bp, &i, 0, 99))) {
-				return (0);
+				return 0;
 			}
 
 			if (split_year) {
@@ -457,11 +459,11 @@ isc_tm_strptime(const char *buf, const char *fmt, struct tm *tm) {
 			break;
 
 		default: /* Unknown/unsupported conversion. */
-			return (0);
+			return 0;
 		}
 	}
 
 	/* LINTED functional specification */
 	DE_CONST(bp, ret);
-	return (ret);
+	return ret;
 }
