@@ -22,6 +22,7 @@
 #include <isc/thread.h>
 #include <isc/util.h>
 
+#include "mem_p.h"
 #include "trampoline_p.h"
 
 #define ISC__TRAMPOLINE_UNUSED 0
@@ -67,7 +68,7 @@ isc__trampoline_new(int tid, isc_threadfunc_t start, isc_threadarg_t arg) {
 		.self = ISC__TRAMPOLINE_UNUSED,
 	};
 
-	return (trampoline);
+	return trampoline;
 }
 
 void
@@ -131,7 +132,7 @@ done:
 	INSIST(trampoline != NULL);
 	uv_mutex_unlock(&isc__trampoline_lock);
 
-	return (trampoline);
+	return trampoline;
 }
 
 void
@@ -148,7 +149,7 @@ isc__trampoline_detach(isc__trampoline_t *trampoline) {
 		isc__trampoline_min = trampoline->tid;
 	}
 
-	free(trampoline->jemalloc_enforce_init);
+	isc__mem_free_noctx(trampoline->jemalloc_enforce_init, 8);
 	free(trampoline);
 
 	uv_mutex_unlock(&isc__trampoline_lock);
@@ -174,7 +175,7 @@ isc__trampoline_attach(isc__trampoline_t *trampoline) {
 	 * so that an optimizing compiler does not strip away such a pair of
 	 * malloc() + free() calls altogether, as it would foil the fix.
 	 */
-	trampoline->jemalloc_enforce_init = malloc(8);
+	trampoline->jemalloc_enforce_init = isc__mem_alloc_noctx(8);
 	uv_mutex_unlock(&isc__trampoline_lock);
 }
 
@@ -190,5 +191,5 @@ isc__trampoline_run(isc_threadarg_t arg) {
 
 	isc__trampoline_detach(trampoline);
 
-	return (result);
+	return result;
 }
