@@ -51,7 +51,7 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 	 * Copy the buffer as it may not be NULL terminated.
 	 */
 	if (source->length > sizeof(buf) - 1) {
-		return (ISC_R_BADNUMBER);
+		return ISC_R_BADNUMBER;
 	}
 	/* Copy source->length bytes and NULL terminate. */
 	snprintf(buf, sizeof(buf), "%.*s", (int)source->length, source->base);
@@ -66,7 +66,7 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 
 	/* Every duration starts with 'P' */
 	if (toupper((unsigned char)str[0]) != 'P') {
-		return (ISC_R_BADNUMBER);
+		return ISC_R_BADNUMBER;
 	}
 	P = str;
 
@@ -80,10 +80,10 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 		endptr = NULL;
 		lli = strtoll(str + 1, &endptr, 10);
 		if (*endptr != *X) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		if (errno != 0 || lli < 0 || lli > UINT32_MAX) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		duration->parts[0] = (uint32_t)lli;
 		str = X;
@@ -101,10 +101,10 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 		errno = 0;
 		lli = strtoll(str + 1, &endptr, 10);
 		if (*endptr != *X) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		if (errno != 0 || lli < 0 || lli > UINT32_MAX) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		duration->parts[1] = (uint32_t)lli;
 		str = X;
@@ -117,10 +117,10 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 		errno = 0;
 		lli = strtoll(str + 1, &endptr, 10);
 		if (*endptr != *X) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		if (errno != 0 || lli < 0 || lli > UINT32_MAX) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		duration->parts[3] = (uint32_t)lli;
 		str = X;
@@ -139,10 +139,10 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 		errno = 0;
 		lli = strtoll(str + 1, &endptr, 10);
 		if (*endptr != *X) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		if (errno != 0 || lli < 0 || lli > UINT32_MAX) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		duration->parts[4] = (uint32_t)lli;
 		str = X;
@@ -160,10 +160,10 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 		errno = 0;
 		lli = strtoll(str + 1, &endptr, 10);
 		if (*endptr != *X) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		if (errno != 0 || lli < 0 || lli > UINT32_MAX) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		duration->parts[5] = (uint32_t)lli;
 		str = X;
@@ -176,10 +176,10 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 		errno = 0;
 		lli = strtoll(str + 1, &endptr, 10);
 		if (*endptr != *X) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		if (errno != 0 || lli < 0 || lli > UINT32_MAX) {
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		}
 		duration->parts[6] = (uint32_t)lli;
 		str = X;
@@ -191,15 +191,15 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 	if (W != NULL) {
 		if (not_weeks) {
 			/* Mix of weeks and other indicators is not allowed */
-			return (ISC_R_BADNUMBER);
+			return ISC_R_BADNUMBER;
 		} else {
 			errno = 0;
 			lli = strtoll(str + 1, &endptr, 10);
 			if (*endptr != *W) {
-				return (ISC_R_BADNUMBER);
+				return ISC_R_BADNUMBER;
 			}
 			if (errno != 0 || lli < 0 || lli > UINT32_MAX) {
-				return (ISC_R_BADNUMBER);
+				return ISC_R_BADNUMBER;
 			}
 			duration->parts[2] = (uint32_t)lli;
 			str = W;
@@ -208,11 +208,11 @@ isccfg_duration_fromtext(isc_textregion_t *source,
 
 	/* Deal with trailing garbage. */
 	if (str[1] != '\0') {
-		return (ISC_R_BADNUMBER);
+		return ISC_R_BADNUMBER;
 	}
 
 	duration->iso8601 = true;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -237,7 +237,7 @@ isccfg_parse_duration(isc_textregion_t *source, isccfg_duration_t *duration) {
 		}
 	}
 
-	return (result);
+	return result;
 }
 
 uint32_t
@@ -258,5 +258,5 @@ isccfg_duration_toseconds(const isccfg_duration_t *duration) {
 	seconds += (uint64_t)duration->parts[1] * 86400 * 31;  /* Months */
 	seconds += (uint64_t)duration->parts[0] * 86400 * 365; /* Years */
 
-	return (seconds > UINT32_MAX ? UINT32_MAX : (uint32_t)seconds);
+	return seconds > UINT32_MAX ? UINT32_MAX : (uint32_t)seconds;
 }
