@@ -241,10 +241,10 @@ cfg_parse_obj(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	result = type->parse(pctx, type, ret);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	ENSURE(*ret != NULL);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -301,13 +301,13 @@ cfg_create_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 		obj->value.tuple[i] = NULL;
 	}
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (obj != NULL) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
 	}
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -330,11 +330,11 @@ cfg_parse_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	}
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 void
@@ -402,7 +402,7 @@ free_tuple(cfg_parser_t *pctx, cfg_obj_t *obj) {
 bool
 cfg_obj_istuple(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_tuple);
+	return obj->type->rep == &cfg_rep_tuple;
 }
 
 const cfg_obj_t *
@@ -417,7 +417,7 @@ cfg_tuple_get(const cfg_obj_t *tupleobj, const char *name) {
 	fields = tupleobj->type->of;
 	for (f = fields, i = 0; f->name != NULL; f++, i++) {
 		if (strcmp(f->name, name) == 0) {
-			return (tupleobj->value.tuple[i]);
+			return tupleobj->value.tuple[i];
 		}
 	}
 	UNREACHABLE();
@@ -433,13 +433,13 @@ cfg_parse_special(cfg_parser_t *pctx, int special) {
 	if (pctx->token.type == isc_tokentype_special &&
 	    pctx->token.value.as_char == special)
 	{
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "'%c' expected", special);
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -457,13 +457,13 @@ parse_semicolon(cfg_parser_t *pctx) {
 	if (pctx->token.type == isc_tokentype_special &&
 	    pctx->token.value.as_char == ';')
 	{
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	cfg_parser_error(pctx, CFG_LOG_BEFORE, "missing ';'");
 	cfg_ungettoken(pctx);
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -476,13 +476,13 @@ parse_eof(cfg_parser_t *pctx) {
 	CHECK(cfg_gettoken(pctx, 0));
 
 	if (pctx->token.type == isc_tokentype_eof) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "syntax error");
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 cleanup:
-	return (result);
+	return result;
 }
 
 /* A list of files, used internally for pctx->files. */
@@ -533,15 +533,15 @@ cfg_parser_create(isc_mem_t *mctx, isc_log_t *lctx, cfg_parser_t **ret) {
 	CHECK(isc_lex_create(pctx->mctx, 1024, &pctx->lexer));
 
 	isc_lex_setspecials(pctx->lexer, specials);
-	isc_lex_setcomments(pctx->lexer,
-			    (ISC_LEXCOMMENT_C | ISC_LEXCOMMENT_CPLUSPLUS |
-			     ISC_LEXCOMMENT_SHELL));
+	isc_lex_setcomments(pctx->lexer, ISC_LEXCOMMENT_C |
+						 ISC_LEXCOMMENT_CPLUSPLUS |
+						 ISC_LEXCOMMENT_SHELL);
 
 	CHECK(cfg_create_list(pctx, &cfg_type_filelist, &pctx->open_files));
 	CHECK(cfg_create_list(pctx, &cfg_type_filelist, &pctx->closed_files));
 
 	*ret = pctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (pctx->lexer != NULL) {
@@ -550,7 +550,7 @@ cleanup:
 	CLEANUP_OBJ(pctx->open_files);
 	CLEANUP_OBJ(pctx->closed_files);
 	isc_mem_putanddetach(&pctx->mctx, pctx, sizeof(*pctx));
-	return (result);
+	return result;
 }
 
 void
@@ -582,10 +582,10 @@ parser_openfile(cfg_parser_t *pctx, const char *filename) {
 	elt->obj = stringobj;
 	ISC_LIST_APPEND(pctx->open_files->value.list, elt, link);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	CLEANUP_OBJ(stringobj);
-	return (result);
+	return result;
 }
 
 void
@@ -641,11 +641,11 @@ parse2(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(parse_eof(pctx));
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -670,7 +670,7 @@ cfg_parse_file(cfg_parser_t *pctx, const char *filename, const cfg_type_t *type,
 	ISC_LIST_APPEND(pctx->closed_files->value.list, elt, link);
 
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -698,7 +698,7 @@ cfg_parse_buffer(cfg_parser_t *pctx, isc_buffer_t *buffer, const char *file,
 	pctx->buf_name = NULL;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -741,7 +741,7 @@ cfg_parse_void(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	UNUSED(type);
 
-	return (cfg_create_obj(pctx, &cfg_type_void, ret));
+	return cfg_create_obj(pctx, &cfg_type_void, ret);
 }
 
 void
@@ -765,7 +765,7 @@ cfg_doc_void(cfg_printer_t *pctx, const cfg_type_t *type) {
 bool
 cfg_obj_isvoid(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_void);
+	return obj->type->rep == &cfg_rep_void;
 }
 
 cfg_type_t cfg_type_void = { "void",	   cfg_parse_void, cfg_print_void,
@@ -790,13 +790,13 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	CHECK(cfg_gettoken(pctx, 0));
 	if (pctx->token.type != isc_tokentype_string) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected percentage");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	percent = strtoull(TOKEN_STRING(pctx), &endp, 10);
 	if (*endp != '%' || *(endp + 1) != 0) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected percentage");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_percentage, &obj));
@@ -804,7 +804,7 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	*ret = obj;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -823,7 +823,7 @@ cfg_print_percentage(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 uint32_t
 cfg_obj_aspercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_percentage);
-	return (obj->value.uint32);
+	return obj->value.uint32;
 }
 
 cfg_type_t cfg_type_percentage = { "percentage",	 cfg_parse_percentage,
@@ -833,7 +833,7 @@ cfg_type_t cfg_type_percentage = { "percentage",	 cfg_parse_percentage,
 bool
 cfg_obj_ispercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_percentage);
+	return obj->type->rep == &cfg_rep_percentage;
 }
 
 /*
@@ -856,7 +856,7 @@ cfg_parse_fixedpoint(cfg_parser_t *pctx, const cfg_type_t *type,
 	if (pctx->token.type != isc_tokentype_string) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected fixed point number");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	p = TOKEN_STRING(pctx);
@@ -869,7 +869,7 @@ cfg_parse_fixedpoint(cfg_parser_t *pctx, const cfg_type_t *type,
 	{
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected fixed point number");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_fixedpoint, &obj));
@@ -886,7 +886,7 @@ cfg_parse_fixedpoint(cfg_parser_t *pctx, const cfg_type_t *type,
 	*ret = obj;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -906,7 +906,7 @@ cfg_print_fixedpoint(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 uint32_t
 cfg_obj_asfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_fixedpoint);
-	return (obj->value.uint32);
+	return obj->value.uint32;
 }
 
 cfg_type_t cfg_type_fixedpoint = { "fixedpoint",	 cfg_parse_fixedpoint,
@@ -916,7 +916,7 @@ cfg_type_t cfg_type_fixedpoint = { "fixedpoint",	 cfg_parse_fixedpoint,
 bool
 cfg_obj_isfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_fixedpoint);
+	return obj->type->rep == &cfg_rep_fixedpoint;
 }
 
 /*
@@ -935,7 +935,7 @@ cfg_parse_uint32(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_gettoken(pctx, ISC_LEXOPT_NUMBER | ISC_LEXOPT_CNUMBER));
 	if (pctx->token.type != isc_tokentype_number) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected number");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_uint32, &obj));
@@ -943,7 +943,7 @@ cfg_parse_uint32(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	obj->value.uint32 = pctx->token.value.as_ulong;
 	*ret = obj;
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -967,13 +967,13 @@ cfg_print_uint32(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_isuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_uint32);
+	return obj->type->rep == &cfg_rep_uint32;
 }
 
 uint32_t
 cfg_obj_asuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint32);
-	return (obj->value.uint32);
+	return obj->value.uint32;
 }
 
 cfg_type_t cfg_type_uint32 = { "integer",	 cfg_parse_uint32,
@@ -986,13 +986,13 @@ cfg_type_t cfg_type_uint32 = { "integer",	 cfg_parse_uint32,
 bool
 cfg_obj_isuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_uint64);
+	return obj->type->rep == &cfg_rep_uint64;
 }
 
 uint64_t
 cfg_obj_asuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint64);
-	return (obj->value.uint64);
+	return obj->value.uint64;
 }
 
 void
@@ -1016,13 +1016,13 @@ numlen(uint32_t num) {
 	size_t count = 0;
 
 	if (period == 0) {
-		return (1);
+		return 1;
 	}
 	while (period > 0) {
 		count++;
 		period /= 10;
 	}
-	return (count);
+	return count;
 }
 
 /*
@@ -1133,7 +1133,7 @@ cfg_print_duration_or_unlimited(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_isduration(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_duration);
+	return obj->type->rep == &cfg_rep_duration;
 }
 
 uint32_t
@@ -1154,7 +1154,7 @@ parse_duration(cfg_parser_t *pctx, cfg_obj_t **ret) {
 	if (result == ISC_R_RANGE) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "duration or TTL out of range");
-		return (result);
+		return result;
 	} else if (result != ISC_R_SUCCESS) {
 		goto cleanup;
 	}
@@ -1163,12 +1163,12 @@ parse_duration(cfg_parser_t *pctx, cfg_obj_t **ret) {
 	obj->value.duration = duration;
 	*ret = obj;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR,
 			 "expected ISO 8601 duration or TTL value");
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1184,12 +1184,12 @@ cfg_parse_duration(cfg_parser_t *pctx, const cfg_type_t *type,
 		goto cleanup;
 	}
 
-	return (parse_duration(pctx, ret));
+	return parse_duration(pctx, ret);
 
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR,
 			 "expected ISO 8601 duration or TTL value");
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1217,15 +1217,15 @@ cfg_parse_duration_or_unlimited(cfg_parser_t *pctx, const cfg_type_t *type,
 		CHECK(cfg_create_obj(pctx, &cfg_type_duration, &obj));
 		obj->value.duration = duration;
 		*ret = obj;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
-	return (parse_duration(pctx, ret));
+	return parse_duration(pctx, ret);
 
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR,
 			 "expected ISO 8601 duration, TTL value, or unlimited");
-	return (result);
+	return result;
 }
 
 /*%
@@ -1272,14 +1272,14 @@ create_string(cfg_parser_t *pctx, const char *contents, const cfg_type_t *type,
 	obj->value.string.base = isc_mem_get(pctx->mctx, len + 1);
 	if (obj->value.string.base == 0) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	}
 	memmove(obj->value.string.base, contents, len);
 	obj->value.string.base[len] = '\0';
 
 	*ret = obj;
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1294,12 +1294,11 @@ cfg_parse_qstring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_gettoken(pctx, CFG_LEXOPT_QSTRING));
 	if (pctx->token.type != isc_tokentype_qstring) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected quoted string");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1312,12 +1311,11 @@ parse_ustring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	if (pctx->token.type != isc_tokentype_string) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected unquoted string");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_ustring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_ustring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1330,10 +1328,9 @@ cfg_parse_astring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	UNUSED(type);
 
 	CHECK(cfg_getstringtoken(pctx));
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1346,10 +1343,9 @@ cfg_parse_sstring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	UNUSED(type);
 
 	CHECK(cfg_getstringtoken(pctx));
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_sstring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_sstring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1361,12 +1357,12 @@ parse_btext(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_gettoken(pctx, ISC_LEXOPT_BTEXT));
 	if (pctx->token.type != isc_tokentype_btext) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected bracketed text");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (create_string(pctx, TOKEN_STRING(pctx),
-			      &cfg_type_bracketed_text, ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_bracketed_text,
+			     ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 static void
@@ -1400,10 +1396,10 @@ cfg_is_enum(const char *s, const char *const *enums) {
 
 	for (p = enums; *p != NULL; p++) {
 		if (strcasecmp(*p, s) == 0) {
-			return (true);
+			return true;
 		}
 	}
-	return (false);
+	return false;
 }
 
 static isc_result_t
@@ -1411,10 +1407,10 @@ check_enum(cfg_parser_t *pctx, cfg_obj_t *obj, const char *const *enums) {
 	const char *s = obj->value.string.base;
 
 	if (cfg_is_enum(s, enums)) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	cfg_parser_error(pctx, 0, "'%s' unexpected", s);
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 }
 
 isc_result_t
@@ -1429,10 +1425,10 @@ cfg_parse_enum(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(parse_ustring(pctx, NULL, &obj));
 	CHECK(check_enum(pctx, obj, type->of));
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 void
@@ -1465,7 +1461,7 @@ cfg_parse_enum_or_other(cfg_parser_t *pctx, const cfg_type_t *enumtype,
 		CHECK(cfg_parse_obj(pctx, othertype, ret));
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -1545,13 +1541,13 @@ free_string(cfg_parser_t *pctx, cfg_obj_t *obj) {
 bool
 cfg_obj_isstring(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_string);
+	return obj->type->rep == &cfg_rep_string;
 }
 
 const char *
 cfg_obj_asstring(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_string);
-	return (obj->value.string.base);
+	return obj->value.string.base;
 }
 
 /* Quoted string only */
@@ -1641,11 +1637,11 @@ parse_geoip(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_parse_obj(pctx, fields[3].type, &obj->value.tuple[3]));
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 static void
@@ -1699,7 +1695,7 @@ parse_addrmatchelt(cfg_parser_t *pctx, const cfg_type_t *type,
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
 					 "'geoip' "
 					 "not supported in this build");
-			return (ISC_R_UNEXPECTEDTOKEN);
+			return ISC_R_UNEXPECTEDTOKEN;
 #endif /* if defined(HAVE_GEOIP2) */
 		} else {
 			if (cfg_lookingat_netaddr(
@@ -1726,10 +1722,10 @@ parse_addrmatchelt(cfg_parser_t *pctx, const cfg_type_t *type,
 	bad:
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected IP match list element");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 /*%
@@ -1787,7 +1783,7 @@ parse_optional_btext(cfg_parser_t *pctx, const cfg_type_t *type,
 		CHECK(cfg_parse_obj(pctx, &cfg_type_void, ret));
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 static void
@@ -1823,13 +1819,13 @@ cfg_type_t cfg_type_optional_bracketed_text = { "optional_btext",
 bool
 cfg_obj_isboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_boolean);
+	return obj->type->rep == &cfg_rep_boolean;
 }
 
 bool
 cfg_obj_asboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_boolean);
-	return (obj->value.boolean);
+	return obj->value.boolean;
 }
 
 isc_result_t
@@ -1845,7 +1841,7 @@ cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	result = cfg_gettoken(pctx, 0);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	if (pctx->token.type != isc_tokentype_string) {
@@ -1869,14 +1865,14 @@ cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_create_obj(pctx, &cfg_type_boolean, &obj));
 	obj->value.boolean = value;
 	*ret = obj;
-	return (result);
+	return result;
 
 bad_boolean:
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "boolean expected");
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -1910,7 +1906,7 @@ cfg_create_list(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **obj) {
 	CHECK(cfg_create_obj(pctx, type, obj));
 	ISC_LIST_INIT((*obj)->value.list);
 cleanup:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1921,7 +1917,7 @@ create_listelt(cfg_parser_t *pctx, cfg_listelt_t **eltp) {
 	elt->obj = NULL;
 	ISC_LINK_INIT(elt, link);
 	*eltp = elt;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -1962,11 +1958,11 @@ cfg_parse_listelt(cfg_parser_t *pctx, const cfg_type_t *elttype,
 	elt->obj = value;
 
 	*ret = elt;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	isc_mem_put(pctx->mctx, elt, sizeof(*elt));
-	return (result);
+	return result;
 }
 
 /*
@@ -1995,14 +1991,14 @@ parse_list(cfg_parser_t *pctx, const cfg_type_t *listtype, cfg_obj_t **ret) {
 		elt = NULL;
 	}
 	*ret = listobj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (elt != NULL) {
 		free_listelt(pctx, elt);
 	}
 	CLEANUP_OBJ(listobj);
-	return (result);
+	return result;
 }
 
 static void
@@ -2037,7 +2033,7 @@ cfg_parse_bracketed_list(cfg_parser_t *pctx, const cfg_type_t *type,
 	CHECK(parse_list(pctx, type, ret));
 	CHECK(cfg_parse_special(pctx, '}'));
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -2093,11 +2089,11 @@ cfg_parse_spacelist(cfg_parser_t *pctx, const cfg_type_t *listtype,
 		ISC_LIST_APPEND(listobj->value.list, elt, link);
 	}
 	*ret = listobj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(listobj);
-	return (result);
+	return result;
 }
 
 void
@@ -2123,22 +2119,22 @@ cfg_print_spacelist(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_islist(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_list);
+	return obj->type->rep == &cfg_rep_list;
 }
 
 const cfg_listelt_t *
 cfg_list_first(const cfg_obj_t *obj) {
 	REQUIRE(obj == NULL || obj->type->rep == &cfg_rep_list);
 	if (obj == NULL) {
-		return (NULL);
+		return NULL;
 	}
-	return (ISC_LIST_HEAD(obj->value.list));
+	return ISC_LIST_HEAD(obj->value.list);
 }
 
 const cfg_listelt_t *
 cfg_list_next(const cfg_listelt_t *elt) {
 	REQUIRE(elt != NULL);
-	return (ISC_LIST_NEXT(elt, link));
+	return ISC_LIST_NEXT(elt, link);
 }
 
 /*
@@ -2151,7 +2147,7 @@ cfg_list_length(const cfg_obj_t *obj, bool recurse) {
 	unsigned int count = 0;
 
 	if (obj == NULL || !cfg_obj_islist(obj)) {
-		return (0U);
+		return 0U;
 	}
 	for (elt = cfg_list_first(obj); elt != NULL; elt = cfg_list_next(elt)) {
 		if (recurse && cfg_obj_islist(elt->obj)) {
@@ -2160,13 +2156,13 @@ cfg_list_length(const cfg_obj_t *obj, bool recurse) {
 			count++;
 		}
 	}
-	return (count);
+	return count;
 }
 
 cfg_obj_t *
 cfg_listelt_value(const cfg_listelt_t *elt) {
 	REQUIRE(elt != NULL);
-	return (elt->obj);
+	return elt->obj;
 }
 
 /*
@@ -2375,14 +2371,14 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	}
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(value);
 	CLEANUP_OBJ(obj);
 	CLEANUP_OBJ(eltobj);
 	CLEANUP_OBJ(includename);
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -2400,11 +2396,11 @@ parse_symtab_elt(cfg_parser_t *pctx, const char *name, cfg_type_t *elttype,
 
 	symval.as_pointer = obj;
 	CHECK(isc_symtab_define(symtab, name, 1, symval, isc_symexists_reject));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 /*
@@ -2422,7 +2418,7 @@ cfg_parse_map(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_parse_mapbody(pctx, type, ret));
 	CHECK(cfg_parse_special(pctx, '}'));
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -2444,11 +2440,11 @@ parse_any_named_map(cfg_parser_t *pctx, cfg_type_t *nametype,
 	CHECK(cfg_parse_map(pctx, type, &mapobj));
 	mapobj->value.map.id = idobj;
 	*ret = mapobj;
-	return (result);
+	return result;
 cleanup:
 	CLEANUP_OBJ(idobj);
 	CLEANUP_OBJ(mapobj);
-	return (result);
+	return result;
 }
 
 /*
@@ -2458,7 +2454,7 @@ cleanup:
 isc_result_t
 cfg_parse_named_map(cfg_parser_t *pctx, const cfg_type_t *type,
 		    cfg_obj_t **ret) {
-	return (parse_any_named_map(pctx, &cfg_type_astring, type, ret));
+	return parse_any_named_map(pctx, &cfg_type_astring, type, ret);
 }
 
 /*
@@ -2468,7 +2464,7 @@ cfg_parse_named_map(cfg_parser_t *pctx, const cfg_type_t *type,
 isc_result_t
 cfg_parse_addressed_map(cfg_parser_t *pctx, const cfg_type_t *type,
 			cfg_obj_t **ret) {
-	return (parse_any_named_map(pctx, &cfg_type_netaddr, type, ret));
+	return parse_any_named_map(pctx, &cfg_type_netaddr, type, ret);
 }
 
 /*
@@ -2478,7 +2474,7 @@ cfg_parse_addressed_map(cfg_parser_t *pctx, const cfg_type_t *type,
 isc_result_t
 cfg_parse_netprefix_map(cfg_parser_t *pctx, const cfg_type_t *type,
 			cfg_obj_t **ret) {
-	return (parse_any_named_map(pctx, &cfg_type_netprefix, type, ret));
+	return parse_any_named_map(pctx, &cfg_type_netprefix, type, ret);
 }
 
 static void
@@ -2667,7 +2663,7 @@ cfg_doc_map(cfg_printer_t *pctx, const cfg_type_t *type) {
 bool
 cfg_obj_ismap(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_map);
+	return obj->type->rep == &cfg_rep_map;
 }
 
 isc_result_t
@@ -2684,16 +2680,16 @@ cfg_map_get(const cfg_obj_t *mapobj, const char *name, const cfg_obj_t **obj) {
 
 	result = isc_symtab_lookup(map->symtab, name, MAP_SYM, &val);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	*obj = val.as_pointer;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 const cfg_obj_t *
 cfg_map_getname(const cfg_obj_t *mapobj) {
 	REQUIRE(mapobj != NULL && mapobj->type->rep == &cfg_rep_map);
-	return (mapobj->value.map.id);
+	return mapobj->value.map.id;
 }
 
 unsigned int
@@ -2703,7 +2699,7 @@ cfg_map_count(const cfg_obj_t *mapobj) {
 	REQUIRE(mapobj != NULL && mapobj->type->rep == &cfg_rep_map);
 
 	map = &mapobj->value.map;
-	return (isc_symtab_count(map->symtab));
+	return isc_symtab_count(map->symtab);
 }
 
 const char *
@@ -2717,17 +2713,17 @@ cfg_map_firstclause(const cfg_type_t *map, const void **clauses,
 
 	clauseset = map->of;
 	if (*clauseset == NULL) {
-		return (NULL);
+		return NULL;
 	}
 	*clauses = *clauseset;
 	*idx = 0;
 	while ((*clauseset)[*idx].name == NULL) {
 		*clauses = (*++clauseset);
 		if (*clauses == NULL) {
-			return (NULL);
+			return NULL;
 		}
 	}
-	return ((*clauseset)[*idx].name);
+	return (*clauseset)[*idx].name;
 }
 
 const char *
@@ -2749,10 +2745,10 @@ cfg_map_nextclause(const cfg_type_t *map, const void **clauses,
 		*idx = 0;
 		*clauses = (*++clauseset);
 		if (*clauses == NULL) {
-			return (NULL);
+			return NULL;
 		}
 	}
-	return ((*clauseset)[*idx].name);
+	return (*clauseset)[*idx].name;
 }
 
 /* Parse an arbitrary token, storing its raw text representation. */
@@ -2779,13 +2775,13 @@ parse_token(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	memmove(obj->value.string.base, r.base, r.length);
 	obj->value.string.base[r.length] = '\0';
 	*ret = obj;
-	return (result);
+	return result;
 
 cleanup:
 	if (obj != NULL) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
 	}
-	return (result);
+	return result;
 }
 
 cfg_type_t cfg_type_token = { "token",		 parse_token,
@@ -2832,11 +2828,11 @@ parse_unsupported(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	}
 	INSIST(braces == 0);
 	*ret = listobj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(listobj);
-	return (result);
+	return result;
 }
 
 cfg_type_t cfg_type_unsupported = { "unsupported",	 parse_unsupported,
@@ -2859,17 +2855,17 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 	struct in6_addr in6a;
 
 	if (pctx->token.type != isc_tokentype_string) {
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	s = TOKEN_STRING(pctx);
 	if ((flags & CFG_ADDR_WILDOK) != 0 && strcmp(s, "*") == 0) {
 		if ((flags & CFG_ADDR_V4OK) != 0) {
 			isc_netaddr_any(na);
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		} else if ((flags & CFG_ADDR_V6OK) != 0) {
 			isc_netaddr_any6(na);
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		} else {
 			UNREACHABLE();
 		}
@@ -2877,7 +2873,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 		if ((flags & (CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK)) != 0) {
 			if (inet_pton(AF_INET, s, &in4a) == 1) {
 				isc_netaddr_fromin(na, &in4a);
-				return (ISC_R_SUCCESS);
+				return ISC_R_SUCCESS;
 			}
 		}
 		if ((flags & CFG_ADDR_V4PREFIXOK) != 0 && strlen(s) <= 15U) {
@@ -2889,7 +2885,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 				strlcat(buf, ".0", sizeof(buf));
 				if (inet_pton(AF_INET, buf, &in4a) == 1) {
 					isc_netaddr_fromin(na, &in4a);
-					return (ISC_R_IPV4PREFIX);
+					return ISC_R_IPV4PREFIX;
 				}
 			}
 		}
@@ -2911,17 +2907,17 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 					result = isc_netscope_pton(
 						AF_INET6, d + 1, &in6a, &zone);
 					if (result != ISC_R_SUCCESS) {
-						return (result);
+						return result;
 					}
 				}
 
 				isc_netaddr_fromin6(na, &in6a);
 				isc_netaddr_setzone(na, zone);
-				return (ISC_R_SUCCESS);
+				return ISC_R_SUCCESS;
 			}
 		}
 	}
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 }
 
 isc_result_t
@@ -2957,7 +2953,7 @@ cfg_parse_rawaddr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 		}
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 bool
@@ -2968,7 +2964,7 @@ cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	REQUIRE(pctx != NULL);
 
 	result = token_addr(pctx, flags, &na_dummy);
-	return (result == ISC_R_SUCCESS || result == ISC_R_IPV4PREFIX);
+	return result == ISC_R_SUCCESS || result == ISC_R_IPV4PREFIX;
 }
 
 isc_result_t
@@ -2985,22 +2981,22 @@ cfg_parse_rawport(cfg_parser_t *pctx, unsigned int flags, in_port_t *port) {
 	    strcmp(TOKEN_STRING(pctx), "*") == 0)
 	{
 		*port = 0;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	if (pctx->token.type != isc_tokentype_number) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected port number or '*'");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 	if (pctx->token.value.as_ulong >= 65536U) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "port number out of range");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 	*port = (in_port_t)(pctx->token.value.as_ulong);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -3039,10 +3035,10 @@ parse_netaddr(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	isc_sockaddr_fromnetaddr(&obj->value.sockaddr, &netaddr, 0);
 	obj->value.sockaddrdscp.dscp = -1;
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 static void
@@ -3138,13 +3134,13 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		if (pctx->token.type != isc_tokentype_number) {
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
 					 "expected prefix length");
-			return (ISC_R_UNEXPECTEDTOKEN);
+			return ISC_R_UNEXPECTEDTOKEN;
 		}
 		prefixlen = pctx->token.value.as_ulong;
 		if (prefixlen > addrlen) {
 			cfg_parser_error(pctx, CFG_LOG_NOPREP,
 					 "invalid prefix length");
-			return (ISC_R_RANGE);
+			return ISC_R_RANGE;
 		}
 		result = isc_netaddr_prefixok(&netaddr, prefixlen);
 		if (result != ISC_R_SUCCESS) {
@@ -3154,13 +3150,13 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 					 "'%s/%u': address/prefix length "
 					 "mismatch",
 					 buf, prefixlen);
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 	} else {
 		if (expectprefix) {
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
 					 "incomplete IPv4 address or prefix");
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 		prefixlen = addrlen;
 	}
@@ -3168,10 +3164,10 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 	obj->value.netprefix.address = netaddr;
 	obj->value.netprefix.prefixlen = prefixlen;
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "expected network prefix");
-	return (result);
+	return result;
 }
 
 static void
@@ -3186,7 +3182,7 @@ print_netprefix(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_isnetprefix(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_netprefix);
+	return obj->type->rep == &cfg_rep_netprefix;
 }
 
 void
@@ -3264,11 +3260,11 @@ parse_sockaddrsub(cfg_parser_t *pctx, const cfg_type_t *type, int flags,
 	}
 	isc_sockaddr_fromnetaddr(&obj->value.sockaddr, &netaddr, port);
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 static unsigned int sockaddr_flags = CFG_ADDR_V4OK | CFG_ADDR_V6OK |
@@ -3294,7 +3290,7 @@ cfg_parse_sockaddr(cfg_parser_t *pctx, const cfg_type_t *type,
 
 	flagp = type->of;
 
-	return (parse_sockaddrsub(pctx, &cfg_type_sockaddr, *flagp, ret));
+	return parse_sockaddrsub(pctx, &cfg_type_sockaddr, *flagp, ret);
 }
 
 void
@@ -3363,13 +3359,13 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 bool
 cfg_obj_issockaddr(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_sockaddr);
+	return obj->type->rep == &cfg_rep_sockaddr;
 }
 
 const isc_sockaddr_t *
 cfg_obj_assockaddr(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_sockaddr);
-	return (&obj->value.sockaddr);
+	return &obj->value.sockaddr;
 }
 
 isc_result_t
@@ -3379,7 +3375,7 @@ cfg_gettoken(cfg_parser_t *pctx, int options) {
 	REQUIRE(pctx != NULL);
 
 	if (pctx->seen_eof) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	options |= (ISC_LEXOPT_EOF | ISC_LEXOPT_NOMORE);
@@ -3429,7 +3425,7 @@ redo:
 				 isc_result_totext(result));
 		break;
 	}
-	return (result);
+	return result;
 }
 
 void
@@ -3452,7 +3448,7 @@ cfg_peektoken(cfg_parser_t *pctx, int options) {
 	CHECK(cfg_gettoken(pctx, options));
 	cfg_ungettoken(pctx);
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -3465,16 +3461,16 @@ cfg_getstringtoken(cfg_parser_t *pctx) {
 
 	result = cfg_gettoken(pctx, CFG_LEXOPT_QSTRING);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	if (pctx->token.type != isc_tokentype_string &&
 	    pctx->token.type != isc_tokentype_qstring)
 	{
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected string");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -3510,15 +3506,15 @@ static bool
 have_current_file(cfg_parser_t *pctx) {
 	cfg_listelt_t *elt;
 	if (pctx->open_files == NULL) {
-		return (false);
+		return false;
 	}
 
 	elt = ISC_LIST_TAIL(pctx->open_files->value.list);
 	if (elt == NULL) {
-		return (false);
+		return false;
 	}
 
-	return (true);
+	return true;
 }
 
 static char *
@@ -3528,17 +3524,17 @@ current_file(cfg_parser_t *pctx) {
 	cfg_obj_t *fileobj;
 
 	if (!have_current_file(pctx)) {
-		return (none);
+		return none;
 	}
 
 	elt = ISC_LIST_TAIL(pctx->open_files->value.list);
 	if (elt == NULL) { /* shouldn't be possible, but... */
-		return (none);
+		return none;
 	}
 
 	fileobj = elt->obj;
 	INSIST(fileobj->type == &cfg_type_qstring);
-	return (fileobj->value.string.base);
+	return fileobj->value.string.base;
 }
 
 static void
@@ -3637,14 +3633,14 @@ const char *
 cfg_obj_file(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
 
-	return (obj->file);
+	return obj->file;
 }
 
 unsigned int
 cfg_obj_line(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
 
-	return (obj->line);
+	return obj->line;
 }
 
 isc_result_t
@@ -3666,7 +3662,7 @@ cfg_create_obj(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	*ret = obj;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -3694,13 +3690,13 @@ create_map(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	obj->value.map.id = NULL;
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (obj != NULL) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
 	}
-	return (result);
+	return result;
 }
 
 static void
@@ -3714,7 +3710,7 @@ cfg_obj_istype(const cfg_obj_t *obj, const cfg_type_t *type) {
 	REQUIRE(obj != NULL);
 	REQUIRE(type != NULL);
 
-	return (obj->type == type);
+	return obj->type == type;
 }
 
 /*
@@ -3810,7 +3806,7 @@ cfg_parser_mapadd(cfg_parser_t *pctx, cfg_obj_t *mapobj, cfg_obj_t *obj,
 
 breakout:
 	if (clause == NULL || clause->name == NULL) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	result = isc_symtab_lookup(map->symtab, clausename, 0, &symval);
@@ -3851,7 +3847,7 @@ cleanup:
 	}
 	CLEANUP_OBJ(destobj);
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -3880,7 +3876,7 @@ cfg_pluginlist_foreach(const cfg_obj_t *config, const cfg_obj_t *list,
 		if (strcasecmp(type, "query") != 0) {
 			cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
 				    "unsupported plugin type");
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 
 		library = cfg_obj_asstring(cfg_tuple_get(plugin, "library"));
@@ -3897,5 +3893,5 @@ cfg_pluginlist_foreach(const cfg_obj_t *config, const cfg_obj_t *list,
 		}
 	}
 
-	return (result);
+	return result;
 }
