@@ -38,7 +38,7 @@
 isc_result_t
 ns_server_create(isc_mem_t *mctx, ns_matchview_t matchingview,
 		 ns_server_t **sctxp) {
-	ns_server_t *sctx;
+	ns_server_t *sctx = NULL;
 	isc_result_t result;
 
 	REQUIRE(sctxp != NULL && *sctxp == NULL);
@@ -49,6 +49,11 @@ ns_server_create(isc_mem_t *mctx, ns_matchview_t matchingview,
 
 	isc_mem_attach(mctx, &sctx->mctx);
 
+	/*
+	 * See here for more details:
+	 * https://github.com/jemalloc/jemalloc/issues/2483
+	 */
+
 	isc_refcount_init(&sctx->references, 1);
 
 	isc_quota_init(&sctx->xfroutquota, 10);
@@ -97,7 +102,6 @@ ns_server_create(isc_mem_t *mctx, ns_matchview_t matchingview,
 
 	sctx->fuzztype = isc_fuzz_none;
 	sctx->fuzznotify = NULL;
-	sctx->gethostname = NULL;
 
 	sctx->matchingview = matchingview;
 	sctx->answercookie = true;
@@ -107,7 +111,7 @@ ns_server_create(isc_mem_t *mctx, ns_matchview_t matchingview,
 	sctx->magic = SCTX_MAGIC;
 	*sctxp = sctx;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -228,7 +232,7 @@ ns_server_setserverid(ns_server_t *sctx, const char *serverid) {
 		sctx->server_id = isc_mem_strdup(sctx->mctx, serverid);
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -245,7 +249,7 @@ bool
 ns_server_getoption(ns_server_t *sctx, unsigned int option) {
 	REQUIRE(SCTX_VALID(sctx));
 
-	return ((sctx->options & option) != 0);
+	return (sctx->options & option) != 0;
 }
 
 void
