@@ -137,7 +137,8 @@ log_rr(dns_name_t *name, dns_rdata_t *rdata, uint32_t ttl) {
 	rdl.rdclass = rdata->rdclass;
 	rdl.ttl = ttl;
 	if (rdata->type == dns_rdatatype_sig ||
-	    rdata->type == dns_rdatatype_rrsig) {
+	    rdata->type == dns_rdatatype_rrsig)
+	{
 		rdl.covers = dns_rdata_covers(rdata);
 	} else {
 		rdl.covers = dns_rdatatype_none;
@@ -247,23 +248,23 @@ ixfr_rrstream_create(isc_mem_t *mctx, const char *journal_filename,
 				    sizep));
 
 	*sp = (rrstream_t *)s;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	ixfr_rrstream_destroy((rrstream_t **)(void *)&s);
-	return (result);
+	return result;
 }
 
 static isc_result_t
 ixfr_rrstream_first(rrstream_t *rs) {
 	ixfr_rrstream_t *s = (ixfr_rrstream_t *)rs;
-	return (dns_journal_first_rr(s->journal));
+	return dns_journal_first_rr(s->journal);
 }
 
 static isc_result_t
 ixfr_rrstream_next(rrstream_t *rs) {
 	ixfr_rrstream_t *s = (ixfr_rrstream_t *)rs;
-	return (dns_journal_next_rr(s->journal));
+	return dns_journal_next_rr(s->journal);
 }
 
 static void
@@ -328,11 +329,11 @@ axfr_rrstream_create(isc_mem_t *mctx, dns_db_t *db, dns_dbversion_t *ver,
 	s->it_valid = true;
 
 	*sp = (rrstream_t *)s;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	axfr_rrstream_destroy((rrstream_t **)(void *)&s);
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -341,7 +342,7 @@ axfr_rrstream_first(rrstream_t *rs) {
 	isc_result_t result;
 	result = dns_rriterator_first(&s->it);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	/* Skip SOA records. */
 	for (;;) {
@@ -358,7 +359,7 @@ axfr_rrstream_first(rrstream_t *rs) {
 			break;
 		}
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -381,7 +382,7 @@ axfr_rrstream_next(rrstream_t *rs) {
 			break;
 		}
 	}
-	return (result);
+	return result;
 }
 
 static void
@@ -448,23 +449,23 @@ soa_rrstream_create(isc_mem_t *mctx, dns_db_t *db, dns_dbversion_t *ver,
 				    &s->soa_tuple));
 
 	*sp = (rrstream_t *)s;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	soa_rrstream_destroy((rrstream_t **)(void *)&s);
-	return (result);
+	return result;
 }
 
 static isc_result_t
 soa_rrstream_first(rrstream_t *rs) {
 	UNUSED(rs);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
 soa_rrstream_next(rrstream_t *rs) {
 	UNUSED(rs);
-	return (ISC_R_NOMORE);
+	return ISC_R_NOMORE;
 }
 
 static void
@@ -552,7 +553,7 @@ compound_rrstream_create(isc_mem_t *mctx, rrstream_t **soa_stream,
 	*data_stream = NULL;
 	*soa_stream = NULL;
 	*sp = (rrstream_t *)s;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -563,7 +564,7 @@ compound_rrstream_first(rrstream_t *rs) {
 		rrstream_t *curstream = s->components[s->state];
 		s->result = curstream->methods->first(curstream);
 	} while (s->result == ISC_R_NOMORE && s->state < 2);
-	return (s->result);
+	return s->result;
 }
 
 static isc_result_t
@@ -578,13 +579,13 @@ compound_rrstream_next(rrstream_t *rs) {
 		 */
 		curstream->methods->pause(curstream);
 		if (s->state == 2) {
-			return (ISC_R_NOMORE);
+			return ISC_R_NOMORE;
 		}
 		s->state++;
 		curstream = s->components[s->state];
 		s->result = curstream->methods->first(curstream);
 	}
-	return (s->result);
+	return s->result;
 }
 
 static void
@@ -1029,7 +1030,7 @@ got_soa:
 		}
 		if (result == ISC_R_NOTFOUND || result == ISC_R_RANGE) {
 			xfrout_log1(client, question_name, question_class,
-				    ISC_LOG_DEBUG(4),
+				    ISC_LOG_INFO,
 				    "IXFR version not in journal, "
 				    "falling back to AXFR");
 			mnemonic = "AXFR-style IXFR";
@@ -1044,7 +1045,7 @@ got_soa:
 				data_stream->methods->destroy(&data_stream);
 				data_stream = NULL;
 				xfrout_log1(client, question_name,
-					    question_class, ISC_LOG_DEBUG(4),
+					    question_class, ISC_LOG_INFO,
 					    "IXFR delta size (%zu bytes) "
 					    "exceeds the maximum ratio to "
 					    "database size "
@@ -1263,7 +1264,7 @@ xfrout_ctx_create(isc_mem_t *mctx, ns_client_t *client, unsigned int id,
 	 * Note that although 65535-byte RRs are allowed in principle, they
 	 * cannot be zone-transferred (at least not if uncompressible),
 	 * because the message and RR headers would push the size of the
-	 * TCP message over the 65536 byte limit.
+	 * TCP message over the 65535 byte limit.
 	 */
 	mem = isc_mem_get(mctx, len);
 	isc_buffer_init(&xfr->buf, mem, len);
@@ -1498,7 +1499,8 @@ sendstream(xfrout_ctx_t *xfr) {
 		msgrdl->rdclass = rdata->rdclass;
 		msgrdl->ttl = ttl;
 		if (rdata->type == dns_rdatatype_sig ||
-		    rdata->type == dns_rdatatype_rrsig) {
+		    rdata->type == dns_rdatatype_rrsig)
+		{
 			msgrdl->covers = dns_rdata_covers(rdata);
 		} else {
 			msgrdl->covers = dns_rdatatype_none;
@@ -1559,6 +1561,22 @@ sendstream(xfrout_ctx_t *xfr) {
 		xfrout_log(xfr, ISC_LOG_DEBUG(8),
 			   "sending TCP message of %d bytes", used.length);
 
+		/* System test helper options to simulate network issues. */
+		if (ns_server_getoption(xfr->client->manager->sctx,
+					NS_SERVER_TRANSFERSLOWLY))
+		{
+			/* Sleep for a bit over a second. */
+			select(0, NULL, NULL, NULL,
+			       &(struct timeval){ 1, 1000 });
+		}
+		if (ns_server_getoption(xfr->client->manager->sctx,
+					NS_SERVER_TRANSFERSTUCK))
+		{
+			/* Sleep for a bit over a minute. */
+			select(0, NULL, NULL, NULL,
+			       &(struct timeval){ 60, 1000 });
+		}
+
 		isc_nmhandle_attach(xfr->client->handle,
 				    &xfr->client->sendhandle);
 		if (xfr->idletime > 0) {
@@ -1571,6 +1589,23 @@ sendstream(xfrout_ctx_t *xfr) {
 		xfr->cbytes = used.length;
 	} else {
 		xfrout_log(xfr, ISC_LOG_DEBUG(8), "sending IXFR UDP response");
+
+		/* System test helper options to simulate network issues. */
+		if (ns_server_getoption(xfr->client->manager->sctx,
+					NS_SERVER_TRANSFERSLOWLY))
+		{
+			/* Sleep for a bit over a second. */
+			select(0, NULL, NULL, NULL,
+			       &(struct timeval){ 1, 1000 });
+		}
+		if (ns_server_getoption(xfr->client->manager->sctx,
+					NS_SERVER_TRANSFERSTUCK))
+		{
+			/* Sleep for a bit over a minute. */
+			select(0, NULL, NULL, NULL,
+			       &(struct timeval){ 60, 1000 });
+		}
+
 		ns_client_send(xfr->client);
 		xfr->stream->methods->pause(xfr->stream);
 		isc_nmhandle_detach(&xfr->client->reqhandle);
