@@ -69,7 +69,7 @@ matchview(isc_netaddr_t *srcaddr, isc_netaddr_t *destaddr,
 	UNUSED(sigresultp);
 	UNUSED(viewp);
 
-	return (ISC_R_NOTIMPLEMENTED);
+	return ISC_R_NOTIMPLEMENTED;
 }
 
 int
@@ -84,19 +84,19 @@ setup_server(void **state) {
 
 	result = dns_dispatchmgr_create(mctx, netmgr, &dispatchmgr);
 	if (result != ISC_R_SUCCESS) {
-		return (-1);
+		return -1;
 	}
 
 	result = ns_interfacemgr_create(mctx, sctx, taskmgr, timermgr, netmgr,
 					dispatchmgr, maintask, NULL, workers,
 					false, &interfacemgr);
 	if (result != ISC_R_SUCCESS) {
-		return (-1);
+		return -1;
 	}
 
 	result = ns_listenlist_default(mctx, port, true, AF_INET, &listenon);
 	if (result != ISC_R_SUCCESS) {
-		return (-1);
+		return -1;
 	}
 
 	ns_interfacemgr_setlistenon4(interfacemgr, listenon);
@@ -104,7 +104,7 @@ setup_server(void **state) {
 
 	clientmgr = ns_interfacemgr_getclientmgr(interfacemgr);
 
-	return (0);
+	return 0;
 }
 
 int
@@ -123,7 +123,7 @@ teardown_server(void **state) {
 	}
 
 	teardown_managers(state);
-	return (0);
+	return 0;
 }
 
 static dns_zone_t *served_zone = NULL;
@@ -191,7 +191,7 @@ ns_test_serve_zone(const char *zonename, const char *filename,
 	 */
 	result = dns_test_makezone(zonename, &served_zone, view, false);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	/*
@@ -233,7 +233,7 @@ ns_test_serve_zone(const char *zonename, const char *filename,
 		dns_db_detach(&db);
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 release_zone:
 	dns_test_releasezone(served_zone);
@@ -242,7 +242,7 @@ close_zonemgr:
 free_zone:
 	dns_zone_detach(&served_zone);
 
-	return (result);
+	return result;
 }
 
 void
@@ -278,7 +278,7 @@ ns_test_getclient(ns_interface_t *ifp0, bool tcp, ns_client_t **clientp) {
 	client->handle = (isc_nmhandle_t *)client; /* Hack */
 	*clientp = client;
 
-	return (result);
+	return result;
 }
 
 /*%
@@ -368,7 +368,7 @@ attach_query_msg_to_client(ns_client_t *client, const char *qnamestr,
 	 * Parse the rendered query, storing results in client->message.
 	 */
 	isc_buffer_first(&querybuf);
-	return (dns_message_parse(client->message, &querybuf, 0));
+	return dns_message_parse(client->message, &querybuf, 0);
 
 put_name:
 	dns_message_puttempname(message, &qname);
@@ -377,7 +377,7 @@ put_rdataset:
 destroy_message:
 	dns_message_detach(&message);
 
-	return (result);
+	return result;
 }
 
 /*%
@@ -400,19 +400,13 @@ extract_qctx(void *arg, void *data, isc_result_t *resultp) {
 	 * gets unwound.
 	 */
 	qctx = isc_mem_get(mctx, sizeof(*qctx));
-	if (qctx != NULL) {
-		memmove(qctx, (query_ctx_t *)arg, sizeof(*qctx));
-	}
+	memmove(qctx, (query_ctx_t *)arg, sizeof(*qctx));
 
 	qctxp = (query_ctx_t **)data;
-	/*
-	 * If memory allocation failed, the supplied pointer will simply be set
-	 * to NULL.  We rely on the user of this hook to react properly.
-	 */
 	*qctxp = qctx;
 	*resultp = ISC_R_UNSET;
 
-	return (NS_HOOK_RETURN);
+	return NS_HOOK_RETURN;
 }
 
 /*%
@@ -456,9 +450,9 @@ create_qctx_for_client(ns_client_t *client, query_ctx_t **qctxp) {
 	isc_nmhandle_detach(&client->reqhandle);
 
 	if (*qctxp == NULL) {
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	} else {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 }
 
@@ -479,7 +473,7 @@ ns_test_qctx_create(const ns_test_qctx_create_params_t *params,
 	 */
 	result = ns_test_getclient(NULL, false, &client);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	TIME_NOW(&client->tnow);
 
@@ -525,7 +519,7 @@ ns_test_qctx_create(const ns_test_qctx_create_params_t *params,
 	handle = client->handle;
 	isc_nmhandle_detach(&handle);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 detach_query:
 	dns_message_detach(&client->message);
@@ -534,7 +528,7 @@ detach_view:
 detach_client:
 	isc_nmhandle_detach(&client->handle);
 
-	return (result);
+	return result;
 }
 
 void
@@ -567,7 +561,7 @@ ns_test_hook_catch_call(void *arg, void *data, isc_result_t *resultp) {
 
 	*resultp = ISC_R_UNSET;
 
-	return (NS_HOOK_RETURN);
+	return NS_HOOK_RETURN;
 }
 
 isc_result_t
@@ -581,27 +575,27 @@ ns_test_loaddb(dns_db_t **db, dns_dbtype_t dbtype, const char *origin,
 
 	result = dns_name_fromstring(name, origin, 0, NULL);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	result = dns_db_create(mctx, "rbt", name, dbtype, dns_rdataclass_in, 0,
 			       NULL, db);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	result = dns_db_load(*db, testfile, dns_masterformat_text, 0);
-	return (result);
+	return result;
 }
 
 static int
 fromhex(char c) {
 	if (c >= '0' && c <= '9') {
-		return (c - '0');
+		return c - '0';
 	} else if (c >= 'a' && c <= 'f') {
-		return (c - 'a' + 10);
+		return c - 'a' + 10;
 	} else if (c >= 'A' && c <= 'F') {
-		return (c - 'A' + 10);
+		return c - 'A' + 10;
 	}
 
 	printf("bad input format: %02x\n", c);
@@ -621,7 +615,7 @@ ns_test_getdata(const char *file, unsigned char *buf, size_t bufsiz,
 
 	result = isc_stdio_open(file, "r", &f);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	bp = buf;
@@ -665,5 +659,5 @@ ns_test_getdata(const char *file, unsigned char *buf, size_t bufsiz,
 
 cleanup:
 	isc_stdio_close(f);
-	return (result);
+	return result;
 }
